<?php
/*
Parmetros:
	action 		= ao requisitada
	token 		= Chave de temporria de operao acesso
	email		= Email de usurio cadastrado no projeto <pid>
	password	= Senha de acesso do usurio <email> no sistema
	pid			= Nmero identificador nico do projeto no sistema
	idform 		= Nmero identificador nico do formulrio no sistema
	idrecord 	= Nmero identificador do registro no sistema
*/
class Api {
	var $strEncoding = 'ISO-8859-1';
	var $intLimitResults = 100;
	var $intTokenValidMinutes = 30;
	var $intDailyRecordsCreationLimit = 100;
	var $strURLAPI;
	var $intThumbSize = 300;
	var $strWFSViconNS = 'vicon';
	var $intDevice = 2; // Table device - record 'Mobile'
	
	public function __construct($strPrefix = '') {
		include_once 'database.php';
		$database = new Database($strPrefix);
		$this->database = $database;
		include_once 'strings.php';
		$strings = new Strings();
		$this->strings = $strings;
		include_once 'project.php';
		$project = new Project($database);
		$this->project = $project;
		include_once 'user.php';
		$user = new User($database);
		$this->user = $user;
		include_once 'form.php';
		$form = new Form($database);
		$this->form = $form;
		include_once 'formrecord.php';
		$formrecord = new Formrecord($database);
		$this->formrecord = $formrecord;
		include_once 'geodesign.php';
		$geodesign = new Geodesign();
		$this->geodesign = $geodesign;
		$this->strURLAPI = $this->strings->strSiteURL . '/api.php?';
	}
	
	public function strPrintErrorParametersInvalid($strParameters, $strOutputFormat = 'xml') {
		$arrResult = array();
		$arrResult['id'] = -1;
		$arrResult['detail'] = 'Incomplete parameters. Parameters required for this call: ' . $strParameters;
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result');
		}
	}
	
	public function strPrintErrorUserProjectInvalid($strOutputFormat) {
		$arrResult = array();
		$arrResult['id'] = -2;
		$arrResult['detail'] = 'Invalid email and/or password and/or Project ID';
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result');
		}
	}
	
	public function strPrintErrorUserInvalid($strOutputFormat) {
		$arrResult = array();
		$arrResult['id'] = -2;
		$arrResult['detail'] = 'Invalid email and/or password';
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result');
		}
	}
	
	public function strPrintErrorTokenInvalid($strOutputFormat) {
		$arrResult = array();
		$arrResult['id'] = -2;
		$arrResult['detail'] = 'Invalid token (expired after ' . $this->intTokenValidMinutes . ' minutes of its generation).';
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result');
		}
	}

	public function strPrintErrorNotPublicProject($strClass, $strOutputFormat) {
		$arrResult = array();
		$arrResult['id'] = -3;
		$arrResult['detail'] = $strClass . ' cannot be listed without a token generated by an user from this project.  This project is not open for public access.  Thus, it is necessary to generate a token by command login';
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result');
		}
	}
	
	public function strPrintErrorDeletePermission($strOutputFormat) {
		$arrResult = array();
		$arrResult['id'] = -4;
		$arrResult['detail'] = 'Record cannot be delete due to access level limitation.';
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result');
		}
	}

	public function strPrintErrorRecordNotExists($strOutputFormat) {
		$arrResult = array();
		$arrResult['id'] = -5;
		$arrResult['detail'] = 'Record does not exist!';
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result');
		}
	}

	public function strPrintErrorUserPositionInsertPermission($strOutputFormat) {
		$arrResult = array();
		$arrResult['id'] = -4;
		$arrResult['detail'] = 'User position could not be inserted due to access level limitation';
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result');
		}
	}
	
	public function strPrintErrorRecordInsertExceeded($strOutputFormat) {
		$arrResult = array();
		$arrResult['id'] = -6;
		$arrResult['detail'] = 'Fail! Exceeded daily creation quota (' . $this->intDailyRecordsCreationLimit . ' records/day).';
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result');
		}
	}
	
	public function strPrintLoginTokenGenerated($strToken, $strOutputFormat) {
		$arrResult = array();
		$arrResult['id'] = $strToken;
		$arrResult['detail'] = 'Token successfully generated.  Valid for ' . $this->intTokenValidMinutes . ' minutes.';
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result');
		}
	}
	
	public function strPrintRecordDeleteOK($strOutputFormat) {
		$arrResult = array();
		$arrResult['id'] = 1;
		$arrResult['detail'] = 'Record successfully deleted!';
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result');
		}
	}
	
	public function strPrintUserDeleteOK($strOutputFormat) {
		$arrResult = array();
		$arrResult['id'] = 1;
		$arrResult['detail'] = 'User successfully deleted from project!';
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result');
		}
	}
	
	public function strUserPositionInsertOK($strOutputFormat) {
		$arrResult = array();
		$arrResult['id'] = 1;
		$arrResult['detail'] = 'User position successfully inserted!';
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result');
		}
	}
	
	public function strPrintReportGenerationOK($strOutputFile, $strOutputFormat) {
		$strExtension = explode('.', $strOutputFile);
		$arrResult = array();
		$arrResult['id'] = 1;
		$arrResult['detail'] = 'Report successfully generated!';
		$arrResult['fileName'] = $this->strings->strSiteURL . '/' . $strOutputFile;
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result');
		}
	}
	
	public function strPrintErrorFormCreationNotPermited($strOutputFormat) {
		$arrResult = array();
		$arrResult['id'] = -4;
		$arrResult['detail'] = 'Record could not be created due to user level limitation. User access level must be >= 3.';
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result');
		}
	}
	
	public function strPrintErrorFormNotExists($strOutputFormat) {
		$arrResult = array();
		$arrResult['id'] = -5;
		$arrResult['detail'] = 'Form does not exist.';
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result');
		}
	}
	
	public function strPrintRecordInsertOK($idFormRecord, $strOutputFormat) {
		$arrResult = array();
		$arrResult['id'] = 1;
		$arrResult['idFormRecord'] = $idFormRecord;
		$arrResult['detail'] = 'Record successfully created!';
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result');
		}
	}
	
	// Verificar se o projeto idProjeto  pblico.  
	public function blnIsProjectPublic($idProject) {
		$arrProjects = $this->project->selectProjects($idProject);
		return $arrProjects[0]['blnAllowAllView'];
	}

	// Verificar se o token  vlido para X minutos 
	public function arrIsTokenValid($strToken, $blnCheckExpire = true) {
		$query = "
			SELECT 
				u.idUser,
				u.idProject,
				u.idUserLevel
			FROM
				userapisession api,
				user u
			WHERE 
				u.idUser	= api.idUser AND
				api.strKey	= '$strToken' 
				" . ($blnCheckExpire == true ? " AND (NOW() - INTERVAL " . $this->intTokenValidMinutes . " MINUTE) < api.dtDate" : "")
		;
		$result = $this->database->executeQuery($query);
		$result = $this->database->prepareReturn($result);
		if (count($result) > 0) {
			return $result[0];
		} else {
			return false;
		}
	}
	
	public function blnIsUserInProject($idUser, $idProject){
		$query = "
		SELECT 
			COUNT(u.idProject)  AS `int`
		FROM 
			user u
		WHERE 
			u.idProject = " . $idProject . " AND 
			u.strEmail = (SELECT u.strEmail FROM user u WHERE u.idUser = " . $idUser . ")
		";
		$result = $this->database->executeQuery($query);
		$result = $this->database->prepareReturn($result);
		return $result[0]['int'] > 0;
	}

	// Verificar se a quantidade de registros criados hoje foi maior que $this->intDailyRecordsCreationLimit
	public function verificaUsuarioExtrapolouLimiteCriacaoDiaria($idUsuario) {
		$query = "SELECT COUNT(idFormRecord) AS as `int` FROM formrecord WHERE idUser=" . $idUsuario . " AND dtCreation >= DATE(NOW())";
		$result = $this->database->executeQuery($query);
		$result = $this->database->prepareReturn($result);
		return $result[0]['int'] >= $this->intDailyRecordsCreationLimit;
	}
	
	public function login($strEmail, $strPassword, $blnReturnArray = false, $strOutputFormat = 'xml') {
		// Verificando se as variveis esto OK.  Se no estiverem vou parar aqui
		if ((! $strEmail) || (!$strPassword)) {
			$strResposta = $this->strPrintErrorParametersInvalid('action, email, password', $strOutputFormat);
			return $strResposta;
		}
		// Se continuou  porque as variveis esto OK
		$arrUsers = $this->user->mobileLogin($strEmail, md5($strPassword));
		// Se usurio existe vou preparar o retorno OK
		if (count($arrUsers) > 0) {
			$strToken = substr(md5(uniqid(time())),0,20);
			// Removendo registros de sessao anteriores.  S quero o ltimo
			$query = "DELETE FROM userapisession WHERE idUser=" . $arrUsers[0]['idUser'];
			$result = $this->database->executeQuery($query);
			// Inserindo registro dessa sessao
			$query = "INSERT INTO userapisession (idUser, dtDate, strKey) VALUES (" . $arrUsers[0]['idUser'] . ", NOW(), '" . $strToken . "')";
			$result = $this->database->executeQuery($query);
			if ($blnReturnArray) {
				$arrResult = array();
				$arrResult['strToken'] = $strToken;
				$arrResult['strEmail'] = $strEmail;
				$arrResult['strPassword'] = $strPassword;
				return $arrResult;
			} else {
				return $this->strPrintLoginTokenGenerated($strToken, $strOutputFormat);
			}
		} else {
			// Usurio no existe
			return $this->strPrintErrorUserProjectInvalid($strOutputFormat);
		}
	}
	
	public function listuserprojects($strToken, $strOutputFormat = 'xml') {
		// Verificando se as variveis esto OK.  Se no estiverem vou parar aqui
		if ($strToken) {
			$arrToken = $this->arrIsTokenValid($strToken);
			if (! $arrToken) {
				return $this->strPrintErrorTokenInvalid($strOutputFormat);
			}
		} else {
			$strResposta = $this->strPrintErrorParametersInvalid('action, token', $strOutputFormat);
			return $strResposta;
		}
		$arrResult = array();
		$arrResult['id'] = 1;
		$arrProjects = $this->user->selectUserProjects($arrToken['idUser']);
		// Creating Background Image Thumbnail to decrease download speed
		foreach($arrProjects as $i => $arrProject) {
			$arrFileName = explode(".", $arrProject['strBackgroundFileFullPath']);
			$ext = strtolower(array_pop($arrFileName));
			$strSuffix = '-small';
			$strBackgroundSmallFileFullPath = $arrFileName[0] . $strSuffix . '.' . $ext;
			if (($ext == 'jpg') && (! file_exists($strBackgroundSmallFileFullPath) && (file_exists($arrProject['strBackgroundFileFullPath'])))) {
				list($width, $height, $type, $attr) = getimagesize($arrProject['strBackgroundFileFullPath']);
				$this->strings->createThumbnail($arrProject['strBackgroundFileFullPath'], $strSuffix, $this->intThumbSize, round($this->intThumbSize*$height/$width), 80);
			}
			$arrProjects[$i]['strBackgroundSmallFileFullPath'] = file_exists($strBackgroundSmallFileFullPath) ? $strBackgroundSmallFileFullPath : '';
			// Select Date of Last Created/Update Record 
			$arrInfo = $this->formrecord->selectDateLastRecordProject($arrProjects[$i]['idProject']);;
			$arrProjects[$i]['dtDateLastRecord'] = $arrInfo['dtDateLastRecord'];
		}
		$arrResult['projects'] = $arrProjects;
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result', null);
		}
	}

	public function listprojectusers($idProject, $strToken, $strOutputFormat = 'xml') {
		if (! $idProject) return $this->strPrintErrorParametersInvalid('action, pid, token (for private projects)', $strOutputFormat);
		if (! $this->blnIsProjectPublic($idProject)) {
			if ($strToken) {
				$arrToken = $this->arrIsTokenValid($strToken);
				if (! $arrToken) {
					return $this->strPrintErrorTokenInvalid($strOutputFormat);
				}
				if (! $this->blnIsUserInProject($arrToken['idUser'], $idProject)) {
					return $this->strPrintErrorNotPublicProject('', $strOutputFormat);
				}
			} else {
				return $this->strPrintErrorNotPublicProject('Users', $strOutputFormat);
			}
		}
		$arrResult = array();
		$arrResult['id'] = 1;
		$arrProjects = $this->project->selectProjects($idProject);
		$arrResult['project'] = $arrProjects[0];
		$arrUsers = $this->user->selectUsers($idProject);
		// Delete unnecessary field values
		foreach($arrUsers as $i => $arrUser){
			unset($arrUsers[$i]['strPassword']);
			unset($arrUsers[$i]['blnDeleted']);
		}
		$arrResult['users'] = $arrUsers;
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result', null);
		}
	}
	
	public function listprojectforms($idProject, $strToken, $strOutputFormat = 'xml') {
		if (! $idProject) return $this->strPrintErrorParametersInvalid('action, pid, token (for private projects)', $strOutputFormat);
		if (! $this->blnIsProjectPublic($idProject)) {
			if ($strToken) {
				$arrToken = $this->arrIsTokenValid($strToken);
				if (! $arrToken) {
					return $this->strPrintErrorTokenInvalid($strOutputFormat);
				}
				if (! $this->blnIsUserInProject($arrToken['idUser'], $idProject)) {
					return $this->strPrintErrorNotPublicProject('', $strOutputFormat);
				}
			} else {
				return $this->strPrintErrorNotPublicProject('Forms', $strOutputFormat);
			}
		}
		$arrResult = array();
		$arrResult['id'] = 1;
		$arrForms = $this->form->selectForms($idProject, 0, '', 1, 1);
		$arrResult['forms'] = $arrForms;
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result', null);
		}
	}
	
	public function listprojectrecords($idProject, $idUser = 0, $dtDateFrom = '', $intLimit = 999999, $strToken, $strOutputFormat = 'xml') {
		if (! $idProject) return $this->strPrintErrorParametersInvalid('action, pid, token (for private projects)', $strOutputFormat);
		if (! $this->blnIsProjectPublic($idProject)) {
			if ($strToken) {
				$arrToken = $this->arrIsTokenValid($strToken);
				if (! $arrToken) {
					return $this->strPrintErrorTokenInvalid($strOutputFormat);
				}
				/*
				// Comentando aqui para fazer o mobile funcionar porque ele gera o token para um usurio e depois tenta usar em outro projeto e da retornar o erro aqui
				if (! $this->blnIsUserInProject($arrToken['idUser'], $idProject)) {
					return $this->strPrintErrorNotPublicProject('', $strOutputFormat);
				}
				*/
			} else {
				return $this->strPrintErrorNotPublicProject('Records', $strOutputFormat);
			}
		}
		if ($idUser > 0) {
			$arrUser = $this->user->selectUser($idUser);
			$arrProject = $this->project->selectProjects($idProject);
			$strJSONScope = json_encode($this->user->arrUserViewScope($arrUser, $arrProject[0]['idProjectUserViewScope']));
		}
		$arrFormRecords = $this->formrecord->selectFormRecordsMobile($idProject, $strJSONScope, $dtDateFrom, $intLimit);
		foreach($arrFormRecords as $i => $arrFormRecord) {
			$arrFormRecordDatas = $this->formrecord->selectFormRecordData($arrFormRecord['idFormRecord']);
			$fields = array();
			foreach($arrFormRecordDatas as $j => $arrFormRecordData) {
				$fields[$j]['idFormField'] = $arrFormRecordData['idFormField'];
				$fields[$j]['strName'] = $arrFormRecordData['strName'];
				$fields[$j]['strTip'] = $arrFormRecordData['strTip'];
				$fields[$j]['idFormFieldType'] = $arrFormRecordData['idFormFieldType'];
				$fields[$j]['idValue'] = str_replace(' ', '', $arrFormRecordData['idValue']);
				$fields[$j]['dataValue'] = $arrFormRecordData['idFormFieldType'] == 7 ? str_replace('<:>',", ", $arrFormRecordData['strValue']) : $arrFormRecordData['strValue'];
			}
			// Marker
			$arrFormRecords[$i]['strMarkerFullPath'] = $this->strings->strMarkerFolder . '/' . $arrFormRecord['strMarkerFileName'];
			if ($arrFormRecords[$i]['idProjectMarker'] > 0) {
				$arrFormRecords[$i]['strMarkerFullPath'] = $this->strings->strProjectFolder . '/' . $arrFormRecords[$i]['idProjectMarker'] . '/' . $arrFormRecords[$i]['strMarkerFileName'];
			}
			$arrFormRecords[$i]['strFormMarkerFullPath'] = $arrFormRecords[$i]['strMarkerFullPath'];
			$arrFormRecords[$i]['strMarkerFullURL'] = $this->strings->strSiteURL . '/' . $arrFormRecords[$i]['strMarkerFullPath'];
			// Custom Marker
			if (($arrFormRecords[$i]['idShapeType'] == 1) && ($arrFormRecords[$i]['strCustomMarkerRGBColor'])) {
				$arrFormRecords[$i]['strMarkerFullPath'] = $arrFormRecords[$i]['strCustomMarkerRGBColor'];
				$arrFormRecords[$i]['strMarkerFullURL'] = $arrFormRecords[$i]['strMarkerFullPath'];
			}
			// Fields
			$arrFormRecords[$i]['fields'] = $fields;
			$arrFormRecords[$i]['arrFiles'] = $this->formrecord->selectFormRecordFiles($arrFormRecord['idProject'], $arrFormRecord['idFormRecord']);
			// Vertexs
			$arrVertexs = array();
			if ($arrFormRecord['idShapeType'] == 1) {
				$arrVertexs[] = array($arrFormRecord['dblLatitude'], $arrFormRecord['dblLongitude']);
			} else {
				$arrVtcs = $this->formrecord->selectFormRecordVertexs($arrFormRecord['idFormRecord']);
				foreach($arrVtcs as $k => $arrVtc) {
					$arrVertexs[] = array($arrVtc['dblLatitude'], $arrVtc['dblLongitude']);
				}
			}
			$arrFormRecords[$i]['arrVertexs'] = $arrVertexs;
		}
		$arrResult = array();
		$arrResult['id'] = 1;
		$arrResult['fromdate'] = $dtDateFrom;
		$arrResult['records'] = $arrFormRecords;
		$arrResult['deleted'] = $this->formrecord->arrDeleteFormRecordsIDs($idProject, $dtDateFrom);
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result', null);
		}
	}
	
	public function projectlastupdate($idProject, $idUser = 0, $strOutputFormat = 'xml') {
		$arrResult = array();
		$arrResult['id'] = 1;
		if ($idUser > 0) {
			$arrUser = $this->user->selectUser($idUser);
			$arrProject = $this->project->selectProjects($idProject);
			$strJSONScope = json_encode($this->user->arrUserViewScope($arrUser, $arrProject[0]['idProjectUserViewScope']));
		}
		$arrInfo = $this->formrecord->selectDateLastRecordProject($idProject, $strJSONScope);
		$arrResult['dtProjectLastUpdate'] = $arrInfo['dtDateLastRecord'];
		$arrResult['intProjectRecords'] = $arrInfo['intProjectRecords'];
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result', null);
		}
	}
	
	public function listevents($strIDs, $dtDateFrom = '', $intLimit = 999999, $strOutputFormat = 'xml') {
		$strIDEventTypes = implode(',', array(1,2,10,11,12,13,14,15)); // Filter by these event types...
		$arrEvents = $this->database->selectEvents(0, 0, 0, $dtDateFrom, '', $intLimit, true, $strIDs, $strIDEventTypes);
		$arrResult = array();
		$arrResult['id'] = 1;
		$arrResult['fromdate'] = $dtDateFrom;
		$arrResult['events'] = $arrEvents;
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result', null);
		}
	}
	
	public function listforminfo($idForm, $strToken, $strOutputFormat = 'xml') {
		if (! $idForm) return $this->strPrintErrorParametersInvalid('idform, token (for private projects)', $strOutputFormat);
		$arrForms = $this->form->selectForms(0, $idForm);
		if (! count($arrForms)) return $this->strPrintErrorFormNotExists($strOutputFormat);
		$idProject = $arrForms[0]['idProject'];
		if (! $this->blnIsProjectPublic($idProject)) {
			if ($strToken) {
				$arrToken = $this->arrIsTokenValid($strToken);
				if (! $arrToken) {
					return $this->strPrintErrorTokenInvalid($strOutputFormat);
				}
				if (! $this->blnIsUserInProject($arrToken['idUser'], $idProject)) {
					return $this->strPrintErrorNotPublicProject('', $strOutputFormat);
				}
			} else {
				return $this->strPrintErrorNotPublicProject('Form', $strOutputFormat);
			}
		}
		$arrResult = array();
		$arrResult['form'] = $arrForms[0];
		$arrFormFields = $this->form->selectFormFields($arrForms[0]['idForm']);
		// Load alternatives for Unique or Multi Choice fields
		foreach ($arrFormFields as $i => $arrFormField) {
			// Remove <o> and <m> from field tip
			$arrFormFields[$i]['strTip'] = strip_tags($arrFormField['strTip']);
			// Retrieve Unique and Multi choice alternatives
			if (($arrFormField['idFormFieldType'] == 3) || ($arrFormField['idFormFieldType'] == 4)) {
				$arrFormFieldAlternatives = $this->form->selectFieldAlternatives($arrFormField['idFormField']);
				$arrFormFields[$i]['alternatives'] = $arrFormFieldAlternatives;
			}
		}
		$arrResult['form']['fields'] = $arrFormFields;
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result', null);
		}
	}	
		
	public function deleterecord($idFormRecord, $idUser, $strToken, $strOutputFormat = 'xml') {
		// Verificando se as variveis esto OK.  Se no estiverem vou parar aqui
		if ((! $idFormRecord) || (! $strToken)) return $this->strPrintErrorParametersInvalid('idrecord, token', $strOutputFormat);
		// Se habilito token d erro na remoo do mobile
		//$arrToken = $this->arrIsTokenValid($strToken);
		//if (! $arrToken) return $this->strPrintErrorTokenInvalid($strOutputFormat); 
		// Verificar se o usurio tem permisso para remover o registro
		$arrFormRecord = $this->formrecord->selectFormRecords(0, 0, 0, $idFormRecord);
		// Registro no existe
		if (! count($arrFormRecord)) return $this->strPrintErrorRecordNotExists($strOutputFormat);
		$arrFormRecord = $arrFormRecord[0];
		// Somente nvel 4 e o proprietrio do registro pode remover
		if ($idUser) {
			$arrUser = $this->user->selectUser($idUser);
		} else {
			$arrUser = $arrToken;
		}
		if (($arrUser['idUserLevel'] < 4) && ($arrFormRecord['idUser'] != $arrUser['idUser'])) return $this->strPrintErrorDeletePermission($strOutputFormat);
		// Chamando funo para remover o registro
		$this->formrecord->deleteFormRecord($idFormRecord, true, false, $idUser);
		return $this->strPrintRecordDeleteOK($strOutputFormat);
	}
	
	public function deleteuser($idUser, $strToken, $strOutputFormat = 'xml') {
		// Verificando se as variveis esto OK.  Se no estiverem vou parar aqui
		if ((! $idUser) || (! $strToken)) return $this->strPrintErrorParametersInvalid('uid, token', $strOutputFormat);
		$arrResult = $this->user->leaveProject($idUser, '', 1, false);
		return $this->strPrintUserDeleteOK($strOutputFormat);
	}
	
	public function insertuserposition($dblLatitude, $dblLongitude, $strToken, $idUser = 0, $strOutputFormat = 'xml') {
		// Verificando se as variveis esto OK.  Se no estiverem vou parar aqui
		if ((! $dblLatitude) || (! $dblLongitude) || (! $strToken)) return $this->strPrintErrorParametersInvalid('lat, lng, token', $strOutputFormat);
		$arrToken = $this->arrIsTokenValid($strToken, false);
		if (! $arrToken) return $this->strPrintErrorTokenInvalid($strOutputFormat); 
		if (($arrToken['idUserLevel'] < 4) && ($arrFormRecord['idUser'] != $arrToken['idUser'])) return $this->strPrintErrorUserPositionInsertPermission($strOutputFormat);
		// Chamando funo para inserir a posio do usurio
		$idUser = $idUser > 0 ? $idUser : $arrToken['idUser'];
		$this->user->insertUserPosition($idUser, $dblLatitude, $dblLongitude);
		return $this->strUserPositionInsertOK($strOutputFormat);
	}
	
	public function insertrecords($idForm, $data, $strToken, $strOutputFormat = 'xml') {		
		set_time_limit(300);
		// Verificando se as variveis esto OK.  Se no estiverem vou parar aqui
		if ((! $idForm) || (! $strToken)) return $this->strPrintErrorParametersInvalid('idform, token', $strOutputFormat);
		$arrToken = $this->arrIsTokenValid($strToken);
		if (! $arrToken) return $this->strPrintErrorTokenInvalid($strOutputFormat);
		if ($this->verificaUsuarioExtrapolouLimiteCriacaoDiaria($arrToken['idUser'])) return $this->strPrintErrorRecordInsertExceeded($strOutputFormat);		
		$arrForm = $this->form->selectForms(0, $idForm);
		if (! count($arrForm)) return $this->strPrintErrorFormNotExists($strOutputFormat);
		$arrForm = $arrForm[0];
		// Verificando se o usurio tem permisso para remover
		if ($arrToken['idUserLevel'] < 3) return $this->strPrintErrorFormCreationNotPermited($strOutputFormat);
		$arrFormRecordIDs = array();
		// Decupando dados formato GeoJSON - http://geojson.org/geojson-spec.html
		$arrData = json_decode($data, true);
		$arrFeatures = $arrData['features'];
		foreach($arrFeatures as $i=> $arrFeature) {
			$idDevice = 3; // Via API
			// Getting Geometry
			$idShapeType = 1;
			if (($arrFeature['geometry']['type'] == 'LineString') || ($arrFeature['geometry']['type'] == 'MultiLineString')) {
				$idShapeType = 2;
			} else if (($arrFeature['geometry']['type'] == 'Polygon') || ($arrFeature['geometry']['type'] == 'MultiPolygon')) {
				$idShapeType = 3;
			}
			$arrGeometryCoordinates = $arrFeature['geometry']['coordinates'];
			if ($idShapeType == 1) {
				$arrGeometryCoordinates = array($arrFeature['geometry']['coordinates']); 
			}
			$arrCoordinates = array();
			foreach($arrGeometryCoordinates as $arrCoordinate) {
				$arrCoordinates[] = array(
					'dblLongitude'	=> $arrCoordinate[0],
					'dblLatitude'	=> $arrCoordinate[1]
				);
			}
			// Creating Form Record
			$arrResult = $this->formrecord->insertFormRecord($arrToken['idUser'], $idForm, 3, $idShapeType, '', $arrCoordinates);
			$idFormRecord = $arrResult['idFormRecord'];
			$arrFormRecordIDs[] = $idFormRecord;
			// Fields Values
			$arrFormFields = $this->form->selectFormFields($idForm);
			foreach($arrFeature['properties']['fields'] as $arrField) {
				$idFormField = $arrField['idFormField'];
				$strValue = $arrField['value'];
				if (! $strValue) continue;
				foreach($arrFormFields as $arrFormField) {
				if ($arrFormField['idFormField'] == $idFormField) {
						if ($arrFormField['idFormFieldType'] == 1) { 
							$this->formrecord->insertFormRecordFieldText($idFormRecord, $arrFormField['idFormField'], $strValue);
						} else if (($arrFormField['idFormFieldType'] == 2) && (is_numeric($strValue))){ 
							$this->formrecord->insertFormRecordFieldNumeric($idFormRecord, $arrFormField['idFormField'], $strValue);
						} else if (($arrFormField['idFormFieldType'] == 3) || ($arrFormField['idFormFieldType'] == 4)) {
							// Alternatives are value = 'Abc,def,ghi'
							$strValue = $this->formrecord->strIdAlternativesFormRecord($arrFormField['idFormField'], $strAlternative);
							$this->formrecord->insertFormRecordFieldAlternative($idFormRecord, $arrFormField['idFormField'], $strValue);
						} else if ($arrFormField['idFormFieldType'] == 5) {
							$this->formrecord->insertFormRecordFieldDate($idFormRecord, $arrFormField['idFormField'], $strValue);
						} else if ($arrFormField['idFormFieldType'] == 6) {
							$strValue = date('H:i:s', strtotime($strValue));
							$this->formrecord->insertFormRecordFieldTime($idFormRecord, $arrFormField['idFormField'], $strValue);
						} 
						break;
					}
				}
			}
			// Attachments
			foreach($arrFeature['properties']['attachments'] as $arrAttachment) {
				//$arrAttachment['url'] = utf8_decode($arrAttachment['url']);
				$strFileName = basename($arrAttachment['url']);
				$arrAttachment['url'] = preg_replace("/ /", "%20", $arrAttachment['url']);
				$this->formrecord->insertFormRecordFile($arrForm['idProject'], $idFormRecord, $arrAttachment['url'], utf8_decode($strFileName), utf8_decode($arrAttachment['title']));
				// Do not copy to local, but keep it on source and point url
				//$this->formrecord->insertFormRecordFileURL($arrForm['idProject'], $idFormRecord, $arrAttachment['url'], $strFileName);
			}
		}
		return $this->strPrintRecordInsertOK(json_encode($arrFormRecordIDs), $strOutputFormat);
	}
	
	public function insertrecordmobile($strJSON, $strOutputFormat = 'xml') {
		$arrData = json_decode($strJSON, true);
		$arrForm = $this->form->selectForms(0, $arrData['idForm']);
		if (! count($arrForm)) return $this->strPrintErrorFormNotExists($strOutputFormat);
		// Checking if user has permission to create record
		$arrUser = $this->user->selectUsers(0, $arrData['idUser']);
		$arrUser = $arrUser[0];
		if ($arrUser['idUserLevel'] < 3) return $this->strPrintErrorFormCreationNotPermited($strOutputFormat);
		// Extracting data to create record
		$arrFormRecordData = $arrData['form'];
		$dblLatitude = $arrFormRecordData[0]['dataValue'];
		$dblLongitude = $arrFormRecordData[1]['dataValue'];
	    $dblLatitude = str_replace(",", ".", $dblLatitude);
	    $dblLongitude = str_replace(",", ".", $dblLongitude);
		if (! is_numeric($dblLatitude)) $dblLatitude = 0;
		if (! is_numeric($dblLongitude)) $dblLongitude = 0;
		$arrData['idShapeType'] = $arrData['idShapeType'] ? $arrData['idShapeType'] : 1;
		$arrCoordinates[] = array('dblLatitude' => $dblLatitude, 'dblLongitude' => $dblLongitude);
		if ($arrData['idShapeType'] > 1) {
			$arrCoordinates = array();
			foreach($arrData['arrVertexs'] as $arrVertex) {
				$arrCoordinates[] = array('dblLatitude' => $arrVertex[0], 'dblLongitude' => $arrVertex[1]);
			}
		}
		$arrData['dateSaved'] = str_replace("/", "-", $arrData['dateSaved']);
		$dtCreation = date('Y-m-d H:i:s', strtotime($arrData['dateSaved']));
		if ($dtCreation === false) { // Format dd-mm-YYY hh:mm:ss AM/PM (Javascript Full Time)
			$arrData['dateSaved'] = str_replace(",", "", $arrData['dateSaved']);
			$arrData['dateSaved'] = str_replace(" AM", "", $arrData['dateSaved']);
			$arrData['dateSaved'] = str_replace(" PM", "", $arrData['dateSaved']);
			$blnPM = strpos($arrData['dateSaved'], 'PM') !== FALSE;
			if (strpos($arrData['dateSaved'], '-' . date('Y'))) {
				$arrData['dateSaved'] = str_replace('-' . date('Y'), "", $arrData['dateSaved']);
				$arrData['dateSaved'] = date('Y') . '-' . $arrData['dateSaved'];
				if ($blnPM) {
					$dtCreation = strtotime('+12 hours', $arrData['dateSaved']);
				}
			}
		}
		$idFormRecord = $arrData['idFormRecord'];
		$idProject = $arrData['idProject'];
		// User Invalid
		if (! $arrData['idUser'] > 0) {
			return $this->strPrintErrorUserProjectInvalid($strOutputFormat);
		}
		if ($this->formrecord->blnFormRecordExists($idFormRecord)) {	// If idFormRecord > 0 -> Update Record
			$query = "UPDATE formrecord SET dtLastUpdate = NOW() WHERE idFormRecord = " . $idFormRecord;
			$this->database->executeQuery($query);
			// Insert Event Update Record
			$this->database->insertEvent(14, $arrData['idUser'], $idFormRecord);
			/*
			$intShapeType = $this->formrecord->intFormRecordShapeType($idFormRecord);
			// Just Update Form Records Vertex if it's a point.  Otherwise, keep old vertexes
			if ($intShapeType == 1) {
				$this->formrecord->insertFormRecordVertexs($idFormRecord, 1, $arrCoordinates);
			}
			*/
			$this->formrecord->insertFormRecordVertexs($idFormRecord, $arrData['idShapeType'], $arrCoordinates);
			// Deleting attached files
			if ($idProject > 0) {
				$arrMobileFilePaths = array();
				foreach($arrData['arrFiles'] as $item) {
					$arrMobileFilePaths[] = $item['path'];
				}
				$arrFormRecordFiles = $this->formrecord->selectFormRecordFiles($idProject, $idFormRecord);
				foreach ($arrFormRecordFiles as $arrFormRecordFile) {
					// If file to be submited is already in server, do not delete it
					if (array_search($arrFormRecordFile['strFileNameFullURL'], $arrMobileFilePaths) !== FALSE) continue;
					@unlink($arrFormRecordFile['strFileNameFullPath']);
					@unlink($arrFormRecordFile['strFileNameFullPathRed']);
					$query = "DELETE FROM formrecordfile WHERE idFormRecordFile = " . $arrFormRecordFile['idFormRecordFile'];
					$this->database->executeQuery($query);
				}
			}
			// Delete record keeping idFormRecord and Time Series Values
			$this->formrecord->deleteFormRecord($idFormRecord, false, true);
		} else {				// Otherwise, create new Record
			// Form Invalid
			if (! $arrData['idForm'] > 0) {
				return $this->strPrintErrorFormNotExists($strOutputFormat);
			}
			$arrResult = $this->formrecord->insertFormRecord($arrData['idUser'], $arrData['idForm'], $this->intDevice, $arrData['idShapeType'], '', $arrCoordinates, $dtCreation);
			$idFormRecord = $arrResult['idFormRecord'];
		}
		$arrFormFields = $this->form->selectFormFields($arrData['idForm']);
		foreach ($arrFormFields as $i => $arrFormField) {
			$strValue = $this->strFormFieldValueById($arrFormRecordData, $arrFormField);
			if (! $strValue) continue;
			if ($arrFormField['idFormFieldType'] == 1) {
				$this->formrecord->insertFormRecordFieldText($idFormRecord, $arrFormField['idFormField'], $strValue);
			} else if ($arrFormField['idFormFieldType'] == 2) {
				$this->formrecord->insertFormRecordFieldNumeric($idFormRecord, $arrFormField['idFormField'], $strValue);
			} else if (($arrFormField['idFormFieldType'] == 3) || ($arrFormField['idFormFieldType'] == 4)) {
				$this->formrecord->insertFormRecordFieldAlternative($idFormRecord, $arrFormField['idFormField'], $strValue);
			} else if ($arrFormField['idFormFieldType'] == 5) {
				$this->formrecord->insertFormRecordFieldDate($idFormRecord, $arrFormField['idFormField'], $strValue);
			} else if ($arrFormField['idFormFieldType'] == 6) {
				$strValue = date('H:i:s', strtotime($strValue));
				$this->formrecord->insertFormRecordFieldTime($idFormRecord, $arrFormField['idFormField'], $strValue);
			} else if ($arrFormField['idFormFieldType'] == 7) {
				// Remove Duplicated
				$query = "
					DELETE 
						formrecordfieldtimeserie 
					FROM 
						formrecordfield, formrecordfieldtimeserie 
					WHERE 
						formrecordfield.idFormRecordField = formrecordfieldtimeserie.idFormRecordField AND 
						formrecordfield.idFormField = " . $arrFormField['idFormField'] . " AND 
						formrecordfieldtimeserie.dtDateTime = '" . $dtCreation . "' AND 
						formrecordfieldtimeserie.strValue = '" . $strValue . "'
					";
				$this->database->executeQuery($query);
				// Insert Value
				$strTimeSerie = $dtCreation . chr(9) . $strValue;
				$this->formrecord->insertFormRecordFieldTimeSeries($idFormRecord, $arrFormField['idFormField'], $strTimeSerie);
			}
		}
		return $this->strPrintRecordInsertOK($idFormRecord, $strOutputFormat);
	}
	
	public function strFormFieldValueById($arrFormRecordData, $arrFormField){
		foreach ($arrFormRecordData as $item) {
			if ($item['idFormField'] == $arrFormField['idFormField']) {
				// Handling Other Values
				if (($arrFormField['idFormFieldType'] == 3) || ($arrFormField['idFormFieldType'] == 4)) {
					// Turn string into array()
					if ($arrFormField['idFormFieldType'] == 3) {
						$item['dataValue'] = array($item['dataValue']);
					}
					foreach($item['dataValue'] as $k => $idFormFieldAlternative) {
						if ($idFormFieldAlternative < 0) {
							$arrAlternatives = $item['alternatives'];
							foreach($arrAlternatives as $arrAlternative){
								if ($arrAlternative['idFormFieldAlternative'] == $idFormFieldAlternative) {
									// Check if already inserted this item
									$arrAlternative['strAlternative'] = utf8_decode($arrAlternative['strAlternative']);
									$strID = $this->formrecord->strIdAlternativesFormRecord($arrAlternative['idFormField'], $arrAlternative['strAlternative']);
									if (strlen($strID) > 0) {
										$arrIDs = explode(',', $strID);
										$item['dataValue'][$k] = $arrIDs[0];
									} else {
										// If not, insert and get id
										$arrFormFieldAlternative = $this->form->insertFieldAlternative($arrAlternative['idFormField'], $arrAlternative['strAlternative'], 1);
										$item['dataValue'][$k] = $arrFormFieldAlternative['idFormFieldAlternative'];
									}									
									break;
								}
							}
						}
					}
					return implode(',', $item['dataValue']);
				}
				return $item['dataValue'];
			}
		}
		return false;
	}
		
	// $intSearchType = 1 - Search By Radius | = 2 - Search By Rect
	public function search ($intSearchType, $idProject, $dblLatitudeSW, $dblLongitudeSW, $dblLatitudeNE, $dblLongitudeNE, $intRadius, $strKeyword = '', $strToken, $intStart = 0, $idForm = 0, $dtDateFrom = '', $dtDateTo = '', $intLimit = 0, $strOutputFormat = 'xml') {
		set_time_limit(300);
		// Verificando se as variveis esto OK.  Se no estiverem vou parar aqui
		if ($intSearchType == 1) { // Busca por raio
			if ((! $idProject) || (! is_numeric($dblLatitudeSW)) || (! is_numeric($dblLongitudeSW)) || (! $intRadius)) return $this->strPrintErrorParametersInvalid('pid, lat, lng, radius, token (for private projects)', $strOutputFormat);
		} else { // Busca por retngulo
			if ((! $idProject) || (! $dblLatitudeSW) || (! $dblLongitudeSW) || (! $dblLatitudeNE) || (! $dblLongitudeNE)) return $this->strPrintErrorParametersInvalid('pid, latSW, lngSW, latNE, lngNE, token (for private projects)', $strOutputFormat);
		}
		if (! $this->blnIsProjectPublic($idProject)) {
			if ($strToken) {
				$arrToken = $this->arrIsTokenValid($strToken);
				if (! $arrToken) {
					return $this->strPrintErrorTokenInvalid($strOutputFormat);
				}
				if (! $this->blnIsUserInProject($arrToken['idUser'], $idProject)) {
					return $this->strPrintErrorNotPublicProject('', $strOutputFormat);
				}
			} else {
				return $this->strPrintErrorNotPublicProject('Forms', $strOutputFormat);
			}
		}
		$arrCoordinates = array();
		if ($intSearchType == 1) {
			$arrCoordinates[0]['dblLat'] = $dblLatitudeSW;
			$arrCoordinates[0]['dblLng'] = $dblLongitudeSW;
			$arrFormRecords = $this->formrecord->selectFormRecordsByPolygon('C', $idProject, $arrCoordinates, '', $intRadius, $intLimit, 'fr.idForm, fr.idFormRecord', $idForm, $dtDateFrom, $dtDateTo);
		} else {
			$arrCoordinates[0]['dblLat'] = $dblLatitudeNE;
			$arrCoordinates[0]['dblLng'] = $dblLongitudeNE;
			$arrCoordinates[1]['dblLat'] = $dblLatitudeSW;
			$arrCoordinates[1]['dblLng'] = $dblLongitudeSW;
			$arrFormRecords = $this->formrecord->selectFormRecordsByPolygon('R', $idProject, $arrCoordinates, '', '', $intLimit, 'fr.idForm, fr.idFormRecord', $idForm, $dtDateFrom, $dtDateTo);
		}

		$k = 0;
		$arrResult = array();
		foreach ($arrFormRecords as $arrFormRecordReport) {
			$arrFormRecord = $this->formrecord->selectFormRecords(0, 0, 0, $arrFormRecordReport['idFormRecord']);
			$arrFormRecord = $arrFormRecord[0];
			$arrResult['records'][$k]['formName'] = $arrFormRecord['strFormName'];
			$arrResult['records'][$k]['recordID'] = $arrFormRecord['idFormRecord'];
			$arrResult['records'][$k]['shapeType'] = $arrFormRecord['idShapeType'];
			$arrResult['records'][$k]['creationDate'] = $arrFormRecord['strCreation'];
			$arrResult['records'][$k]['creationEmail'] = $arrFormRecord['strEmail'];
			$arrResult['records'][$k]['lastUpdateDate'] = $arrFormRecord['strLastUpdate'];
			$arrResult['records'][$k]['sourceDevice'] = $arrFormRecord['idDevice'];
			$arrResult['records'][$k]['shapeColor'] = $arrFormRecord['strCustomMarkerRGBColor'];
			$arrResult['records'][$k]['markerImage'] = $arrFormRecord['strMarkerFullURL'];
			if ($arrFormRecordReport['dblDistanceFromCenterMts'] > 0) {
				 $arrResult['records'][$k]['distanceMts'] = number_format($arrFormRecordReport['dblDistanceFromCenterMts'], 2, '.', '');
			}				
			$arrResult['records'][$k]['attachedFiles'] = count($arrFormRecord['arrFiles']);
			// Coordinates
			foreach($arrFormRecord['arrVertex'] as $index => $arrVerte) {
				$arrResult['records'][$k]['coordinates'][$index]['latitude'] = $arrVerte['dblLatitude'];
				$arrResult['records'][$k]['coordinates'][$index]['longitude'] = $arrVerte['dblLongitude'];
			}
		
			$arrFormRecordDatas = $this->formrecord->selectFormRecordData($arrFormRecordReport['idFormRecord']);
			foreach($arrFormRecordDatas as $index => $arrFormRecordData) {
			//$strValue = $this->formrecord->returnInfoCampoFormulario($arrFormRecordData, $arrFormField['idPergunta'], $arrFormField['idTipoPergunta']);	
				$strValue = $arrFormRecordData['strValue'];
				// Format for time series
				if ($arrFormRecordData['idFormFieldType'] == 7) $strValue = str_replace('<:>',", ", $strValue);
				$arrResult['records'][$k]['fields'][$index]['name'] = $arrFormRecordData['strName'];
				$arrResult['records'][$k]['fields'][$index]['description'] = $arrFormRecordData['strTip'];
				$arrResult['records'][$k]['fields'][$index]['dataType'] = $arrFormRecordData['idFormFieldType'];
				$arrResult['records'][$k]['fields'][$index]['value'] = $strValue;
			}
			
			// Attached Files
			foreach($arrFormRecord['arrFiles'] as $index => $arrFile) {
				$arrResult['records'][$k]['files'][$index]['name'] = $arrFile['strFileOriginalName'];
				$arrResult['records'][$k]['files'][$index]['description'] = $arrFile['strDescription'];
				$arrResult['records'][$k]['files'][$index]['sizeMb'] = number_format(@filesize($arrFile['strFileNameFullPath'])/1000000, 2, '.','');
				$arrResult['records'][$k]['files'][$index]['url'] = $arrFile['strFileNameFullURL'];
				$arrResult['records'][$k]['files'][$index]['urlThumb'] = $arrFile['strFileThumbURL'];
			}
			$k++;
		} // End of FormRecord
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result', null);
		}
	}

	// Informaes de um registro
	public function recordinfo($idFormRecord, $strToken, $strOutputFormat = 'xml') {
		// Verificando se as variveis esto OK.  Se no estiverem vou parar aqui
		if (! $idFormRecord) return $this->strPrintErrorParametersInvalid('idrecord, token (for private projects)', $strOutputFormat);
		$arrFormRecord = $this->formrecord->selectFormRecords(0, 0, 0, $idFormRecord);
		// Registro no existe
		if (! count($arrFormRecord)) return $this->strPrintErrorRecordNotExists($strOutputFormat);
		if (! $this->blnIsProjectPublic($arrFormRecord[0]['idProject'])) {
			if ($strToken) {
				$arrToken = $this->arrIsTokenValid($strToken);
				if (! $arrToken) {
					return $this->strPrintErrorTokenInvalid($strOutputFormat);
				}
				if (! $this->blnIsUserInProject($arrToken['idUser'], $arrFormRecord[0]['idProject'])) {
					return $this->strPrintErrorNotPublicProject('', $strOutputFormat);
				}
			} else {
				return $this->strPrintErrorNotPublicProject('Forms', $strOutputFormat);
			}
		}
		$arrFormRecordDatas = $this->formrecord->selectFormRecordData($arrFormRecord[0]['idFormRecord']);
		$fields = array();
		foreach($arrFormRecordDatas as $j => $arrFormRecordData) {
			$fields[$j]['idFormField'] = $arrFormRecordData['idFormField'];
			$fields[$j]['strName'] = $arrFormRecordData['strName'];
			$fields[$j]['strTip'] = $arrFormRecordData['strTip'];
			$fields[$j]['idFormFieldType'] = $arrFormRecordData['idFormFieldType'];
			$fields[$j]['idValue'] = str_replace(' ', '', $arrFormRecordData['idValue']);
			$fields[$j]['dataValue'] = $arrFormRecordData['idFormFieldType'] == 7 ? str_replace('<:>',", ", $arrFormRecordData['strValue']) : $arrFormRecordData['strValue'];
		}
		$arrFormRecord[0]['fields'] = $fields;		
		$arrFormRecord[0]['arrVertexs'] = $arrFormRecord[0]['arrVertex'];
		$arrResult = array();
		$arrResult['records'] = $arrFormRecord;
		if ($strOutputFormat == 'json') {
			return json_encode($this->strings->encodeArray($arrResult));
		} else {
			return $this->strings->strArrayToXML($arrResult, 'result', null);
		}
	}
			
	public function generatereport($idProject, $strExtension, $strToken, $strOutputFormat = 'xml') {
		// Verificando se as variveis esto OK.  Se no estiverem vou parar aqui
		if ((! $idProject) || (! $strExtension)) return $this->strPrintErrorParametersInvalid('pid, ext, token (for private projects)', $strOutputFormat);
		if (! $this->blnIsProjectPublic($idProject)) {
			if ($strToken) {
				$arrToken = $this->arrIsTokenValid($strToken);
				if (! $arrToken) {
					return $this->strPrintErrorTokenInvalid($strOutputFormat);
				}
				if (! $this->blnIsUserInProject($arrToken['idUser'], $idProject)) {
					return $this->strPrintErrorNotPublicProject('', $strOutputFormat);
				}
				$arrProject = $this->project->selectProjects($idProject);
				$strJSONScope = json_encode($this->user->arrUserViewScope($arrToken['idUser'], $arrProject[0]['idProjectUserViewScope']));
			} else {
				return $this->strPrintErrorNotPublicProject('Forms', $strOutputFormat);
			}
		}
		include_once 'report.php';
		$report = new Report($this->database);
		$arrReturn = $report->generateReport($idProject, $strExtension, '', true, false, false, 0, 0, 70, '', '../', $strJSONScope);
		$strOutputFileName = $arrReturn['strFilePathTMP'];
		$strOutputFileName = str_replace("../", "", $strOutputFileName);
		return $this->strPrintReportGenerationOK($strOutputFileName, $strOutputFormat);
	}
	
	public function liveKML($idProject, $strOutputFormat = 'xml') {
		// Verificando se as variveis esto OK.  Se no estiverem vou parar aqui
		if (! is_numeric($idProject)) {
			return '<kml><Document><open>1</open><Folder><name>Invalid Project</name><gx:balloonVisibility>1</gx:balloonVisibility></Folder></Document></kml>';
		}
		include_once 'report.php';
		$report = new Report($this->database);
		$arrProject = $this->project->selectProjects($idProject);
		$arrProject = $arrProject[0];
		if (count($arrProject) == 0) {
			return '<kml><Document><open>1</open><Folder><name>Invalid Project</name><gx:balloonVisibility>1</gx:balloonVisibility></Folder></Document></kml>';
		}
		if (! $arrProject['blnAllowAllView']) {
			return '<kml><Document><open>1</open><Folder><name>Private Records</name><gx:balloonVisibility>1</gx:balloonVisibility></Folder></Document></kml>';
		}
		set_time_limit(1800); // Increasing Timeout to Garantee Enough Time
		$arrReport = $report->generateReport($arrProject['idProject'], 'kml', '', true, true, false, 0, 0, 100, '', '', '', '', '', '', '', false);
		return $arrReport['strReport'];
	}
		
	/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	WFS Protocol
	+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
	public function wfs($idProject, $strEmail = '', $strPassword = '', $blnSummary = false, $REQUEST, $TYPENAME) {
		$strWFSURL = $this->strURLAPI . 'action=wfs&amp;pid=' . $idProject . '&amp;email=' . $strEmail . '&amp;password=' . $strPassword . ($blnSummary === true ? '&amp;summary=1' : '');
		// Verificando se as variveis esto OK.  Se no estiverem vou parar aqui
		if (!$idProject) {
			$strResposta = $this->strPrintErrorParametersInvalid('action, pid', $strOutputFormat);
			return $strResposta;
		}
//$this->strings->log($REQUEST . ':' . $TYPENAME, 'tmp/out.txt', true);
		if (strtolower($REQUEST) == 'describefeaturetype') {
			return $this->wfsDescribeFeatureType($TYPENAME, $blnSummary);
		} else if ((strtolower($REQUEST) == 'getfeature') && ($TYPENAME)) { // Redirect to Features Load
			return $this->wfsGetFeatures($TYPENAME, $blnSummary, $strWFSURL);
		} 
		// Se projeto no  pblico, verificar se usurio est correto
		if (! $this->blnIsProjectPublic($idProject)) {
			$arrUsers = $this->user->mobileLogin($strEmail, md5($strPassword), $idProject);
			// Se usurio/senha incorreto, no aceitar
			if (! count($arrUsers)) {
				return $this->strPrintErrorUserProjectInvalid($strOutputFormat);
			}
		}
		// If continues, parameters OK
		$arrProject = $this->project->selectProjects($idProject);
		$arrProject = $arrProject[0];
		$xmlWFSCapabilities = new SimpleXMLElement('<WFS_Capabilities
		version="1.0.0"
		xmlns="http://www.opengis.net/wfs"
		xmlns:ogc="http://www.opengis.net/ogc"
		xmlns:gml="http://www.opengis.net/gml"
		xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
		xmlns:ows="http://www.opengis.net/ows" 
		></WFS_Capabilities>');
		$arrForms = $this->form->selectForms($idProject);
		$xmlFeatureTypeList = $xmlWFSCapabilities->addChild('FeatureTypeList');
		foreach ($arrForms as $i => $arrForm) {
			$xmlFeatureType = $xmlFeatureTypeList->addChild('FeatureType');
			$xmlFeatureType->addChild('Title', utf8_encode($arrForm['strName']));
			$xmlFeatureType->addChild('Name', $this->strXMLFieldName($arrForm['strName'] . '_' . $arrForm['idForm']));
			$xmlFeatureType->addChild('Abstract', $arrForm['intRecords'] . ' object' . ($arrForm['intRecords']  == 1 ? '' : 's'));
			$xmlFeatureType->addChild('SRS', 'EPSG:4326'); // WGS84
		}
		return $xmlWFSCapabilities->asXML();
	}
	
	public function wfsDescribeFeatureType($TYPENAME, $blnSummary) {
		//http://204.62.18.179:8080/geoserver/wfs?service=WFS&version=1.0.0&request=DescribeFeatureType&typeName=ogi%3Aaoi_seismicity_centroids
		//http://copadesvr02.copade.neuquen.gov.ar/geoserver/wfs?service=WFS&version=1.0.0&request=DescribeFeatureType&typeName=cite%3Aactual_suelo
		$arrParams = explode('_', $TYPENAME);
		$idForm = array_pop($arrParams);
		$arrFormFields = $this->form->selectFormFields($idForm);
		$strXMLFormField = '';
		if (! $blnSummary) {
			foreach ($arrFormFields as $arrFormField) {
				if ($arrFormField['idFormFieldType'] == 2) {
					$strFieldType = 'double';
				} else if ($arrFormField['idFormFieldType'] == 5) {
					$strFieldType = 'date';
				} else if ($arrFormField['idFormFieldType'] == 6) {
					$strFieldType = 'time';
				} else {
					$strFieldType = 'string';
				}
				$strFieldName = $this->strXMLFieldName($arrFormField['strName']);
				$strXMLFormField .= '<xsd:element maxOccurs="1" minOccurs="0" name="' . $strFieldName . '" nillable="true" type="xsd:' . $strFieldType . '"/>';
			}
		}
		$xmlSchema = simplexml_load_string('<xsd:schema 
			xmlns:gml="http://www.opengis.net/gml"
			xmlns:' . $this->strWFSViconNS . '="' . $this->strings->strSiteURL . '"
			xmlns:xsd="http://www.w3.org/2001/XMLSchema"
			elementFormDefault="qualified"
			targetNamespace="' . $this->strings->strSiteURL . '/' . $this->strWFSViconNS . '"
		>
		<xsd:import namespace="http://www.opengis.net/gml" schemaLocation="http://schemas.opengis.net/gml/3.1.1/base/gml.xsd"/>
		<xsd:complexType name="' . $idForm . 'Type">
		  <xsd:complexContent>
			<xsd:extension base="gml:AbstractFeatureType">
			  <xsd:sequence>
				<xsd:element maxOccurs="1" minOccurs="0" name="shape" nillable="true" type="gml:GeometryPropertyType"/>
				<xsd:element maxOccurs="1" minOccurs="0" name="ID" nillable="true" type="xsd:integer"/>
				<xsd:element maxOccurs="1" minOccurs="0" name="userCreation" nillable="true" type="xsd:string"/>
				<xsd:element maxOccurs="1" minOccurs="0" name="dateCreation" nillable="true" type="xsd:dateTime"/>
				<xsd:element maxOccurs="1" minOccurs="0" name="dateLastUpdate" nillable="true" type="xsd:dateTime"/>
				<xsd:element maxOccurs="1" minOccurs="0" name="attachedFiles" nillable="true" type="xsd:integer"/>
				<xsd:element maxOccurs="1" minOccurs="0" name="URL" nillable="true" type="xsd:string"/>
				' . $strXMLFormField . '
			  </xsd:sequence>
			</xsd:extension>
		  </xsd:complexContent>
		</xsd:complexType>
		<xsd:element name="' . $TYPENAME . '" substitutionGroup="gml:_Feature" type="' . $this->strWFSViconNS . ':' . $idForm . 'Type"/>
		</xsd:schema>');
		return $xmlSchema->asXML();
	}
	
	public function wfsGetFeatures($TYPENAME, $blnSummary, $strWFSURL) {
		//http://okmaps.org/geoserver/wfs?SERVICE=WFS&VERSION=1.0.0&REQUEST=GetFeature&TYPENAME=ogi:aoi_seismicity_centroids&SRSNAME=EPSG:4326
		//http://copadesvr02.copade.neuquen.gov.ar/geoserver/wfs?version=1.0.0&SERVICE=WFS&VERSION=1.0.0&REQUEST=GetFeature&TYPENAME=cite:actual_suelo&SRSNAME=EPSG:22182
		set_time_limit(300);
		$arrParams = explode('_', $TYPENAME);
		$idForm = array_pop($arrParams);
		$strXSI = $strWFSURL . '&amp;SERVICE=WFS&amp;VERSION=1.0.0&amp;REQUEST=DescribeFeatureType&amp;TYPENAME=' . $TYPENAME;
		$xmlFeatures = simplexml_load_string('<wfs:FeatureCollection
			xmlns="http://www.opengis.net/wfs"
			xmlns:wfs="http://www.opengis.net/wfs"
			xmlns:gml="http://www.opengis.net/gml"
			xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
			xmlns:' . $this->strWFSViconNS . '="' . $this->strings->strSiteURL . '"
			xsi:schemaLocation="' . $strXSI . ' http://www.opengis.net/wfs ' . $this->strings->strSiteURL . '/schema/WFS-basic.xsd"
		></wfs:FeatureCollection>');
		// Form Records
		if (! $idForm) $xmlFeatures->asXML();
		$arrFormRecords = $this->formrecord->selectFormRecords(0, 0, $idForm, 0, '', 'idFormRecord');
		// Count Records Shape Types
		$arrFormRecordsTypes = $this->arrCountFormRecordsTypes($arrFormRecords);
		$intJustType = 0;
		//$arrShapeTypesPosfix = array(1 => '_points', 2 => '_lines', 3 => '_polygons');		
		if (
			($arrFormRecordsTypes['intPoints'] == $arrFormRecordsTypes['intTotal']) || 
			($arrFormRecordsTypes['intLines'] == $arrFormRecordsTypes['intTotal']) || 
			($arrFormRecordsTypes['intPolygons'] == $arrFormRecordsTypes['intTotal'])
		) {
			if (($arrFormRecordsTypes['intPoints'] >= $arrFormRecordsTypes['intLines']) && ($arrFormRecordsTypes['intPoints'] >= $arrFormRecordsTypes['intPolygons'])) {
				$intJustType = 1;
			} else if (($arrFormRecordsTypes['intLines'] > $arrFormRecordsTypes['intPoints']) && ($arrFormRecordsTypes['intLines'] >= $arrFormRecordsTypes['intPolygons'])) {
				$intJustType = 2;
			} else if (($arrFormRecordsTypes['intPolygons'] >= $arrFormRecordsTypes['intLines']) && ($arrFormRecordsTypes['intPolygons'] >= $arrFormRecordsTypes['intPoints'])) {
				$intJustType = 3;
			}
			//$arrShapeTypesPosfix = array(1 => '', 2 => '', 3 => '');
		}
		foreach($arrFormRecords as $j => $arrFormRecord) {
			$gmlFeatureMember = $xmlFeatures->addChild('gml:featureMember','', 'http://www.opengis.net/gml');
			$viconRecord = $gmlFeatureMember->addChild($this->strWFSViconNS . ':' . $TYPENAME, '', $this->strings->strSiteURL);
			$viconRecord->addAttribute('fid', $arrFormRecord['idFormRecord']);
			$viconShape = $viconRecord->addChild($this->strWFSViconNS . ':shape', '', $this->strings->strSiteURL);
			// Print Record Coordinates
			if ($arrFormRecord['idShapeType'] == 1) {
				if (($intJustType > 0) && ($intJustType != 1)) { continue; }
				$gmlCoordinatesParent = $viconShape->addChild('gml:Point', '', 'http://www.opengis.net/gml');
			} else if ($arrFormRecord['idShapeType'] == 2) {
				if (($intJustType > 0) && ($intJustType != 2)) { continue; }
				$gmlCoordinatesParent = $viconShape->addChild('gml:LineString', '', 'http://www.opengis.net/gml');
			} else if ($arrFormRecord['idShapeType'] == 3) {
				if (($intJustType > 0) && ($intJustType != 3)) { continue; }
				$gmlPolygon = $viconShape->addChild('gml:Polygon', '', 'http://www.opengis.net/gml');
				$gmlPolygon->addAttribute('srsName', 'EPSG:4326');
				$gmlOuterBoundaryIs = $gmlPolygon->addChild('gml:outerBoundaryIs', '', 'http://www.opengis.net/gml');
				$gmlCoordinatesParent = $gmlOuterBoundaryIs->addChild('gml:LinearRing', '', 'http://www.opengis.net/gml');
			}
			$gmlCoordinatesParent->addAttribute('srsName', 'http://www.opengis.net/gml/srs/epsg.xml#4326');
			$gmlCoordinates = $gmlCoordinatesParent->addChild('gml:coordinates', $this->strings->strStringfyCoordinatesKML($arrFormRecord['arrVertex']), 'http://www.opengis.net/gml');
			$gmlCoordinates->addAttribute('xmlns:gml', 'http://www.opengis.net/gml');
			$gmlCoordinates->addAttribute('decimal', '.');
			$gmlCoordinates->addAttribute('cs', ',');
			$gmlCoordinates->addAttribute('ts', ' ');
			// Record Header Info
			$viconRecord->addChild('ID', $arrFormRecord['idFormRecord']);
			$viconRecord->addChild('userCreation', utf8_encode($arrFormRecord['strEmail']));
			$viconRecord->addChild('dateCreation', date('Y-m-d\TH:i:s', strtotime($arrFormRecord['dtCreation'])));
			$viconRecord->addChild('dateLastUpdate', date('Y-m-d\TH:i:s', strtotime($arrFormRecord['dtLastUpdate'])));
			$viconRecord->addChild('attachedFiles', count($arrFormRecord['arrFiles']));
			$viconRecord->addChild('URL', $this->strings->strSiteURL . '/' . $arrFormRecord['idFormRecord']);
			// Record Info
			if ($blnSummary) continue;
			$arrFormRecordDatas = $this->formrecord->selectFormRecordData($arrFormRecord['idFormRecord']);
			foreach($arrFormRecordDatas as $k => $arrFormRecordData) {
				$strValue = $arrFormRecordData['strValue'];
				// Format for time series				
				if ($arrFormRecordData['idFormFieldType'] == 7) $strValue = str_replace('<:>',", ", $strValue);
				$viconRecord->addChild($this->strXMLFieldName($arrFormRecordData['strName']), utf8_encode($strValue));
			}
		}
		return $xmlFeatures->asXML();
	}
	
	public function arrCountFormRecordsTypes($arrFormRecords) {
		$arrResult = array(
			"intTotal"		=> count($arrFormRecords),
			"intPoints"		=> 0,
			"intLines"		=> 0,
			"intPolygons"	=> 0
		);
		foreach($arrFormRecords as $i => $arrFormRecord) {
			if ($arrFormRecord['idShapeType'] == 1) {
				$arrResult['intPoints']++;
			} else if ($arrFormRecord['idShapeType'] == 2) {
				$arrResult['intLines']++;
			} else if ($arrFormRecord['idShapeType'] == 3) {
				$arrResult['intPolygons']++;
			}
		}
		return $arrResult;
	}
	
	public function strXMLFieldName($str) {
		$str = utf8_encode(strtolower(trim($this->strings->removeCharAccent($str))));
		if (strtolower($str) == 'id') { $str = 'id1'; }
		if (strtolower($str) == 'url') { $str = 'url1'; }
		$arr = array("[" => "", "]" => "", "=" => "", "<" => "", ">" => "", "," => "", ":" => "", "(" => "", ")" => "", "-" => "", " " => "_", "?" => "", "/" => "_", "*" => "", "\\" => "_", "@" => "");
		$str = strtr($str, $arr);
		// Remove number from beginning to avoid error
		$arr = array('0','1','2','3','4','5','6','7','8','9');
		if (array_search($str[0], $arr) !== FALSE) $str = substr($str, 1, strlen($str));
		return $str;
	}
	
	public function geodesignWFS($strToken, $REQUEST, $TYPENAME) {
		$strWFSURL = $this->strURLAPI . 'action=geodesign-wfs&amp;token=' . $strToken;
		// Verificando se as variveis esto OK.  Se no estiverem vou parar aqui
		if (!$strToken) {
			$strResposta = $this->strPrintErrorParametersInvalid('token', $strOutputFormat);
			return $strResposta;
		}
		if (strtolower($REQUEST) == 'describefeaturetype') {
			return $this->geodesignWFSDescribeFeatureType($TYPENAME);
		} else if ((strtolower($REQUEST) == 'getfeature') && ($TYPENAME)) {
			return $this->geodesignWFSGetFeatures($TYPENAME, $strWFSURL, $strToken);
		} 
				
		$xmlWFSCapabilities = new SimpleXMLElement('<WFS_Capabilities
		version="1.0.0"
		xmlns="http://www.opengis.net/wfs"
		xmlns:ogc="http://www.opengis.net/ogc"
		xmlns:gml="http://www.opengis.net/gml"
		xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
		xmlns:ows="http://www.opengis.net/ows" 
		></WFS_Capabilities>');
		
		$xmlFeatureTypeList = $xmlWFSCapabilities->addChild('FeatureTypeList');
		$arrProjects = $this->geodesign->selectUserProjects($strToken);
		foreach ($arrProjects as $arrProject) {
			$xmlFeatureType = $xmlFeatureTypeList->addChild('FeatureType');
			$xmlFeatureType->addChild('Title', utf8_encode($arrProject['projecttitle']));
			$xmlFeatureType->addChild('Name', 'prj_' . $arrProject['id']);
			$xmlFeatureType->addChild('SRS', 'EPSG:4326'); // WGS84
		}
		return $xmlWFSCapabilities->asXML();
	}
	
	public function geodesignWFSDescribeFeatureType($TYPENAME) {
		$xmlSchema = simplexml_load_string('<xsd:schema 
			xmlns:gml="http://www.opengis.net/gml"
			xmlns:' . $this->strWFSViconNS . '="' . $this->strings->strSiteURL . '"
			xmlns:xsd="http://www.w3.org/2001/XMLSchema"
			elementFormDefault="qualified"
			targetNamespace="' . $this->strings->strSiteURL . '"
		>
		<xsd:import namespace="http://www.opengis.net/gml" schemaLocation="http://schemas.opengis.net/gml/3.1.1/base/gml.xsd"/>
		<xsd:complexType name="' . $TYPENAME . 'Type">
		  <xsd:complexContent>
			<xsd:extension base="gml:AbstractFeatureType">
			  <xsd:sequence>
				<xsd:element maxOccurs="1" minOccurs="0" name="shape" nillable="true" type="gml:GeometryPropertyType"/>
				<xsd:element maxOccurs="1" minOccurs="0" name="id" nillable="true" type="xsd:integer"/>
				<xsd:element maxOccurs="1" minOccurs="0" name="description" nillable="true" type="xsd:string"/>
				<xsd:element maxOccurs="1" minOccurs="0" name="sysid" nillable="true" type="xsd:integer"/>
				<xsd:element maxOccurs="1" minOccurs="0" name="sysname" nillable="true" type="xsd:string"/>
				<xsd:element maxOccurs="1" minOccurs="0" name="author" nillable="true" type="xsd:string"/>
				<xsd:element maxOccurs="1" minOccurs="0" name="areatype" nillable="true" type="xsd:string"/>
				<xsd:element maxOccurs="1" minOccurs="0" name="color" nillable="true" type="xsd:string"/>
			  </xsd:sequence>
			</xsd:extension>
		  </xsd:complexContent>
		</xsd:complexType>
		<xsd:element name="' . $TYPENAME . '" substitutionGroup="gml:_Feature" type="' . $TYPENAME . 'Type"/>
		</xsd:schema>');
		return $xmlSchema->asXML();
	}
	
	public function geodesignWFSGetFeatures($TYPENAME, $strWFSURL, $strAPIToken) {
		set_time_limit(300);
		$idProject = str_replace("prj_", "", $TYPENAME);
		$strXSI = $strWFSURL . '&amp;SERVICE=WFS&amp;VERSION=1.0.0&amp;REQUEST=DescribeFeatureType&amp;TYPENAME=' . $TYPENAME;
		$xmlFeatures = simplexml_load_string('<wfs:FeatureCollection
			xmlns="http://www.opengis.net/wfs"
			xmlns:wfs="http://www.opengis.net/wfs"
			xmlns:gml="http://www.opengis.net/gml"
			xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
			xmlns:' . $this->strWFSViconNS . '="' . $this->strings->strSiteURL . '"
			xsi:schemaLocation="' . $strXSI . ' http://www.opengis.net/wfs ' . $this->strings->strSiteURL . '/schema/WFS-basic.xsd"
		></wfs:FeatureCollection>');
		
		$arrDiagrams = $this->geodesign->selectProjectDiagrams($idProject, $strAPIToken, true);
		foreach($arrDiagrams as $arrDiagram) {
			// If shape has no coordinates, skip it
			if (count($arrDiagram['arrCoordinates']) == 0) continue;
			$gmlFeatureMember = $xmlFeatures->addChild('gml:featureMember','', 'http://www.opengis.net/gml');
			$diagram = $gmlFeatureMember->addChild($this->strWFSViconNS . ':' . $TYPENAME, '', $this->strings->strSiteURL);
			$diagram->addAttribute('fid', $arrDiagram['id']);
			$diagramShape = $diagram->addChild($this->strWFSViconNS . ':shape', '', $this->strings->strSiteURL);
			$gmlPolygon = $diagramShape->addChild('gml:Polygon', '', 'http://www.opengis.net/gml');
			$gmlPolygon->addAttribute('srsName', 'EPSG:4326');
			$gmlOuterBoundaryIs = $gmlPolygon->addChild('gml:outerBoundaryIs', '', 'http://www.opengis.net/gml');
			$gmlCoordinatesParent = $gmlOuterBoundaryIs->addChild('gml:LinearRing', '', 'http://www.opengis.net/gml');
			$gmlCoordinatesParent->addAttribute('srsName', 'http://www.opengis.net/gml/srs/epsg.xml#4326');
			$gmlCoordinates = $gmlCoordinatesParent->addChild('gml:coordinates', $this->strings->strStringfyCoordinatesKML($arrDiagram['arrCoordinates']), 'http://www.opengis.net/gml');
			$gmlCoordinates->addAttribute('xmlns:gml', 'http://www.opengis.net/gml');
			$gmlCoordinates->addAttribute('decimal', '.');
			$gmlCoordinates->addAttribute('cs', ',');
			$gmlCoordinates->addAttribute('ts', ' ');
			// Diagram Info
			$diagram->addChild('id', $arrDiagram['id']);
			$diagram->addChild('description', utf8_encode($arrDiagram['description']));
			$diagram->addChild('sysid', $arrDiagram['sysid']);
			$diagram->addChild('sysname', utf8_encode($arrDiagram['sysname']));
			$diagram->addChild('author', utf8_encode($arrDiagram['author']));
			$diagram->addChild('areatype', utf8_encode($arrDiagram['areatype']));
			$diagram->addChild('color', utf8_encode($arrDiagram['color']));
		}
		return $xmlFeatures->asXML();
	}

	public function geodesignLiveKML($strAPIToken, $idProject) {
		// Verificando se as variveis esto OK.  Se no estiverem vou parar aqui
		if ((! $idProject) || (! $strAPIToken)) {
			return '<kml><Document><open>1</open><Folder><name>Invalid Project</name><gx:balloonVisibility>1</gx:balloonVisibility></Folder></Document></kml>';
		}		
		$arrOutput = $this->geodesign->exportDiagrams('KML', $idProject, $strAPIToken, '', true);
		return $arrOutput['strReport'];
	}

	public function geodesignCSV($strAPIToken, $idProject) {
		if ((!$strAPIToken) || (!$idProject)) {
			return $this->strPrintErrorParametersInvalid('token, idproject');
		}
		$strCSV = '';
		$arrDiagrams = $this->geodesign->selectProjectDiagrams($idProject, $strAPIToken, true);
		$arrFields = array('id', 'description', 'rank', 'author', 'sysname', 'areatype', 'color');
		$strCSV .= 'latitude;longitude;' . implode(';', $arrFields) . chr(13);
		foreach($arrDiagrams as $arrDiagram) {
			// Skip Diagrams without coordinates
			if (! count($arrDiagram['arrCoordinates'])) {continue;}
			$arrValues = array();
			$arrLats = array();
			$arrLngs = array();
			foreach($arrDiagram['arrCoordinates'] as $arrVertex) {
				$arrLats[] = $arrVertex['dblLatitude'];
				$arrLngs[] = $arrVertex['dblLongitude'];
			}
			$arrValues[] = implode(' ', $arrLats);
			$arrValues[] = implode(' ', $arrLngs);
			foreach ($arrFields as $strField) {
				if (($strField == 'color') && (! $arrDiagram[$strField])) { $arrDiagram[$strField] = 'ff0000';}
				$arrValues[] = utf8_decode($arrDiagram[$strField]);
			}
			$strCSV .= implode(';', $arrValues) . chr(13);
		}
		return $strCSV;
	}
	
	public function geodesignCSVProjects($strAPIToken) {
		if (!$strAPIToken) {
			return $this->strPrintErrorParametersInvalid('token');
		}
		$strCSV = '';
		$arrProjects = $this->geodesign->selectUserProjects($strAPIToken);
		$arrFields = array('projecttitle', 'id');
		$strCSV .= implode(';', $arrFields) . chr(13);
		foreach($arrProjects as $arrProject) {
			$arrValues = array();
			foreach ($arrFields as $strField) {
				$arrValues[] = utf8_decode($arrProject[$strField]);
			}
			$strCSV .= implode(';', $arrValues) . chr(13);
		}
		return $strCSV;
	}

	public function geodesignCSVDiagrams($strAPIToken, $idProject) {
		if ((!$strAPIToken) || (!$idProject)) {
			return $this->strPrintErrorParametersInvalid('token, idproject');
		}
		$strCSV = '';
		$arrDiagrams = $this->geodesign->selectProjectDiagrams($idProject, $strAPIToken, true);
		$arrFields = array('id', 'description', 'rank', 'author', 'sysname', 'areatype', 'color', 'color_rgb');
		$strCSV .= 'latitude;longitude;' . implode(';', $arrFields) . chr(13);
		foreach($arrDiagrams as $arrDiagram) {
			// Skip Diagrams without coordinates
			if (! count($arrDiagram['arrCoordinates'])) {continue;}
			$arrDiagram['color_rgb'] = 
				hexdec(substr($arrDiagram['color'],0,2)) . ',' . 
				hexdec(substr($arrDiagram['color'],2,2)) . ',' . 
				hexdec(substr($arrDiagram['color'],4,2));
			$arrValues = array();
			$arrLats = array();
			$arrLngs = array();
			foreach($arrDiagram['arrCoordinates'] as $arrVertex) {
				$arrLats[] = $arrVertex['dblLatitude'];
				$arrLngs[] = $arrVertex['dblLongitude'];
			}
			$arrValues[] = implode(' ', $arrLats);
			$arrValues[] = implode(' ', $arrLngs);
			foreach ($arrFields as $strField) {
				if (($strField == 'color') && (! $arrDiagram[$strField])) { $arrDiagram[$strField] = 'ff0000';}
				$arrValues[] = utf8_decode($arrDiagram[$strField]);
			}
			$strCSV .= implode(';', $arrValues) . chr(13);
		}
		return $strCSV;
	}
}
?>