<?php
class Datasource {
	public $strDefaultIcon				= 'fa fa-database';
	public $strDataSourceFolderName		= 'datasource';
	public $strDataSourceImageNoLogo	= 'img/data-source.png';
	public $strDataSourceScriptPHPLogo	= 'img/filetypes/php.png';
	public $intMaxDaysServiceOn			= 7;
	public $strFirstField				= 'search_keyword';
	public $arrDefaultGETParameters		= array(
		'q'				=> array('strName' => 'q', 'strDescription' => '[STRING] Filter results by specific keywords.', 'strExample' => 'copacabana'),
		'limit'			=> array('strName' => 'limit', 'strDescription' => '[INTEGER] Limit number of results to the specified number.', 'strExample' => '2')
	);
	public $arrDefaultFields			= array(
		'id'			=> array('strName' => 'id', 'blnMandatory' => true, 'strDescription' => '[STRING]', 'strExample' => 'abc123456'),
		'date'			=> array('strName' => 'date', 'blnMandatory' => true, 'strDescription' => '[STRING] ISO8601 or MySQL Format YYYY-MM-DD HH:MM:SS', 'strExample' => '2016-12-01 18:00:00'),
		'shapetype'		=> array('strName' => 'shapetype', 'blnMandatory' => false, 'strDescription' => '[INTEGER] Possible Values: 1 = Point; 2 = Polyline; 3 = Polygon', 'strExample' => '1'),
		'color'			=> array('strName' => 'color', 'blnMandatory' => false, 'strDescription' => '[STRING] Shape color in 6-digit hexadecimal format', 'strExample' => 'ff0000'),
		'coordinates'	=> array('strName' => 'coordinates', 'blnMandatory' => false, 'strDescription' => '[FLOAT,FLOAT] longitude,latitude - decimal degrees', 'strExample' => '-43.123456,-23.123456'),
		'files' 		=> array('strName' => 'files', 'blnMandatory' => false, 'strDescription' => '[STRING] File(s) URL(s) separated by semicolon (;)','strExample' => 'http://www.viconsaga.com.br/images/abc.jpg;http://www.viconsaga.com.br/images/efg.jpg')
	);

	public function __construct($database) {
		$this->database = $database;

		include_once 'strings.php';
		$strings = new Strings();
		$this->strings = $strings;
		
		include_once 'form.php';
		$form = new Form($database);
		$this->form = $form;
		
		include_once 'formrecord.php';
		$formrecord = new Formrecord($database);
		$this->formrecord = $formrecord;
		
		session_start();
	}


	public function selectDataSources($idProject = 0, $idDataSources = 0, $blnJustProjectOrOthersActivesAndPublics = false, $blnJustActives = false) {
		$arrIDs = explode(',', $idDataSources);
		$query =
		"SELECT
			ds.idProject,
			ds.idDataSource,
			ds.strName,
			ds.strSiteURL,
			ds.strLogoFileName,
			ds.strScriptPHPFileName,
			ds.intUpdateFrequencyMin,
			ds.strGETParameterq,
			ds.strGETParameterlimit,
			ds.strResultTimeSeriesFields,
			ds.blnActive,
			ds.blnPublic
		FROM
			datasource ds
		WHERE 
		ds.idDataSource > 1
		" . ($idProject > 0 ? " AND ds.idProject = " . $idProject : "") . "
		" . ($idDataSources != 0 ? " AND ds.idDataSource IN (" . implode(",", $arrIDs). ")" : "") . "
		" . ($blnJustActives ? " AND ds.blnActive = 1" : "") . "
		" . ($blnJustProjectOrOthersActivesAndPublics ? " OR (ds.idDataSource > 1 AND ds.idProject <> " . $idProject . " AND ds.blnActive = 1 AND ds.blnPublic = 1)" : "") . "
		ORDER BY 
			" . ($idProject ? "ds.idProject=" . $idProject . " DESC, " : "") . "
			ds.idDataSource DESC
		";
		$result = $this->database->executeQuery($query);
		$result = $this->database->prepareReturn($result);
		foreach ($result as $idLine => $item) {
			// Formating full path for logo image
			$result[$idLine]['strLogoFileNameFullPath'] = $this->strDataSourceFolderName . '/' . $result[$idLine]['strLogoFileName'];
			if ((! $result[$idLine]['strLogoFileName']) | (! file_exists($result[$idLine]['strLogoFileNameFullPath']))) {
				$result[$idLine]['strLogoFileNameFullPath'] = $this->strDataSourceImageNoLogo;
			}
			// Formating full path for script php
			$result[$idLine]['strScriptPHPFileNameFullPath'] = $this->strDataSourceFolderName . '/' . $result[$idLine]['strScriptPHPFileName'];
			$result[$idLine]['strScriptPHPFileNameFullURL'] = $this->strings->strSiteURL . '/' . $result[$idLine]['strScriptPHPFileNameFullPath'];
			if ((! $result[$idLine]['strScriptPHPFileName']) | (! file_exists($result[$idLine]['strScriptPHPFileNameFullPath']))) {
				$result[$idLine]['strScriptPHPFileNameFullPath'] = '';
				$result[$idLine]['strScriptPHPFileNameFullURL'] = '';
			}
			// Array Containing Time Series Field List
			$result[$idLine]['arrResultTimeSeriesFields'] = explode(',', $result[$idLine]['strResultTimeSeriesFields']);
			// Return DataSource Request Parameters
			$arrParameters = $this->selectDataSourceParameters($result[$idLine]['idDataSource']);
			$strParameters = '';
			$arrParametersTest = array();
			foreach ($arrParameters as $k => $arrParameter) {
				$strLinkParameterGET = '';
				foreach($this->arrDefaultGETParameters as $arrDefaultGETParameter) {
					if ($arrParameter['strName'] == $result[$idLine]['strGETParameter' . $arrDefaultGETParameter['strName']]) {
						$strLinkParameterGET = '<span style="color:#FF0000">[' . $arrDefaultGETParameter['strName'] . ']</span>';
						$arrParametersTest[] = $arrParameter['strName'] . '=' . $arrDefaultGETParameter['strExample'];
						break;
					}
				}
				if (($arrParameter['blnMandatory']) && (strpos(implode('&', $arrParametersTest), $arrParameter['strName'] . '=') === FALSE)) {
					$arrParametersTest[] = $arrParameter['strName'] . '=' . ($arrParameter['strDefaultValue'] != '' ? $arrParameter['strDefaultValue'] : '');
				}
				$strParameters .= $arrParameter['strName'] . ($arrParameter['blnMandatory'] ? '*' : '') . $strLinkParameterGET . ($k < count($arrParameters)-1 ? ', ' : '');
			}
			$result[$idLine]['arrParameters'] = $arrParameters;
			$result[$idLine]['strParameters'] = $strParameters;
			$result[$idLine]['strParametersTest'] = implode('&', $arrParametersTest);
		}
		return $result;
	}
	
	public function insertDataSource($idProject = 0, $strName, $strSiteURL, $intUpdateFrequencyMin = 60, $strGETParameterq = '', $strGETParameterlimit = '', $strResultTimeSeriesFields = '') {
		$query = "
			INSERT INTO 
				datasource
			SET 
				idProject					= '" . $idProject . "',
				strName						= '" . $strName . "',
				strSiteURL					= '" . $strSiteURL . "',
				intUpdateFrequencyMin		= " . $intUpdateFrequencyMin . ",
				strGETParameterq			= '" . $strGETParameterq . "',
				strGETParameterlimit		= '" . $strGETParameterlimit . "',
				strResultTimeSeriesFields	= '" . $strResultTimeSeriesFields . "'
		";
		$result = $this->database->executeQuery($query);
		$arrResult = array();
		$arrResult['idDataSource'] = $this->database->getLastInsertedID();
		return $arrResult;
	}
	
	public function updateDataSource($idDataSource, $strName, $strSiteURL, $intUpdateFrequencyMin = 60, $strGETParameterq = '', $strGETParameterlimit = '', $strResultTimeSeriesFields = '') {
		$query = "
			UPDATE 
				datasource
			SET 
				strName					= '" . $strName . "',
				strSiteURL				= '" . $strSiteURL . "',
				intUpdateFrequencyMin	= " . $intUpdateFrequencyMin . ",
				strGETParameterq			= '" . $strGETParameterq . "',
				strGETParameterlimit		= '" . $strGETParameterlimit . "',
				strResultTimeSeriesFields	= '" . $strResultTimeSeriesFields . "'
			WHERE
				idDataSource= " . $idDataSource . "
		";
		$result = $this->database->executeQuery($query);
		return $arrResult;
	}
	
	public function deleteDataSource($idDataSource) {
		// Delete Logo and Script Files
		$arrDataSource = $this->selectDataSources(0, $idDataSource);
		if (strpos($arrDataSource[0]['strLogoFileNameFullPath'],'img/') === FALSE) {
			@unlink($arrDataSource[0]['strLogoFileNameFullPath']);
		}
		@unlink($arrDataSource[0]['strScriptPHPFileName']);
		
		// Set all forms to Vicon
		$query = "UPDATE FROM form SET idDataSource=1 WHERE idDataSource=" . $idDataSource;
		$this->database->executeQuery($query);
		
		// Delete Datasource Search Result
		$query = "DELETE FROM datasourceusersearchresult WHERE idDataSource=" . $idDataSource;
		$result = $this->database->executeQuery($query);

		// Delete Datasource User Search
		$query = "DELETE FROM datasourceusersearch WHERE WHERE idDataSource=" . $idDataSource;
		$result = $this->database->executeQuery($query);

		// Delete Datasource Search Parameters
		$query = "DELETE FROM datasourceparameter WHERE idDataSource=" . $idDataSource;
		$result = $this->database->executeQuery($query);

		// Delete Datasource
		$query = "DELETE FROM datasource WHERE idDataSource=" . $idDataSource;
		$result = $this->database->executeQuery($query);		
		return $this->database->getNumAffectedRows();
	}

	public function updateDataSourceProperty($idDataSource, $strField, $strValue) {
		$query = "UPDATE datasource SET " . $strField . "='" . $strValue . "' WHERE idDataSource=" . $idDataSource;
		$result = $this->database->executeQuery($query);
		return $this->database->getNumAffectedRows();
	}

	public function updateDataSourceLogo($idDataSource, $strFileName) {
		$arrResult = array();
		// Deleting current file
		$arrDataSource = $this->selectDataSources(0, $idDataSource);
		$strFileDelete = $arrDataSource[0]['strLogoFileNameFullPath'];
		if (strpos($strFileDelete,'img/') === FALSE) {
			@unlink($strFileDelete);
		}
		// Setting Uploaded File Name
		$strSourceFileFullPathName = $this->strings->strSiteTmpFileFolder . '/' . $strFileName;
	    $strFileExt = explode(".", $strFileName);
	    $strFileExt = strtolower(array_pop($strFileExt));
		$arrDataSourceName = explode(' ', $arrDataSource[0]['strName']);
		$strDestinationFileName = ($arrDataSourceName[0] ? strtolower($arrDataSourceName[0]) : $idDataSource) . $this->strings->generateRandomString(2) . '.' . $strFileExt;
		$strDestinationFileFullPathName = $this->strDataSourceFolderName . '/' . $strDestinationFileName;
		if (! $strFileName) {
			$strDestinationFileName = '';
			$strDestinationFileFullPathName = '';
		}
		$query = "UPDATE datasource SET strLogoFileName='" . $strDestinationFileName . "' WHERE idDataSource=" . $idDataSource;
		$result = $this->database->executeQuery($query);
		// Now moving file and updating table
		if ($strFileName) {
			copy($strSourceFileFullPathName, $strDestinationFileFullPathName);
			$arrResult['strLogoFileNameFullPath'] = $strDestinationFileFullPathName;
		} else {
			$arrResult['strLogoFileNameFullPath'] = $this->strDataSourceImageNoLogo;
		}
		return $arrResult;
	}
	
	public function updateDataSourceScript($idDataSource, $strFileName) {
		$arrResult = array();
		$arrDataSource = $this->selectDataSources(0, $idDataSource);
		// Setting Uploaded File Name
		$strSourceFileFullPathName = $this->strings->strSiteTmpFileFolder . '/' . $strFileName;
	    $strFileExt = explode(".", $strFileName);
	    $strFileExt = strtolower(array_pop($strFileExt));
		$arrDataSourceName = explode(' ', $arrDataSource[0]['strName']);
		$strDestinationFileName = ($arrDataSourceName[0] ? strtolower($arrDataSourceName[0]) : $idDataSource) . '.' . $strFileExt;
		$strDestinationFileFullPathName = $this->strDataSourceFolderName . '/' . $strDestinationFileName;
		// Deleting current file
		@unlink($arrDataSource[0]['strScriptPHPFileNameFullPath']);
		// Now moving file and updating table
		if (! $strFileName) {
			$strDestinationFileName = '';
			$strDestinationFileFullPathName = '';
		}
		$query = "UPDATE datasource SET strScriptPHPFileName='" . $strDestinationFileName . "' WHERE idDataSource=" . $idDataSource;
		$result = $this->database->executeQuery($query);
		if ($strFileName) {
			copy($strSourceFileFullPathName, $strDestinationFileFullPathName);
		}
		$arrResult['strScriptPHPFileNameFullPath'] = $strDestinationFileFullPathName;
		return $arrResult;
	}
	
	public function intCountDataSources($idProject = 0) {
		$query = "SELECT COUNT(idDataSource) as `intNum` FROM datasources" . ($idProject >= 0 ? " WHERE idProject=" . $idProject : "");
		$result = $this->database->executeQuery($query);
		$result = $this->database->prepareReturn($result);
		return  $result[0]['intNum'];
	}
	
	// datasourceusersearchresult
	public function selectDataSourceUserSearchResults($idDataSource, $idUser){
	  $arrResult = array();
	  $query = "SELECT DISTINCT strID,dtCreated,idFormRecord FROM datasourceusersearchresult WHERE idDataSource=" . $idDataSource . " AND idUser=" . $idUser;
	  $result = $this->database->executeQuery($query);
	  $result = $this->database->prepareReturn($result);
	  foreach($result as $item) {
		  $arrResult[$item['strID']][$item['dtCreated']] = $item['idFormRecord'];
		  $arrResult[$item['strID']] = $item['idFormRecord'];
	  }
	  return $arrResult;
	}
	
	public function arrXMLToRecord($xmlRecord) {
		// Attached files
		$arrRecord = array();
		$strFiles = (string)$xmlRecord->{$this->arrDefaultFields['files']['strName']};
		$arrFiles = $strFiles ? explode(';', $strFiles) : array();
		$arrVertexs = explode(' ', (string)$xmlRecord->{$this->arrDefaultFields['coordinates']['strName']});
		$arrCoordinates = array();
		foreach($arrVertexs as $str){
			$arr = explode(',', $str);
			// If no coords, by default set 0,0
			$arrCoordinates[] = array('dblLatitude' => ($arr[1] ? $arr[1] : 0), 'dblLongitude' => ($arr[0] ? $arr[0] : 0));
		}
		$arrRecord['strID'] = (string)$xmlRecord->{$this->arrDefaultFields['id']['strName']};
		$arrRecord['dtCreation'] = (string) $xmlRecord->{$this->arrDefaultFields['date']['strName']};
		$arrRecord['strDate'] = date("Y-m-d H:i:s", strtotime($arrRecord['dtCreation']));
		$idShapeType = (string)$xmlRecord->{$this->arrDefaultFields['shapetype']['strName']};
		$arrRecord['idShapeType'] = ($idShapeType > 0 ? $idShapeType : (count($arrCoordinates) == 1 ? 1 : 3));
		$strShapeColor = str_replace('#','',(string)$xmlRecord->{$this->arrDefaultFields['color']['strName']});
		$arrRecord['strShapeColor'] = ($strShapeColor ? $strShapeColor : $this->strings->strGenerateRandonColor());
		$arrRecord['arrCoordinates'] = $arrCoordinates;
		$arrRecord['arrFiles'] = $arrFiles;
		$arrRecord['XML'] = $xmlRecord;
		return $arrRecord;
	}
	
	public function insertDataSourceUserSearchResult($idUser, $idDataSource, $idFormRecord, $arrRecord) {
		$query = "
			INSERT INTO 
				datasourceusersearchresult
			SET 
				idUser			= " . $idUser . ",
				idDataSource	= " . $idDataSource . ",
				idFormRecord	= " . $idFormRecord . ",
				strID			= '" . $arrRecord['strID'] . "',
				dtCreated		= '" . $arrRecord['dtCreation'] . "',
				dblLatitude		= '" . $arrRecord['arrCoordinates'][0]['dblLatitude'] . "',
				dblLongitude	= '" . $arrRecord['arrCoordinates'][0]['dblLongitude'] . "',
				strAttachedFiles= '" . implode(';', $arrRecord['arrFiles']) . "'
		";
		$result = $this->database->executeQuery($query);
		return $this->database->getLastInsertedID();
	}
	
	public function deleteDataSourceUserSearchResult($idUser = 0, $idDataSource = 0) {
		$query = "DELETE FROM datasourceusersearchresult WHERE " . 
			($idUser > 0 ? "idUser=" . $idUser : "") . 
			($idDataSource > 0 ? "idDataSource=" . $idDataSource : "")
		;
		$result = $this->database->executeQuery($query);
		return $this->database->getNumAffectedRows();
	}
	
	public function search($idProject, $idUser, $idDataSource, $q) {
		$arrResults = array();
		$arrDataSource = $this->selectDataSources(0, $idDataSource);
		$arrDataSource = $arrDataSource[0];
		if (! $arrDataSource['strScriptPHPFileNameFullURL']) { return false; } 
		// Update last gather for current date/time 
		$this->updateDataSourceUserSearchDate($idDataSource, $idUser);
		// User Predefined GET Parameters		
		$arrDataSourceParametersUser = $this->selectDataSourceParametersUser($idDataSource, $idUser);
		$arrParameters = array();
		foreach ($arrDataSourceParametersUser as $arrDataSourceParameterUser) { 
			$arrParameters[] = $arrDataSourceParameterUser['strName'] . '=' . $arrDataSourceParameterUser['strValue'];
		}
		// Checking if there is any mandatory parameter without user defined value.  In this case fill it with its Default Value
		foreach ($arrDataSource['arrParameters'] as $arrParameter) {
			if (($arrParameter['blnMandatory']) && (strpos(implode('&', $arrParameters), $arrParameter['strName'] . '=') === FALSE)) {
				$arrParameters[] = $arrParameter['strName'] . '=' . ($arrParameter['strDefaultValue'] != '' ? $arrParameter['strDefaultValue'] : '');
			}
		}
		// Change , for + for search for many keywords (+ is OR)
		$q = str_replace(',','+',$q);
		if ($q) {
			$arrParameters[] = ($arrDataSource['strGETParameterq'] ? $arrDataSource['strGETParameterq'] : $this->arrDefaultGETParameters['q']['strName']) . '=' . urlencode($q);
		}
		$strURL = $arrDataSource['strScriptPHPFileNameFullURL'] . '?' . implode('&', $arrParameters);
		//$this->strings->log($strURL, 'tmp/out.txt', true);
		$strResult = @$this->strings->processUrl($strURL);
		if (! $strResult) { return $arrResults; }
		$xmlRecords = simplexml_load_string($strResult);
		if (count($xmlRecords) == 0) return $arrResults;
		$idForm = $this->idFormFromProjectDataSource($idProject, $arrDataSource['idDataSource']);
		if ($idForm === FALSE) {
			$idForm = $this->createFormFromRecord($idProject, $idUser, $arrDataSource, $xmlRecords->{'record'}[0]);
		}
		$arrInserts = array();
		$arrFormFields = $this->form->selectFormFields($idForm, 0, 0, true); 
		$idFormRecord = $this->database->intSelectNextTableKey('formrecord', 'idFormRecord');
		$idFormRecordField = $this->database->intSelectNextTableKey('formrecordfield', 'idFormRecordField');
		// Checking if already imported result to avoid duplicated entry
		$arrIDs = $this->selectDataSourceUserSearchResults($idDataSource, $idUser);
		foreach ($xmlRecords as $xmlRecord) {
			$arrRecord = $this->arrXMLToRecord($xmlRecord);
			if (($arrRecord['strID']) && (array_key_exists($arrRecord['strID'], $arrIDs) !== FALSE)) {
				// If has same ID but distinct date, it's propably a time series
				if (
					(count($arrDataSource['arrResultTimeSeriesFields']) > 0) && 
					(! $arrIDs[$arrRecord['strID']][$arrRecord['strDate']])
				){
					$idFormRecord2 = $arrIDs[$arrRecord['strID']];
					if (! $idFormRecord2) continue;
					foreach($arrDataSource['arrResultTimeSeriesFields'] as $strFielName) {
					  $arrInserts['formrecordfield'][] = "("  . $idFormRecordField . "," . $arrFormFields[$strFielName]['idFormField'] . "," . $idFormRecord2 . ")";
					  $arrInserts['formrecordfieldtimeserie'][] = "(" . $idFormRecordField . ",'" . $arrRecord['strDate'] . "','" . (string)$xmlRecord->{$strFielName} . "')";
					  $idFormRecordField++;
					}
					$arrIDs[$arrRecord['strID']][$arrRecord['strDate']] = $idFormRecord2;
					$arrIDs[$arrRecord['strID']] = $idFormRecord2;
					$this->insertDataSourceUserSearchResult($idUser, $idDataSource, $idFormRecord2, $arrRecord);
					$arrResults[] = $arrRecord;
				}
				continue;
			}
			$arrIDs[$arrRecord['strID']][$arrRecord['strDate']] = $idFormRecord;
			$arrIDs[$arrRecord['strID']] = $idFormRecord;
			$this->insertDataSourceUserSearchResult($idUser, $idDataSource, $idFormRecord, $arrRecord);
			$this->insertFormRecordFromRecord($idForm, $idUser, $idFormRecord, $idFormRecordField, $arrRecord, $arrFormFields, $arrInserts, $q);
			$arrResults[] = $arrRecord;
		}
		// Insert into Database
		$this->insertFormRecords($arrInserts);
		return $arrResults;
	}
	
	public function idFormFromProjectDataSource($idProject, $idDataSource) {
		$query = "SELECT idForm FROM form WHERE idProject=" . $idProject . " AND idDataSource=" . $idDataSource;
		$result = $this->database->executeQuery($query);
		$result = $this->database->prepareReturn($result);
		return (count($result) ? $result[0]['idForm'] : false);
	}
	
	public function createFormFromRecord($idProject, $idUser, $arrDataSource, $xmlRecord) {
		// Copy logo to marker
		$arrMarker = $this->form->uploadFileMarker($idProject, $arrDataSource['strLogoFileNameFullPath'], true);
		// Create form
		$arrForm = $this->form->insertForm($idUser, $idProject, $arrDataSource['strName'], $arrMarker['idMarker'], $arrDataSource['idDataSource']);
		// Create first field customized
		$this->form->insertFormField($arrForm['idForm'], 1, $this->strFirstField);
		// Read XML seeking for leaf values
		$arrXMLLeafs = $this->arrXMLLeafNodes($xmlRecord);
		// Create form fields for each record field
		foreach ($arrXMLLeafs as $arrXMLLeaf) {
		  // Defining field type
		  $idFormFieldType = $this->intFormFieldType($arrDataSource, $arrXMLLeaf);
		  $this->form->insertFormField($arrForm['idForm'], $idFormFieldType, $arrXMLLeaf['strName']);
		}
		return $arrForm['idForm'];
	}
	
	public function intFormFieldType($arrDataSource, $arrXMLLeaf) {
		$idFormFieldType = 1;
		if (is_numeric($arrXMLLeaf['strValue'])) { // Is a Numeric Field
			$idFormFieldType = 2;
		} else if (strtotime($arrXMLLeaf['strValue']) !== FALSE) {
			$idFormFieldType = 5; // Is a Date Field
		}
		foreach($arrDataSource['arrResultTimeSeriesFields'] as $strResultTimeSeriesField) {
		  if ($arrXMLLeaf['strName'] == $strResultTimeSeriesField) {
			  $idFormFieldType = 7; // Time Series
		  }
		}
		return $idFormFieldType;
	}
	
	public function arrXMLLeafNodes($xml, &$arrLeafNodes = array(), $strBranch = '') {
	  foreach ($xml as $node) {
		if ($node->children()) {
		  $this->arrXMLLeafNodes($node, $arrLeafNodes, $node->getName() . ':');
		} else {
		  $strValue = str_replace('<![CDATA[','',$strValue);
		  $strValue = str_replace(']]>','',$strValue);
		  $strValue = utf8_decode(trim($node));
		  $arrLeafNodes[] = array(
			'strName' => $strBranch . $node->getName(),
			'strValue' => $strValue
		  );
		}
	  }
	  return $arrLeafNodes;
	}
	
	public function insertFormRecordFromRecord($idForm, $idUser, &$idFormRecord, &$idFormRecordField, $arrRecord, $arrFormFieldsByName, &$arrInserts, $q) {
		$arrInserts['formrecord'][] = "(" . $idFormRecord . "," . $idUser . "," . $idForm . ",4," . $arrRecord['idShapeType'] . "," . ($arrRecord['idShapeType'] > 1 ? "'" . $arrRecord['strShapeColor'] . "'" : "NULL") . ",'" . $arrRecord['dtCreation'] . "','" . $arrRecord['dtCreation'] . "')";
		foreach($arrRecord['arrCoordinates'] as $i => $arrVertex){
			$arrInserts['formrecordvertex'][] = "(" . $idFormRecord . "," . $arrVertex['dblLatitude'] . "," . $arrVertex['dblLongitude'] . "," . $i . ")";
		}
		// 1st Field Customized
		$arrInserts['formrecordfield'][] = "("  . $idFormRecordField . "," . $arrFormFieldsByName[$this->strFirstField]['idFormField'] . "," . $idFormRecord . ")";
		$arrInserts['formrecordfieldtext'][] = "(" . $idFormRecordField . ",'" . utf8_decode($q) . "')";
		$idFormRecordField++;
		// Read XML seeking for leaf values
		$arrXMLLeafs = $this->arrXMLLeafNodes($arrRecord['XML']);
		// Result field values
		foreach ($arrXMLLeafs as $arrXMLLeaf) {
			$strName = $arrXMLLeaf['strName'];			
			// Check if field exists in form field list.  If not, do not bring it
			if (array_key_exists($strName, $arrFormFieldsByName) === FALSE) { continue; }
			$strValue = mysql_real_escape_string($arrXMLLeaf['strValue']);
			$arrInserts['formrecordfield'][] = "("  . $idFormRecordField . "," . $arrFormFieldsByName[$strName]['idFormField'] . "," . $idFormRecord . ")";
			if ($arrFormFieldsByName[$strName]['idFormFieldType'] == 1) {
				$arrInserts['formrecordfieldtext'][] = "(" . $idFormRecordField . ",'" . $strValue . "')";
			} else if ($arrFormFieldsByName[$strName]['idFormFieldType'] == 2) {
				$arrInserts['formrecordfieldnumeric'][] = "(" . $idFormRecordField . ",'" . $strValue . "')";
			} else if ($arrFormFieldsByName[$strName]['idFormFieldType'] == 5) {
				$arrInserts['formrecordfielddate'][] = "(" . $idFormRecordField . ",'" . date("Y-m-d", strtotime($strValue)) . "')";
			} else if ($arrFormFieldsByName[$strName]['idFormFieldType'] == 7) {
				$arrInserts['formrecordfieldtimeserie'][] = "(" . $idFormRecordField . ",'" . date("Y-m-d H:i:s", strtotime($arrRecord['dtCreation'])) . "','" . $strValue . "')";
			}
			$idFormRecordField++;
		}
		// Insert Attached Files
		foreach($arrRecord['arrFiles'] as $i => $strFileURL){
			$strFileExt = explode(".", $strFileURL);
			$strFileExt = strtolower(array_pop($strFileExt));
			// If file has no extension, set default as jpg
			if (! $strFileExt) $strFileURL = $strFileExt[0] . '.jpg';
			$arrInserts['formrecordfile'][] = "(" . $idFormRecord . ",'" . $strFileURL . "','" . basename($strFileURL) . "',NULL," . $i . ")";
		}
		$idFormRecord++;
		return true;
	}
	
	public function insertFormRecords($arrInserts){
		// formrecord
		if (count($arrInserts['formrecord'])) {
			$query = "INSERT INTO formrecord (idFormRecord, idUser, idForm, idDevice, idShapeType, strCustomMarkerRGBColor, dtCreation, dtLastUpdate) VALUES " . implode(',', $arrInserts['formrecord']);
			$result = $this->database->executeQuery($query);
		}
		// formrecordvertex
		if (count($arrInserts['formrecordvertex'])) {
		  $query = "INSERT INTO formrecordvertex (idFormRecord, dblLatitude, dblLongitude, intPosition) VALUES " . implode(',', $arrInserts['formrecordvertex']);
		  $result = $this->database->executeQuery($query);
		}
		// formrecordfield
		if (count($arrInserts['formrecordfield'])) {
		  $query = "INSERT INTO formrecordfield (idFormRecordField, idFormField, idFormRecord) VALUES " . implode(',', $arrInserts['formrecordfield']);
		  $result = $this->database->executeQuery($query);
		}
		// formrecordfieldtext
		if (count($arrInserts['formrecordfieldtext'])) {
		  $query = "INSERT INTO formrecordfieldtext (idFormRecordField, strValue) VALUES " . implode(',', $arrInserts['formrecordfieldtext']);
		  $result = $this->database->executeQuery($query);
		}
		// formrecordfieldnumeric
		if (count($arrInserts['formrecordfieldnumeric'])) {
		  $query = "INSERT INTO formrecordfieldnumeric (idFormRecordField, dblValue) VALUES " . implode(',', $arrInserts['formrecordfieldnumeric']);
		  $result = $this->database->executeQuery($query);
		}
		// formrecordfielddate
		if (count($arrInserts['formrecordfielddate'])) {
		  $query = "INSERT INTO formrecordfielddate (idFormRecordField, dtValue) VALUES " . implode(',', $arrInserts['formrecordfielddate']);
		  $result = $this->database->executeQuery($query);
		}
		// formrecordfieldtimeserie
		if (count($arrInserts['formrecordfieldtimeserie'])) {
		  $query = "INSERT INTO formrecordfieldtimeserie (idFormRecordField, dtDateTime, strValue) VALUES " . implode(',', $arrInserts['formrecordfieldtimeserie']);
		  $result = $this->database->executeQuery($query);
		}
		// formrecordfile
		if (count($arrInserts['formrecordfile'])) {
		  $query = "INSERT INTO formrecordfile (idFormRecord, strFileName, strFileOriginalName, strDescription, intPosition) VALUES " . implode(',', $arrInserts['formrecordfile']);
		  $result = $this->database->executeQuery($query);
		}
	}
	
	public function scriptVerify($idDataSource) {
		$arrDataSource = $this->selectDataSources(0, $idDataSource);
		$arrDataSource = $arrDataSource[0];
		if (! $arrDataSource['strScriptPHPFileNameFullPath']) { return ''; }
		$arrBlnVerify = array();
		$strPanel = '';
		// Checking Mandatory Fields
		$arrFieldsResult = $this->arrCheckFileHasStrings($arrDataSource['strScriptPHPFileNameFullPath'], $this->arrDefaultFields);
		foreach($this->arrDefaultFields as $arrDefaultField) {
		  $arrBlnVerify[] = array(
			  'strAttributeName'	=> $arrDefaultField['strName'],
			  'blnExists'			=> $arrFieldsResult[$arrDefaultField['strName']],
			  'blnMandatory'		=> $arrDefaultField['blnMandatory']
		  );
		}
		// Printing Formated
		foreach ($arrBlnVerify as $i => $item) {
			$strPanel .= 
				'<img src="img/' . ($item['blnExists'] ? 'yes' : 'no'). '.png" width="16" height="16"> ' . 
				($item['blnMandatory'] == 1 ? '<span style="color:#FF0000;font-weight:bold;cursor:help" data-rel="tooltip">*</span> ' : '') . 
				$item['strAttributeName'] . ($i < count($arrBlnVerify)-1  ? ' | ' : '');
		}
		return $strPanel;
	}
	
	// Open $strFileName PHP script and search for file $strAttributeName ; 
	public function arrCheckFileHasStrings($strFileName, $arrDefaultFields) {
		$arrResult = array();
		if (! file_exists($strFileName)) return false;
		$strFileContent = file_get_contents($strFileName);
		foreach ($arrDefaultFields as $arrDefaultField) {
			$arrResult[$arrDefaultField['strName']] = (strpos($strFileContent, "'" . $arrDefaultField['strName'] . "'") > 0);
		}
		return $arrResult;
	}
	
	// Datasource Parameters
	public function selectDataSourceParameters($idDataSource = 0, $idDataSourceParameter = 0, $blnJustMandatory = 0) {
		$query = "SELECT
			dsp.idDataSourceParameter,
			dsp.idDataSource,
			dsp.strName,
			dsp.txtDescription,
			dsp.strDefaultValue,
			dsp.blnMandatory
		FROM
			datasourceparameter dsp
		WHERE 1 > 0
		" . ($idDataSourceParameter > 0 ? " AND dsp.idDataSourceParameter = " . $idDataSourceParameter : "") . "
		" . ($idDataSource > 0 ? " AND dsp.idDataSource = " . $idDataSource : "") . "
		" . ($blnJustMandatory > 0 ? " AND dsp.blnMandatory = 1 " : "") . "
		ORDER BY 
			dsp.blnMandatory DESC, dsp.strName
		";
		$result = $this->database->executeQuery($query);
		$result = $this->database->prepareReturn($result);
		return $result;
	}
	
	public function insertDataSourceParameter($idDataSource) {
		$query = "INSERT INTO datasourceparameter SET idDataSource=" . $idDataSource;
		$result = $this->database->executeQuery($query);
		$arrResult = array();
		$arrResult['idDataSourceParameter'] = $this->database->getLastInsertedID();
		$arrResult['strName'] = '';
		$arrResult['txtDescription'] = '';
		$arrResult['strDefaultValue'] = '';
		$arrResult['blnMandatory'] = '0';
		return $arrResult;
	}
	
	public function updateDataSourceParameter($idDataSourceParameter, $strName, $txtDescription, $strDefaultValue, $blnMandatory) {
		$txtDescription = str_replace('"','',$txtDescription);
		$query = "
			UPDATE 
				datasourceparameter
			SET 
				strName			= '" . utf8_decode(mysql_real_escape_string(trim($strName))) . "',
				txtDescription	= '" . utf8_decode(mysql_real_escape_string(trim($txtDescription))) . "',
				strDefaultValue = '" . utf8_decode(mysql_real_escape_string(trim($strDefaultValue))) . "',
				blnMandatory	= " .  $blnMandatory . "
			WHERE
				idDataSourceParameter	= " . $idDataSourceParameter . "
		";
		$result = $this->database->executeQuery($query);
		return $this->database->getNumAffectedRows();
	}
	
	public function deleteDataSourceParameter($idDataSourceParameter) {
		$query = "DELETE FROM datasourceparameteruser WHERE idDataSourceParameter = " . $idDataSourceParameter;
		$result = $this->database->executeQuery($query);

		$query = "DELETE FROM datasourceparameter WHERE idDataSourceParameter = " . $idDataSourceParameter;
		$result = $this->database->executeQuery($query);
		return $this->database->getNumAffectedRows();
	}
	
	// Datasource Parameter User
	public function selectDataSourceParametersUser($idDataSource = 0, $idUser = 0) {
		$query = "SELECT
			dspu.idDataSourceParameter,
			dspu.idUser,
			dspu.strValue,
			dsp.strName,
			dsp.strDefaultValue,
			dsp.blnMandatory
		FROM
			datasourceparameteruser dspu,
			datasourceparameter dsp
		WHERE 
		dsp.idDataSourceParameter = dspu.idDataSourceParameter
		" . ($idDataSource > 0 ? " AND dsp.idDataSource = " . $idDataSource : "") . "
		" . ($idUser > 0 ? " AND dspu.idUser = " . $idUser : "")
		;
		$result = $this->database->executeQuery($query);
		$result = $this->database->prepareReturn($result);
		$arrResult = array();
		foreach($result as $item){
			$arrResult[$item['idDataSourceParameter']] = $item;
		}
		return $arrResult;
	}
	
	public function updateDataSourceParameterUser($idDataSourceParameter, $idUser, $strValue) {
		if ($strValue != '') {
		  $query = "
		  INSERT INTO 
			  datasourceparameteruser (idDataSourceParameter, idUser, strValue) 
		  VALUES
			  (" . $idDataSourceParameter . ", " . $idUser . ", '" . $strValue . "')
		  ON DUPLICATE KEY UPDATE
			  strValue='" . $strValue . "'
		  ";
		} else {
		  $query = "DELETE FROM datasourceparameteruser WHERE idDataSourceParameter = " . $idDataSourceParameter . " AND idUser = " . $idUser;
		}
		$result = $this->database->executeQuery($query);
		return $this->database->getNumAffectedRows();
	}
	
	// datasourceusersearch
	public function selectDataSourceUserSearchs($idDataSource = 0, $idUser = 0, $blnJustEnabledUpdates = false) {
		$query = "SELECT
			dsus.idDataSource,
			dsus.idUser,
			dsus.strKeyword,
			dsus.dtSearch,
			ds.strName,
			ds.intUpdateFrequencyMin,
			usr.idProject,
			usr.strEmail
		FROM
			datasourceusersearch dsus,
			datasource ds,
			user usr
		WHERE 
		usr.idUser = dsus.idUser
		" . ($idDataSource > 0 ? " AND dsus.idDataSource = " . $idDataSource : "") . "
		" . ($idUser > 0 ? " AND dsus.idUser = " . $idUser : "") . "
		" . ($blnJustEnabledUpdates ? " AND ds.intUpdateFrequencyMin > 0" : "")
		;
		$result = $this->database->executeQuery($query);
		$result = $this->database->prepareReturn($result);
		$arrResult = array();
		foreach($result as $item){
			$arrResult[$item['idDataSource']] = $item;
		}
		return $arrResult;
	}
	
	public function updateDataSourceUserSearch($idDataSource, $idUser, $strKeyword, $blnDelete) {
		if ($blnDelete) {
		  $query = "DELETE FROM datasourceusersearch WHERE idDataSource = " . $idDataSource . " AND idUser = " . $idUser;
		} else {
		  $query = "
		  INSERT INTO 
			  datasourceusersearch (idDataSource, idUser, strKeyword) 
		  VALUES
			  (" . $idDataSource . ","  . $idUser . ",'" . $strKeyword . "')
		  ON DUPLICATE KEY UPDATE
			  strKeyword = '" . $strKeyword . "'
		  ";
		}
		$result = $this->database->executeQuery($query);
		return $this->database->getNumAffectedRows();
	}
	
	public function updateDataSourceUserSearchKeyword($idUser, $strKeyword) {
		$query = "UPDATE datasourceusersearch SET strKeyword = '" . mysql_real_escape_string(trim(utf8_decode($strKeyword))) . "' WHERE idUser = " . $idUser;
		$result = $this->database->executeQuery($query);
		return $this->database->getNumAffectedRows();
	}
	
	public function updateDataSourceUserSearchDate($idDataSource, $idUser, $dtSearch = '') {
		$query = "
		  UPDATE 
			  datasourceusersearch 
		  SET 
			  dtSearch=" . ($dtSearch ? "'" . $dtSearch . "'" : "NOW()") . " 
		  WHERE 
			  idDataSource = " . $idDataSource . " AND 
			  idUser = " . $idUser
		;
		$result = $this->database->executeQuery($query);
		return $this->database->getNumAffectedRows();
	}
}
?>