<?php
class Geodesign {
	// API Documentation - http://www.geodesignsupport.com/kb/get-methods/
	// Token tiagomarino@hotmail.com - cb26ba27d2ac50fa1e9d2e0205042f25ca1c2210
	// Token Silvio - f088800660e64510cce96f6e596566fd7ea633b0
	public $strSiteURL			= 'https://www.geodesignhub.com';
	public $strSiteGetTokenURL	= 'https://www.geodesignhub.com/api/token/';
	public $strAPIURL			= 'https://www.geodesignhub.com/api/v1/projects/';
	
	public function __construct() {
		include_once 'strings.php';
		$strings = new Strings();
		$this->strings = $strings;
	}
	
	public function selectUserProjects($strAPIToken){
		$arrProjects = $this->get($this->strAPIURL, $strAPIToken);
		return $arrProjects;
	}

	public function selectProjectDiagrams($idProject, $strAPIToken, $blnLoadDiagramDetails = false){
		$arrResult = array();
		if ($blnLoadDiagramDetails) {
			$arrDiagrams = $this->get($this->strAPIURL . $idProject . '/diagrams/all/', $strAPIToken);
			foreach ($arrDiagrams as $i => $arrDiagram) {
				$arrDiagrams[$i] = $this->arrDiagramFormat($arrDiagram);
			}
		} else {
			$arrDiagrams = $this->get($this->strAPIURL . $idProject . '/diagrams/', $strAPIToken);
		}
		$arrSystems = $this->get($this->strAPIURL . $idProject . '/systems/', $strAPIToken);
		foreach($arrDiagrams as $i => $arrDiagram) {
			$arrDiagrams[$i]['sysname'] = $this->strSystemNameById($arrDiagram['sysid'], $arrSystems);
		}		
		return $arrDiagrams;
	}
	
	public function selectProjectMembers($idProject, $strAPIToken){
		$arrResult = array();
		$arrMembers = $this->get($this->strAPIURL . $idProject . '/members/', $strAPIToken);
		$arrResult['arrMembers'] = $arrMembers['members'];
		return $arrResult;
	}
	
	public function selectProjectMemberDiagrams($idProject, $idMember, $strAPIToken){
		$arrResult = array();
		$arrSystems = $this->get($this->strAPIURL . $idProject . '/systems/', $strAPIToken);
		$arrResult['arrSystems'] = $arrSystems;
		if ($idMember) {
			$arrMemberDiagrams = $this->get($this->strAPIURL . $idProject . '/members/' . $idMember . '/diagrams/', $strAPIToken);
			$arrDiagrams = array();
			foreach($arrMemberDiagrams['features'] as $i => $arrDiagram) {
				$arrDiagrams[] = array(
					'worlddescription'	=> $arrDiagram['properties']['description'],
					'sysname'			=> $arrDiagram['properties']['sysname'],
					'areatype'			=> $arrDiagram['properties']['areatype']
				);
			}
		} else {
			$arrDiagrams = $this->get($this->strAPIURL . $idProject . '/diagrams/', $strAPIToken);
			foreach($arrDiagrams as $i => $arrDiagram) {
				$arrDiagrams[$i]['sysname'] = $this->strSystemNameById($arrDiagram['sysid'], $arrSystems);
			}
		}
		$arrResult['arrDiagrams'] = $arrDiagrams;
		return $arrResult;
	}
	
	public function strSystemNameById($id, $arrSystems) {
		foreach ($arrSystems as $arrSystem) {
			if ($arrSystem['id'] == $id) { 
				return $arrSystem['sysname'];
			}
		}
		return '';
	}
	
	public function selectProjectDiagram($idProject, $idDiagram, $strAPIToken){
		$arrDiagram = $this->get($this->strAPIURL . $idProject . '/diagrams/' . $idDiagram . '/', $strAPIToken);
		$arrDiagram = $this->arrDiagramFormat($arrDiagram);
		return $arrDiagram;
	}
	
	public function get($strURL, $strToken){
		$strJSON = $this->strings->processUrl($strURL, array('Authorization: Token ' . $strToken));
		$arrResult = $this->strings->objectify('array', $strJSON);
		return $arrResult;
	}
	
	public function exportDiagrams($strExt, $idProject, $strAPIToken, $strProjectName = '', $blnLiveKML = false){
		set_time_limit(300);
		$arrOutput = array();
		$arrDiagrams = array();
		$strFilePathTMPNoExt = $this->strings->strSiteTmpFileFolder . '/' . date('d-m-y-H-i-s');
		if ($strExt != 'LKML') {
			$arrDiagrams = $this->selectProjectDiagrams($idProject, $strAPIToken, true);
		}
		if (! $strProjectName) $strProjectName = 'Geodesign Hub - ' . $idProject;
		switch ($strExt) {
		case "SHP":
		  // Write to Shapefile
		  require_once('shapefile/writer/Shapefile.php');
		  // Write to DBF
		  require_once "dbf/Column.class.php";
		  require_once "dbf/Record.class.php";
		  require_once "dbf/Table.class.php";
		  require_once "dbf/WritableTable.class.php";
		  $arrFields = array(
			  array("FID", DBFFIELD_TYPE_NUMERIC, 8, 0),
			  array("project", DBFFIELD_TYPE_CHAR, 50),
			  array("description", DBFFIELD_TYPE_CHAR, 100),
			  array("sysid", DBFFIELD_TYPE_NUMERIC, 8, 0),
			  array("sysname", DBFFIELD_TYPE_CHAR, 20),
			  array("author", DBFFIELD_TYPE_CHAR, 50),
			  array("areatype", DBFFIELD_TYPE_CHAR, 20),
			  array("color", DBFFIELD_TYPE_CHAR, 20)
		  );
		  // Bounding Box
		  $arrFiles[] = array('strTemp' => $strFilePathTMPNoExt . '.shp', 'strName' => 'diagrams.shp');
		  $arrFiles[] = array('strTemp' => $strFilePathTMPNoExt . '.shx', 'strName' => 'diagrams.shx');
		  $arrFiles[] = array('strTemp' => $strFilePathTMPNoExt . '.dbf', 'strName' => 'diagrams.dbf');
		  $arrOutput['shp'] = $strFilePathTMPNoExt . '.shp';
		  $arrOutput['shx'] = $strFilePathTMPNoExt . '.shx';
		  $arrOutput['dbf'] = $strFilePathTMPNoExt . '.dbf';
		  $arrBBox = $this->getDiagramsBoundingBox($arrDiagrams);
		  $shp = new ShapeFile(5, array("xmin" => $arrBBox['dblLngSW'], "ymin" => $arrBBox['dblLatSW'], "xmax" => $arrBBox['dblLngNE'], "ymax" => $arrBBox['dblLatNE']));
		  $dbf = XBaseWritableTable::create($strFilePathTMPNoExt . '.dbf', $arrFields);
		  foreach ($arrDiagrams as $i => $arrDiagram) {
			// SHP Record
			$shpRecord = new ShapeRecord(5);
			foreach($arrDiagram['arrCoordinates'] as $arrVertex) {
				$shpRecord->addPoint(array("x" => $arrVertex['dblLongitude'], "y" => $arrVertex['dblLatitude']));
			}
			$intID = $shp->addRecord($shpRecord);
			// DBF Record
			$r =& $dbf->appendRecord();
			$r->setObjectByName("FID", $intID);
			$r->setObjectByName("project", $strProjectName);
			$r->setObjectByName("description", utf8_decode($arrDiagram['description']));
			$r->setObjectByName("sysid", $arrDiagram['sysid']);
			$r->setObjectByName("sysname", $arrDiagram['sysname']);
			$r->setObjectByName("author", $arrDiagram['author']);
			$r->setObjectByName("areatype", $arrDiagram['areatype']);
			$r->setObjectByName("color", $arrDiagram['color']);
			$dbf->writeRecord();
		  }
		  $shp->saveToFile($strFilePathTMPNoExt . '.*');
		  $dbf->close();		  
		  // Create ZIP File to Compile All
		  $arrOutput['strFilePathTMP'] = $strFilePathTMPNoExt . '.zip';
		  $arrOutput['strFilePath'] = 'diagrams.zip';
		  $zip = new ZipArchive();
		  $zip->open($arrOutput['strFilePathTMP'], ZIPARCHIVE::CREATE);
		  foreach ($arrFiles as $arrFile) {
			  $zip->addFile($arrFile['strTemp'], $arrFile['strName']);
		  }
		  $zip->close();
		break;
		case "DXF":
		  $arrOutput['strFilePathTMP'] = $strFilePathTMPNoExt . '.dxf';
		  $arrOutput['strFilePath'] = 'diagrams.dxf';
		  require_once 'dxf/dxfwriter.php';
		  $dxf = new DXF();
		  $dxf->addLayer("Diagrams", DXF_COLOR_RED);
		  foreach ($arrDiagrams as $i => $arrDiagram) {
			$arrVertexs = array();
			foreach($arrDiagram['arrCoordinates'] as $j => $arrVertex) {
				$arrVertexs[] = array('x' => $arrVertex['dblLongitude'], 'y' => $arrVertex['dblLatitude'], 'z'=> 0);
			}
			$dxf->addPolyline($arrVertexs, "Diagrams", $arrDiagram['areatype'] == 'project' ? 'SOLID' : 'DASHED');
		  }
		  $fh = fopen($arrOutput['strFilePathTMP'], 'w');
		  fwrite($fh, $dxf->getString());
		  fclose($fh);
		break;
		case "KML":
		  $arrOutput['strFilePathTMP'] = $strFilePathTMPNoExt . '.kml';
		  $arrOutput['strFilePath'] = 'diagrams.kml';
		  // Get Systems Names
		  $arrSystems = array();
		  foreach ($arrDiagrams as $i => $arrDiagram) {
			  if (array_search($arrDiagram['sysname'], $arrSystems) === FALSE) {
				  $arrSystems[] = $arrDiagram['sysname'];
			  }
		  }
		  $kml = simplexml_load_string('<kml 
			  xmlns="http://www.opengis.net/kml/2.2" 
			  xmlns:gx="http://www.google.com/kml/ext/2.2" 
			  xmlns:kml="http://www.opengis.net/kml/2.2" 
			  xmlns:atom="http://www.w3.org/2005/Atom"
		  ></kml>');
		  $kmlDocument = $kml->addChild('Document');
		  $kmlDocumentName = $kmlDocument->addChild('Name', $strProjectName); // Project Name
		  $kmlDocumentFolder = $kmlDocument->addChild('Folder');
		  $kmlDocumentFolder->addChild('name', $strProjectName . ' (' . count($arrDiagrams) . ')');
		  $kmlDocumentFolder->addChild('open', 1);
		  // Folders by System
		  foreach ($arrSystems as $strSystem) {
			$kmlDocumentFolderSystem = $kmlDocumentFolder->addChild('Folder');
			$kmlDocumentFolderSystem->addChild('name', $strSystem);
			$kmlDocumentFolderSystem->addChild('open', 0);
			// Select Diagrams from System			
			foreach ($arrDiagrams as $i => $arrDiagram) {
			  // Skip Diagrams without coordinates
			  if (! count($arrDiagram['arrCoordinates'])) {continue;}
			  // Skip if Diagram is not from System
			  if ($arrDiagram['sysname'] != $strSystem) {continue;}
			  // Style
			  $kmlDocumentStyle = $kmlDocument->addChild('Style');
			  $kmlDocumentStyle->addAttribute('id', 'style-' . $arrDiagram['id']);
			  $kmlDocumentStyleLineStyle = $kmlDocumentStyle->addChild('LineStyle');
			  $kmlDocumentStyleLineStyle->addChild('width', '3.5');
			  $kmlDocumentStyleLineStyle->addChild('color', '#ff' . $arrDiagram['color']);
			  $kmlDocumentStylePolyStyle = $kmlDocumentStyle->addChild('PolyStyle');
			  $kmlDocumentStylePolyStyle->addChild('color', '#' . ($arrDiagram['areatype'] == 'project' ? '77' : '00') . $arrDiagram['color']);
			  $kmlDocumentStyleMap = $kmlDocument->addChild('StyleMap');
			  $kmlDocumentStyleMap->addAttribute('id', 'mstyle-' . $arrDiagram['id']);
			  $kmlDocumentStyleMapPair = $kmlDocumentStyleMap->addChild('Pair');
			  $kmlDocumentStyleMapPair->addChild('key', 'normal');
			  $kmlDocumentStyleMapPair->addChild('styleUrl', '#style-' . $arrDiagram['id']);
			  $kmlDocumentStyleMapPair = $kmlDocumentStyleMap->addChild('Pair');
			  $kmlDocumentStyleMapPair->addChild('key', 'highlight');
			  $kmlDocumentStyleMapPair->addChild('styleUrl', '#style-' . $arrDiagram['id']);
			  // Placemark
			  $kmlDocumentFolderPlacemark = $kmlDocumentFolderSystem->addChild('Placemark');
			  $kmlDocumentFolderPlacemark->addChild('name', $arrDiagram['description'] . ($arrDiagram['author'] ? ' (' . $arrDiagram['author'] . ')' : ''));
			  $strDescription = 
				  ($strProjectName ? '<b>Project:</b> ' . $strProjectName . '<br>' : '') .
				  '<b>Description:</b> ' . $arrDiagram['description'] . '<br>' .
				  '<b>Author:</b> ' . $arrDiagram['author'] . '<br>' .
				  '<b>Diagram ID:</b> ' . $arrDiagram['id'] . '<br>' .
				  '<b>System ID:</b> ' . $arrDiagram['sysid'] . '<br>' .
				  '<b>System Name:</b> ' . $arrDiagram['sysname'] . '<br>' .
				  '<b>Area Type:</b> ' . $arrDiagram['areatype'] . '<br>' .
				  '<b>Color:</b> ' . $arrDiagram['color']
			  ;
			  $kmlDocumentFolderPlacemark->addChild('description', $strDescription);
			  $kmlDocumentFolderPlacemark->addChild('styleUrl', '#style-' . $arrDiagram['id']);
			  $kmlDocumentFolderPlacemarkPolygon = $kmlDocumentFolderPlacemark->addChild('Polygon');
			  $kmlDocumentFolderPlacemarkPolygon->addChild('tessellate', '1');
			  $kmlDocumentFolderPlacemarkPolygonOuterBoundaryIs = $kmlDocumentFolderPlacemarkPolygon->addChild('outerBoundaryIs');
			  $kmlDocumentFolderPlacemarkPolygonOuterBoundaryIsLinearRing = $kmlDocumentFolderPlacemarkPolygonOuterBoundaryIs->addChild('LinearRing');
			  // Coordinates
			  if (count($arrDiagram['arrCoordinates'])) {
				$arrCoordinates = array();
				foreach($arrDiagram['arrCoordinates'] as $arrVertex) {
					$arrCoordinates[] = $arrVertex['dblLongitude'] . "," . $arrVertex['dblLatitude'] . ",0";
				}
				$kmlDocumentFolderPlacemarkPolygonOuterBoundaryIsLinearRingCoordinates = $kmlDocumentFolderPlacemarkPolygonOuterBoundaryIsLinearRing->addChild('coordinates', implode(' ', $arrCoordinates));
			  }
			}

			
		  }		  
		  if ($blnLiveKML) {
			  $arrOutput['strReport'] = $kml->asXML();
		  } else {
			$fh = fopen($arrOutput['strFilePathTMP'], 'w');
			fwrite($fh, $kml->asXML());
			fclose($fh);
		  }
		break;
		case "LKML":
		  $arrOutput['strFilePathTMP'] = $this->strings->strSiteTmpFileFolder . '/live-' . $idProject . '-' . date('d-m-y-H-i-s') . '-' . $this->strings->generateRandomString(2) . '.kml';
		  $arrOutput['strFilePath'] = 'diagrams-live.kml';
		  $strProjectName = $this->strings->removeInvalidChars($this->strings->changeCharAccent($strProjectName));
		  $arrOutput['strFilePath'] =  $strProjectName . '.kml';
		  $strOut = '<?xml version="1.0" encoding="UTF-8"?>
	  <kml xmlns="http://www.opengis.net/kml/2.2">
	  <NetworkLink>
		  <name>Geodesign Hub - ' . strip_tags($strProjectName) . '</name>
		  <open>1</open>
		  <Link>
			  <href>' . $this->strings->strSiteURL . '/api.php?action=geodesign-live-kml&amp;token=' . $strAPIToken . '&amp;idproject=' . $idProject . '</href>
			  <refreshMode>onInterval</refreshMode>
			  <refreshInterval>1800</refreshInterval>
		  </Link>
	  </NetworkLink>
	  </kml>
		  ';
		  $fh = fopen($arrOutput['strFilePathTMP'], 'w');
		  fwrite($fh, $strOut);
		  fclose($fh);
		break;
		}
		return $arrOutput;
	}
	
	public function getDiagramsBoundingBox($arrDiagrams) {
		$arrBBox = array();
		$arrBBox['dblLatSW'] = 90;
		$arrBBox['dblLngSW'] = 180;
		$arrBBox['dblLatNE'] = -90;
		$arrBBox['dblLngNE'] = -180;
		foreach ($arrDiagrams as $arrDiagram) {
			foreach($arrDiagram['arrCoordinates'] as $arrVertex) {
				if ($arrVertex['dblLatitude']   < $arrBBox['dblLatSW']) $arrBBox['dblLatSW'] = $arrVertex['dblLatitude'];
				if ($arrVertex['dblLongitude']  < $arrBBox['dblLngSW']) $arrBBox['dblLngSW'] = $arrVertex['dblLongitude'];
				if ($arrVertex['dblLatitude']   > $arrBBox['dblLatNE']) $arrBBox['dblLatNE'] = $arrVertex['dblLatitude'];
				if ($arrVertex['dblLongitude']  > $arrBBox['dblLngNE']) $arrBBox['dblLngNE'] = $arrVertex['dblLongitude'];
			}
		}
		return $arrBBox;
	
	}
	
	private function arrDiagramFormat($arrDiagram) {
  	  $arrDiagram['description'] = $arrDiagram['description'];
  	  $arrDiagram['sysid'] = $arrDiagram['sysid'];
	  if ($arrDiagram['geojson']['features']) {
		$arrDiagram['intShapeType'] = $arrDiagram['geojson']['features'][0]['geometry']['type'] == 'Polygon' ? 3 : 2;
		$arrDiagram['author'] = $arrDiagram['geojson']['features'][0]['properties']['author'];
		$arrDiagram['areatype'] = $arrDiagram['geojson']['features'][0]['properties']['areatype'];
		$arrDiagram['color'] = substr($arrDiagram['geojson']['features'][0]['properties']['color'], 1, 10);
		$arrCoordinates = $arrDiagram['geojson']['features'][0]['geometry']['coordinates'][0];
		$arrVtcs = array();
		if (count ($arrCoordinates)) {
			foreach ($arrCoordinates as $arrCoordinate) {
				$arrVtcs[] = array('dblLatitude' => $arrCoordinate[1], 'dblLongitude' => $arrCoordinate[0]);
			}
			$arrDiagram['arrCoordinates'] = $arrVtcs;
		}
	  }
	  //$arrDiagram['strGoogleStaticMapsURL'] = $this->strings->strGenerateStaticMapsURL($arrDiagram['intShapeType'], '#FF0000', 'D', $arrVtcs);
	  return $arrDiagram;
	}	
}
?>