<?php
class Project {
	public $strProjectImageNoLogo		= 'img/logo.png';
	public $strProjectImageNoBackground	= 'img/backgrounds/1.jpg';
	public $strDefaultIcon				= 'icon-map-marker';
	public $strRGBDefaultColor			= 'FF0000';
	public $intMaxBackups				= 3;
	public $intBackupSizeLimitMB		= 300;

	public function __construct($database) {
		$this->database = $database;
		
		include_once 'strings.php';
		$strings = new Strings();
		$this->strings = $strings;
		
		include_once 'gPoint.php';
		$gPoint = new gPoint($database);
		$this->gPoint = $gPoint;
		
		session_start();
	}

	public function selectProjects($idProject = 0, $strSearch = '', $blnActives = 0, $blnCount = false, $blnOrderByEvent = false, $intJustAccessedLastDays = 0) {
		$query =
		"SELECT
			p.idProject,
			p.idUserCreator,
			u.strEmail AS strUserCreator,
			p.blnActive,
			p.dtDateCreation,
			p.strName,
			p.txtDescription,
			p.strAlias,
			p.strAddress,
			p.dblLatitude,
			p.dblLongitude,
			p.idCountry,
			p.idCSSTheme,
			css.strThemeName,
			p.strRGBColor,
			p.strGoogleAnalyticsID,
			p.strSkypeID,
			p.strLogoFile,
			p.strBackgroundFile,
			p.idProjectUserViewScope,
			p.blnAllowAllView,
			p.blnAllowFormShare,
			p.intAllowJoinAsLevel,
			p.blnMobileAllowEditCoordinates,
			p.intBackupFrequencyDays,
			p.dtBackupLastExecution,
			p.intRecordClusterRadiusMts,
			p.blnMapClusterer,
			c.strName as strCountryName,
			c.strLanguageCode,
			c.strCurrencySymbol
			" . ($blnOrderByEvent ? ",MAX(e.dtDateTime) AS dtLastAccess" : "") . "
		FROM
			project 	p,
			country		c,
			user		u,
			csstheme	css
			" . ($blnOrderByEvent ? ", event e" : "") . "
		WHERE 
		c.idCountry = 	p.idCountry AND
		p.idProject =	u.idProject AND 
		css.idCSSTheme = p.idCSSTheme
		" . ($blnOrderByEvent ? " AND e.idUser = u.idUser AND e.idEventType = 19" : "") . "
		" . ($idProject > 0 ? " AND p.idProject = " . $idProject : "") . "
		" . ($blnActives > 0 ? " AND p.blnActive = 1" : "") . "
		" . ($intJustAccessedLastDays > 0 ? "AND e.dtDateTime BETWEEN NOW() - INTERVAL " . $intJustAccessedLastDays . " DAY AND NOW()" : "") . "
		" . ($strSearch ? is_numeric($strSearch) ? "AND p.idProject = " . $strSearch : "
			AND (
			p.strName			LIKE '%" . $strSearch . "%' OR
			p.txtDescription	LIKE '%" . $strSearch . "%' OR
			p.strAddress		LIKE '%" . $strSearch . "%' OR
			p.strAlias			LIKE '" . $strSearch . "'
			)
		" : "") . "
		GROUP BY p.idProject
		ORDER BY 
		" . ($blnOrderByEvent ? " dtLastAccess DESC" : " p.idProject") . "
		";
		$result = $this->database->executeQuery($query);
		$result = $this->database->prepareReturn($result);
		foreach ($result as $idLine => $item) {
			$result[$idLine]['strDateCreation'] = date('d/m/y', strtotime($item['dtDateCreation']));
			$result[$idLine]['strBackupLastExecution'] = $item['dtBackupLastExecution'] ? date('d/m/Y H:i', strtotime($item['dtBackupLastExecution'])) : '-';
			$result[$idLine]['strBackupNextExecution'] = $item['dtBackupLastExecution'] ? date('d/m/Y', strtotime('+' . $item['intBackupFrequencyDays'] . 'day', strtotime($item['dtBackupLastExecution']))) : date('d/m/Y', strtotime('+' . $item['intBackupFrequencyDays'] . 'day'));
			$result[$idLine]['strURL'] = $this->strings->strSiteURL . '/?idProject=' . $result[$idLine]['idProject'];
			$result[$idLine]['strURLExternal'] = $this->strings->strSiteURL . '/' . $result[$idLine]['strAlias'];
			$result[$idLine]['strRGBColor'] = $result[$idLine]['strRGBColor'] ? $result[$idLine]['strRGBColor'] : substr($this->strings->strSiteBaseColor,1,10);
			$result[$idLine]['strRGBColorDark'] = $this->strings->strRGBDarker($result[$idLine]['strRGBColor'], 70);
			$result[$idLine]['strRGBColorLight'] = $this->strings->strRGBLighter($result[$idLine]['strRGBColor'], 90);
			$result[$idLine]['strDateLastAccess'] = $blnOrderByEvent ? date('d/m/y H:i', strtotime($result[$idLine]['dtLastAccess'])) : '';
			$result[$idLine]['intDaysSinceLastAccess'] = $blnOrderByEvent ? 
				floor((time() - strtotime($result[$idLine]['dtLastAccess']))/(60*60*24))
			 : '';
			// Formating full path for logo image
			$result[$idLine]['strLogoFileFullPath'] = $this->strings->strProjectFolder . '/' . $result[$idLine]['idProject'] . '/'  . $result[$idLine]['strLogoFile'];
			if ((! $result[$idLine]['strLogoFile']) || ((! file_exists($result[$idLine]['strLogoFileFullPath'])) && (! file_exists('../' . $result[$idLine]['strLogoFileFullPath'])))) {
				$result[$idLine]['strLogoFileFullPath'] = $this->strProjectImageNoLogo;
			}
			// Formating full path for background image
			$result[$idLine]['strBackgroundFileFullPath'] = $this->strings->strProjectFolder . '/' . $result[$idLine]['idProject'] . '/' . $result[$idLine]['strBackgroundFile'];
			if ((! $result[$idLine]['strBackgroundFile']) || ((! file_exists($result[$idLine]['strBackgroundFileFullPath'])) && (! file_exists('../' . $result[$idLine]['strBackgroundFileFullPath'])))) {
				$result[$idLine]['strBackgroundFileFullPath'] = $this->strProjectImageNoBackground;
			}
			if ($blnCount) {
				$result[$idLine]['intUsers'] =  $this->intCountUsers($item['idProject']);
				$result[$idLine]['intForms'] =  $this->intCountForms($item['idProject']);
				$result[$idLine]['intRecords'] = $this->intCountRecords($item['idProject']);
			}
			// For Project Search
			$result[$idLine]['text'] = $item['strName'];
			//$result[$idLine]['value'] = '<div style="cursor:pointer;white-space: normal;"><a href="../index.php?idProject=' . $result[$idLine]['idProject'] . '" target="_blank" style="text-decoration:none"><img src="../' . $result[$idLine]['strLogoFileFullPath'] . '" style="height:40px;width:40px;float:left;word-break:break-word" class="rounded" align="absmiddle"> ' . strip_tags($result[$idLine]['strName']) . '</a></div>';
			$result[$idLine]['value'] = '<div style="cursor:pointer;white-space: normal;"><img src="../' . $result[$idLine]['strLogoFileFullPath'] . '" style="height:40px;width:40px;float:left;word-break:break-word;margin-right:5px" class="rounded" align="absmiddle"> ' . strip_tags($result[$idLine]['strName']) . '</div>';
			$result[$idLine]['query'] = $strSearch;
		}		
		return $result;
	}

	public function selectProjects2() {
		$query = "SELECT p.idProject FROM project p ORDER BY p.idProject";
		$result = $this->database->executeQuery($query);
		$result = $this->database->prepareReturn($result);		
		return $result;
	}

	public function selectProjectsAllowJoin() {
		$query = "
			SELECT 
				p.idProject, 
				p.strName,
				p.intAllowJoinAsLevel
			FROM 
				project p 
			WHERE 
				p.intAllowJoinAsLevel > 0 
			ORDER BY 
				p.strName
		";
		$result = $this->database->executeQuery($query);
		$result = $this->database->prepareReturn($result);		
		return $result;
	}

	public function insertProject($strEmail, $strName, $strAlias, $blnSendNotificationMail = true) {
		$arrReturn = array();
		// Create Project
		$query =
		"INSERT INTO project SET
			dtDateCreation			= NOW(),
			strName					= '" . $strName . "',
			strAlias				= '" . $strAlias . "',
			blnAllowAllView			= 1,
			idProjectUserViewScope	= 3,
			idProjectUserEditScope	= 3
		";
		$this->database->executeQuery($query);
		$arrReturn['idProject'] = $this->database->getLastInsertedID();		
		if (! is_numeric($arrReturn['idProject'])) { return false;}
		// Create folder for Project
		$strProjectFolderName = $this->strings->strProjectFolder . '/' . $arrReturn['idProject'] . '/';
		mkdir($strProjectFolderName);
		// Create folder for Support Files
		mkdir($strProjectFolderName . '/' . $this->strings->strSupportFolder);
		// Create folder for Backup Files
		mkdir($strProjectFolderName . '/' . $this->strings->strBackupFolder);
		// Create User
		$strPassword = $this->strings->generateRandomString(4);
		$query =
		"INSERT INTO user SET
			idProject		= " . $arrReturn['idProject'] . ",
			idUserLevel		= 4,
			dtRegister		= NOW(),
			strEmail		=  '" . $strEmail . "',
			strPassword	 	= '" . md5($strPassword) . "'
		";
		$this->database->executeQuery($query);
		$arrReturn['idUser'] = $this->database->getLastInsertedID();
		
		/*
		$query = "SELECT MAX(idUser) as `idUser` FROM user WHERE idProject = " . $arrReturn['idProject'];
		$result = $this->database->executeQuery($query);
		$result = $this->database->prepareReturn($result);		
		$arrReturn['idUser'] = $result[0]['idUser'];
		*/
		// Update Project with idUser
		$query = "UPDATE project SET idUserCreator=" . $arrReturn['idUser'] . " WHERE idProject = " . $arrReturn['idProject'];
		$this->database->executeQuery($query);
		// If created user, send a email with password
		if ($blnSendNotificationMail) {
			$arrSessions = array();
			$arrSessions[0]['strTitle'] = $_SESSION['strJoinMailSectionYourInformation'];
			$arrSessions[0]['strContent'] = 
				$_SESSION['strJoinUserEmail'] . ': ' . $strEmail . '<br>' . 
				$_SESSION['strJoinMailPassword'] . ': ' . $strPassword . '<br>' . 
				$_SESSION['strJoinMailURL'] . ': <a href="' . $this->strings->strSiteURL . '/' . $strAlias . '" target="_blank">' . $this->strings->strSiteURL . '/' . $strAlias . '</a>'
			;
			$arrSessions[1]['strTitle'] = $_SESSION['strJoinMailSectionGuideTitle'];
			$arrSessions[1]['strContent'] = 
				$_SESSION['strJoinMailSectionGuideText'] . ':<br>' . 
				'<ul>' . 
					'<li><a href="' . $this->strings->strSiteURL . '/help/lesson-pdf" target="_blank ">Criacao e Consulta Vicon Web</a></li>' . 
					'<li><a href="' . $this->strings->strSiteURL . '/help/mobile-pdf" target="_blank ">Criacao Vicon Mobile (Android) + Consulta QGIS</a></li>' . 
				'</ul>'
			;
			$strBody = $this->strings->mailFormatContent(2, $_SESSION['strJoinMailTitle'], $_SESSION['strJoinMailWelcome'], $_SESSION['strJoinMailGreetings'], $arrSessions, '?idProject=' . $arrReturn['idProject']);
			$strSubject = $this->strings->strUpperAccents($this->strings->strSiteName . ': ' . $_SESSION['strJoinMailTitle']);
			$this->strings->sendMail($strSubject, $strBody, $this->strings->strSiteEmail, $strEmail, $this->strings->strSiteEmail);
		}
		return $arrReturn;
	}

	public function updateProject($idProject, $strAlias, $strName, $txtDescription, $strAddress, $dblLatitude, $dblLongitude, $strGoogleAnalyticsID, $strSkypeID, $blnAllowAllView, $blnAllowFormShare, $intAllowJoinAsLevel, $blnMobileAllowEditCoordinates, $idProjectUserViewScope, $idProjectUserEditScope, $intRecordClusterRadiusMts, $blnMapClusterer) {
		$query = "
			UPDATE project
			SET
				strAlias						= '" . $strAlias . "',
				strName							= '" . $strName . "',
				txtDescription					= '" . $txtDescription . "',
				strAddress						= '" . $strAddress . "',
				dblLatitude						= '" . $dblLatitude . "',
				dblLongitude					= '" . $dblLongitude . "',
				strGoogleAnalyticsID			= '" . $strGoogleAnalyticsID . "',
				strSkypeID						= '" . $strSkypeID . "',
				blnAllowAllView					= '" . $blnAllowAllView . "',
				blnAllowFormShare				= '" . $blnAllowFormShare . "',
				intAllowJoinAsLevel				= '" . $intAllowJoinAsLevel . "',
				blnMobileAllowEditCoordinates	= '" . $blnMobileAllowEditCoordinates . "',			
				idProjectUserViewScope			= '" . $idProjectUserViewScope . "',
				idProjectUserEditScope			= '" . $idProjectUserEditScope . "',
				intRecordClusterRadiusMts		= '" . $intRecordClusterRadiusMts . "',
				blnMapClusterer					= '" . $blnMapClusterer . "'
			WHERE
				idProject	=	" . $idProject;
		$result = $this->database->executeQuery($query);
		return true;
	}

	public function updateProjectInstall($idProject, $strAlias, $strName) {
		$query = "
			UPDATE project
			SET
				strAlias				= '" . $strAlias . "',
				strName					= '" . $strName . "'
			WHERE
				idProject	=	" . $idProject;
		$result = $this->database->executeQuery($query);
		return true;
	}

	public function updateProperty($idProject, $strField, $strValue) {
		$query = "UPDATE project SET " . $strField . "='" . $strValue . "' WHERE idProject = " . $idProject;
		$result = $this->database->executeQuery($query);
		return true;
	}
	
	public function updateFile($idProject, $strFileName, $strField, $blnFullFilePassed = false) {
		$chrType = strtoupper($chrType);
		// Deleting current file
		$arrProject = $this->selectProjects($idProject);
		$strFileDelete = $arrProject[0][$strField . 'FullPath'];
		if (strpos($strFileDelete,'img/') === false) {
			@unlink($strFileDelete);
		}
		// Now moving file and updating table
		$strSourceFileFullPathName = $this->strings->strSiteTmpFileFolder . '/' . $strFileName;
		if ($blnFullFilePassed) $strSourceFileFullPathName = $strFileName;
		if (strpos($strFileName,'mg/backgrounds') > 0) {
			$strSourceFileFullPathName = $strFileName;
			$strSourceFileFullPathName = str_replace('', '', $strFileName);
		}
	    $strFileExt = explode(".", $strFileName);
	    $strFileExt = strtolower(array_pop($strFileExt));
		$strDestinationFileName =  '00' . $this->strings->generateRandomString(2) . '.' . $strFileExt;
		$strDestinationFileFullPathName = $this->strings->strProjectFolder . '/' . $idProject . '/' . $strDestinationFileName;
		if (! $strFileName) {
			$strDestinationFileName = '';
			$strDestinationFileFullPathName = '';
		}
		$query = "UPDATE project SET " . $strField . " = '" . $strDestinationFileName . "' WHERE idProject = " . $idProject;
		$result = $this->database->executeQuery($query);
		if ($strFileName) {
			copy($strSourceFileFullPathName, $strDestinationFileFullPathName);
		}
		$arrResult = array();
		$arrResult['strFilePath'] = $strDestinationFileFullPathName;
		return $arrResult;
	}

	public function deleteProject($idProject) {
		$query = "DELETE userprojectworkgroup FROM userprojectworkgroup, projectworkgroup WHERE projectworkgroup.idProjectWorkgroup = projectworkgroup.idProjectWorkgroup AND projectworkgroup.idProject = " . $idProject;
		$this->database->executeQuery($query);
				
		include_once 'user.php';
		$user = new User($this->database);
		$arrUsers = $user->selectUsers($idProject);
		foreach ($arrUsers as $arrUser) {
			$user->deleteUser($arrUser['idUser']);
		}
		
		include_once 'form.php';
		$form = new Form($this->database);
		$arrForms = $form->selectForms($idProject);
		foreach ($arrForms as $arrForm) {
			$form->deleteForm(0, $arrForm['idForm']);
		}
		
		$query = "UPDATE FROM datasource SET idProject=0 WHERE idProject = " . $idProject;
		$this->database->executeQuery($query);
		
		$query = "DELETE FROM marker WHERE idProject = " . $idProject;
		$this->database->executeQuery($query);

		$query = "DELETE FROM projectsearch WHERE idProject = " . $idProject;
		$this->database->executeQuery($query);

		$query = "DELETE FROM projectworkgroup WHERE idProject = " . $idProject;
		$this->database->executeQuery($query);
		
		$query = "DELETE FROM project WHERE idProject = " . $idProject;
		$this->database->executeQuery($query);
		
		
		$strProjectFolder = $this->strings->strProjectFolder . '/' . $idProject . '/' ;
		if (file_exists($strProjectFolder)) {
			$this->strings->sureRemoveDir($strProjectFolder, true);
		}
		
		return $idProject;
	}

	public function intCountProjects() {
		$query = "SELECT COUNT(idProject) as `intNum` FROM project";
		$result = $this->database->executeQuery($query);
		$result = $this->database->prepareReturn($result);
		return $result[0]['intNum'];
	}
	
	public function intCountUsers($idProject) {
		$query = "SELECT COUNT(u.idUser) as `intNum` FROM user u WHERE idProject = " . $idProject;
		$result = $this->database->executeQuery($query);
		$result = $this->database->prepareReturn($result);
		return $result[0]['intNum'];
	}
	
	public function intCountForms($idProject) {
		$query = "SELECT COUNT(f.idForm) as `intNum` FROM form f WHERE idProject = " . $idProject;
		$result = $this->database->executeQuery($query);
		$result = $this->database->prepareReturn($result);
		return $result[0]['intNum'];
	}
	
	public function intCountRecords($idProject) {
		$query = "SELECT COUNT(fr.idFormRecord) as `intNum` FROM formrecord fr, form f WHERE fr.idForm = f.idForm AND f.idProject = " . $idProject;
		$result = $this->database->executeQuery($query);
		$result = $this->database->prepareReturn($result);
		return $result[0]['intNum'];
	}
	
	public function selectidProjectByAlias($strAlias) {
		$query = "SELECT idProject FROM project WHERE strAlias='" . $strAlias . "'";
		$result = $this->database->executeQuery($query);
		$result = $this->database->prepareReturn($result);
		return $result[0]['idProject'];
	}
	
	public function blnCheckAliasExists($strAlias) {
		$arrFolders = $this->strings->returnFolderFoldersList('./');
		if (array_search(strtolower($strAlias), $arrFolders) !== FALSE) {
			return  array(array('int' => 1));
		}
		$query = "SELECT COUNT(idProject) as `int` FROM project WHERE strAlias LIKE '" . $strAlias . "'";
		$result = $this->database->executeQuery($query);
		$result = $this->database->prepareReturn($result);
		return $result;
	}
	
	// Themes
	public function selectThemes($idTheme = 0) {
		$query = "
			SELECT
				ct.idCSSTheme,
				ct.strThemeName
			FROM
				csstheme ct
			" . ($idTheme ? " WHERE ct.idCSSTheme = " . $idTheme : "") . "
			ORDER BY
				ct.strThemeName
		";
		$result = $this->database->executeQuery($query);
		$result = $this->database->prepareReturn($result);
		foreach ($result as $idLine => $item) {
			$result[$idLine]['strCSSThemeURL'] = 'css/bootstrap-' . $result[$idLine]['strThemeName'] . '.css';
		}
		return  $result;
	}

	// ProjectUserScopes
	public function selectProjectUserScopes($idProjectUserScope = 0) {
		$query = "
			SELECT
				pus.idProjectUserScope,
				pus.strProjectUserScope
			FROM
				projectuserscope pus
			" . ($idProjectUserScope ? " WHERE pus.idProjectUserScope = " . $idProjectUserScope : "") . "
			ORDER BY
				pus.idProjectUserScope
		";
		$result = $this->database->executeQuery($query);
		$result = $this->database->prepareReturn($result);
		foreach ($result as $idLine => $item) {
			$result[$idLine]['strProjectUserScope'] = $_SESSION['strProjectUserScope_' . $result[$idLine]['idProjectUserScope']];
		}
		return $result;
	}
	
	// Project Backup
	public function backupUpdate($idProject, $intBackupFrequencyDays) {
		$query = "UPDATE project SET intBackupFrequencyDays = " . $intBackupFrequencyDays. " WHERE idProject = " . $idProject;
		$result = $this->database->executeQuery($query);
		return true;
	}
	
	public function strSQLInserts($strTableName, $strSQL) {
		$query = "SHOW FIELDS FROM `" . $strTableName . "`";
		$result = $this->database->executeQuery($query);
		$arrFields = $this->database->prepareReturn($result);
		foreach ($arrFields as $arrField) {
			$arrFieldsNames[] = "`" . $arrField['Field'] . "`";
		}	
		$result = $this->database->executeQuery($strSQL);
		$result = $this->database->prepareReturn($result);
		$arrReplaces = array();
		foreach ($result as $item) {
			$arrValues = array();
			foreach ($arrFields as $arrField) {
				$strValue = $item[$arrField['Field']];
				if (is_null($strValue) === true) {
					$strValue = 'NULL';
				} else {
					$strValue = "'" . $this->strings->removeInvalidCharsSQL($strValue) . "'";
				}
				$arrValues[] = $strValue;
			}
			$arrReplaces[] = chr(9) . '(' . implode(',', $arrValues) . ')';
		}
		$strQuery = '-- ' . $strTableName . ' ' . chr(13);
		if (count($arrReplaces) > 0) {
			$strQuery .= "REPLACE INTO `" . $strTableName . "` (" . implode(', ', $arrFieldsNames) . ") VALUES " . chr(13) . implode(',' . chr(13), $arrReplaces) . ';' . chr(13);
		}
		return $strQuery;
	}
	
	public function arrBackupQueries($idProject, $intMode = 1) {
		//$intMode: 1 = SELECT ; 2 = DELETE
		$arrQueries = array();
		$strOperation = $intMode == 1 ? "SELECT" : "DELETE";
		$arrQueries[] = array("project", $strOperation . " project" . ($intMode == 1 ? ".*" : "") . " FROM project WHERE idProject = " . $idProject);
		$arrQueries[] = array("projectworkgroup", $strOperation . " projectworkgroup" . ($intMode == 1 ? ".*" : "") . " FROM projectworkgroup WHERE idProject = " . $idProject);
		$arrQueries[] = array("user", $strOperation . " user" . ($intMode == 1 ? ".*" : "") . " FROM user WHERE idProject = " . $idProject);
		$arrQueries[] = array("form", $strOperation . " form" . ($intMode == 1 ? ".*" : "") . " FROM form WHERE idProject = " . $idProject);
		$arrQueries[] = array("formfield", $strOperation . " formfield" . ($intMode == 1 ? ".*" : "") . " FROM form, formfield WHERE formfield.idForm = form.idForm AND form.idProject = " . $idProject);
		$arrQueries[] = array("formrecord", $strOperation . " formrecord" . ($intMode == 1 ? ".*" : "") . " FROM formrecord, form WHERE formrecord.idForm = form.idForm AND form.idProject = " . $idProject);
		$arrQueries[] = array("formrecordfile", $strOperation . " formrecordfile" . ($intMode == 1 ? ".*" : "") . " FROM formrecordfile, formrecord, form WHERE formrecordfile.idFormRecord = formrecord.idFormRecord AND formrecord.idForm = form.idForm AND form.idProject = " . $idProject);
		$arrQueries[] = array("formrecordfield", $strOperation . " formrecordfield" . ($intMode == 1 ? ".*" : "") . " FROM formrecordfield, formrecord, form WHERE formrecordfield.idFormRecord = formrecord.idFormRecord AND formrecord.idForm = form.idForm AND form.idProject = " . $idProject);
		$arrQueries[] = array("formfieldalternative", $strOperation . " formfieldalternative" . ($intMode == 1 ? ".*" : "") . " FROM formfieldalternative, formfield, form WHERE formfieldalternative.idFormField = formfield.idFormField AND formfield.idForm = form.idForm AND form.idProject = " . $idProject);
		$arrQueries[] = array("formrecordfieldalternative", $strOperation . " formrecordfieldalternative" . ($intMode == 1 ? ".*" : "") . " FROM formrecordfieldalternative, formrecordfield, formrecord, form WHERE formrecordfieldalternative.idFormRecordField = formrecordfield.idFormRecordField AND formrecordfield.idFormRecord = formrecord.idFormRecord AND formrecord.idForm = form.idForm AND form.idProject = " . $idProject);
		$arrQueries[] = array("formrecordfielddate", $strOperation . " formrecordfielddate" . ($intMode == 1 ? ".*" : "") . " FROM formrecordfielddate, formrecordfield, formrecord, form WHERE formrecordfielddate.idFormRecordField = formrecordfield.idFormRecordField AND formrecordfield.idFormRecord = formrecord.idFormRecord AND formrecord.idForm = form.idForm AND form.idProject = " . $idProject);
		$arrQueries[] = array("formrecordfieldnumeric", $strOperation . " formrecordfieldnumeric" . ($intMode == 1 ? ".*" : "") . " FROM formrecordfieldnumeric, formrecordfield, formrecord, form WHERE formrecordfieldnumeric.idFormRecordField = formrecordfield.idFormRecordField AND formrecordfield.idFormRecord = formrecord.idFormRecord AND formrecord.idForm = form.idForm AND form.idProject = " . $idProject);
		$arrQueries[] = array("formrecordfieldtext", $strOperation . " formrecordfieldtext" . ($intMode == 1 ? ".*" : "") . " FROM formrecordfieldtext, formrecordfield, formrecord, form WHERE formrecordfieldtext.idFormRecordField = formrecordfield.idFormRecordField AND formrecordfield.idFormRecord = formrecord.idFormRecord AND formrecord.idForm = form.idForm AND form.idProject = " . $idProject);
		$arrQueries[] = array("formrecordfieldtime", $strOperation . " formrecordfieldtime" . ($intMode == 1 ? ".*" : "") . " FROM formrecordfieldtime, formrecordfield, formrecord, form WHERE formrecordfieldtime.idFormRecordField = formrecordfield.idFormRecordField AND formrecordfield.idFormRecord = formrecord.idFormRecord AND formrecord.idForm = form.idForm AND form.idProject = " . $idProject);
		$arrQueries[] = array("formrecordfieldtimeserie", $strOperation . " formrecordfieldtimeserie" . ($intMode == 1 ? ".*" : "") . " FROM formrecordfieldtimeserie, formrecordfield, formrecord, form WHERE formrecordfieldtimeserie.idFormRecordField = formrecordfield.idFormRecordField AND formrecordfield.idFormRecord = formrecord.idFormRecord AND formrecord.idForm = form.idForm AND form.idProject = " . $idProject);
		$arrQueries[] = array("formrecordlog", $strOperation . " formrecordlog" . ($intMode == 1 ? ".*" : "") . " FROM formrecordlog, formrecord, form WHERE formrecordlog.idFormRecord = formrecord.idFormRecord AND formrecord.idForm = form.idForm AND form.idProject = " . $idProject);
		$arrQueries[] = array("formrecordvertex", $strOperation . " formrecordvertex" . ($intMode == 1 ? ".*" : "") . " FROM formrecordvertex, formrecord, form WHERE formrecordvertex.idFormRecord = formrecord.idFormRecord AND formrecord.idForm = form.idForm AND form.idProject = " . $idProject);
		$arrQueries[] = array("marker", $strOperation . " marker" . ($intMode == 1 ? ".*" : "") . " FROM marker WHERE idProject = " . $idProject);
		$arrQueries[] = array("projectsearch", $strOperation . " projectsearch" . ($intMode == 1 ? ".*" : "") . " FROM projectsearch WHERE idProject = " . $idProject);
		$arrQueries[] = array("support", $strOperation . " support" . ($intMode == 1 ? ".*" : "") . " FROM support, user WHERE support.idUser = user.idUser AND user.idProject = " . $idProject);
		$arrQueries[] = array("supportresponse", $strOperation . " supportresponse" . ($intMode == 1 ? ".*" : "") . " FROM supportresponse, support, user WHERE supportresponse.idSupport = support.idSupport AND support.idUser = user.idUser AND user.idProject = " . $idProject);
		$arrQueries[] = array("toponymy", $strOperation . " toponymy" . ($intMode == 1 ? ".*" : "") . " FROM toponymy, user WHERE toponymy.idUser = user.idUser AND user.idProject = " . $idProject);
		$arrQueries[] = array("event", $strOperation . " event" . ($intMode == 1 ? ".*" : "") . " FROM event, user WHERE event.idUser = user.idUser AND user.idProject = " . $idProject);
		$arrQueries[] = array("useralert", $strOperation . " useralert" . ($intMode == 1 ? ".*" : "") . " FROM useralert, user WHERE useralert.idUser = user.idUser AND user.idProject = " . $idProject);
		$arrQueries[] = array("useralertclause", $strOperation . " useralertclause" . ($intMode == 1 ? ".*" : "") . " FROM useralertclause, useralert, user WHERE useralertclause.idUserAlert = useralert.idUserAlert AND useralert.idUser = user.idUser AND user.idProject = " . $idProject);
		$arrQueries[] = array("useralertevent", $strOperation . " useralertevent" . ($intMode == 1 ? ".*" : "") . " FROM useralertevent, useralert, user WHERE useralertevent.idUserAlert = useralert.idUserAlert AND useralert.idUser = user.idUser AND user.idProject = " . $idProject);
		$arrQueries[] = array("userapisession", $strOperation . " userapisession" . ($intMode == 1 ? ".*" : "") . " FROM userapisession, user WHERE userapisession.idUser = user.idUser AND user.idProject = " . $idProject);
		$arrQueries[] = array("userfilter", $strOperation . " userfilter" . ($intMode == 1 ? ".*" : "") . " FROM userfilter, user WHERE userfilter.idUser = user.idUser AND user.idProject = " . $idProject);
		$arrQueries[] = array("userfilterclause", $strOperation . " userfilterclause" . ($intMode == 1 ? ".*" : "") . " FROM userfilterclause, user, userfilter WHERE userfilterclause.idUserFilter = userfilter.idUserFilter AND userfilter.idUser = user.idUser AND user.idProject = " . $idProject);
		$arrQueries[] = array("userimageoverlay", $strOperation . " userimageoverlay" . ($intMode == 1 ? ".*" : "") . " FROM userimageoverlay, user WHERE userimageoverlay.idUser = user.idUser AND user.idProject = " . $idProject);
		$arrQueries[] = array("userposition", $strOperation . " userposition" . ($intMode == 1 ? ".*" : "") . " FROM userposition, user WHERE userposition.idUser = user.idUser AND user.idProject = " . $idProject);
		$arrQueries[] = array("userprojectworkgroup", $strOperation . " userprojectworkgroup" . ($intMode == 1 ? ".*" : "") . " FROM userprojectworkgroup, user WHERE userprojectworkgroup.idUser = user.idUser AND user.idProject = " . $idProject);
		$arrQueries[] = array("datasource", $strOperation . " datasource" . ($intMode == 1 ? ".*" : "") . " FROM datasource WHERE idProject = " . $idProject);
		$arrQueries[] = array("datasourceparameter", $strOperation . " datasourceparameter" . ($intMode == 1 ? ".*" : "") . " FROM datasourceparameter, datasource WHERE datasourceparameter.idDataSource =  datasource.idDataSource AND datasource.idProject = " . $idProject);		
		$arrQueries[] = array("datasourceparameteruser", $strOperation . " datasourceparameteruser" . ($intMode == 1 ? ".*" : "") . " FROM datasourceparameteruser, user WHERE datasourceparameteruser.idUser = user.idUser AND user.idProject = " . $idProject);
		$arrQueries[] = array("datasourceusersearch", $strOperation . " datasourceusersearch" . ($intMode == 1 ? ".*" : "") . " FROM datasourceusersearch, user WHERE datasourceusersearch.idUser = user.idUser AND user.idProject = " . $idProject);
		$arrQueries[] = array("datasourceusersearchresult", $strOperation . " datasourceusersearchresult" . ($intMode == 1 ? ".*" : "") . " FROM datasourceusersearchresult, user WHERE datasourceusersearchresult.idUser = user.idUser AND user.idProject = " . $idProject);
		return $arrQueries;
	}
	
	public function backupBackup($idProject) {
		set_time_limit(10000);
		$arrProject = $this->selectProjects($idProject);
		$arrProject = $arrProject[0];
		$arrResult['idResult'] = 1;		
		// Generating SQL File
		$arrQueries = $this->arrBackupQueries($idProject, 1);
		$strSQL = '';
		foreach ($arrQueries as $arrQuery) {
			$strSQL .= $this->strSQLInserts($arrQuery[0], $arrQuery[1]);
		}
		$strSQLFileName = 'data-' . $idProject . '-' . date('Y-m-d-H-i', time()) . '.sql';
		$strSQLFileNameURL = $this->strings->strSiteTmpFileFolder . '/' . $strSQLFileName;
		$fh = fopen($strSQLFileNameURL, 'w');
		fwrite($fh, $strSQL);
		fclose($fh);
		// Create ZIP File to compress all
		$strBackupFolderPath = $this->strings->strProjectFolder . '/' . $arrProject['idProject'] . '/' . $this->strings->strBackupFolder;
		// Creating Backup Folder, if not exists
		if (! is_dir($strBackupFolderPath)) {
			mkdir($strBackupFolderPath);
		}
		$strBackupFileURL = $strBackupFolderPath . '/' . date('Y-m-d-H-i', time()) . '.zip';
		$zip = new ZipArchive();
		$strProjectFolderPath = $this->strings->strProjectFolder . '/' . $arrProject['idProject'];
		$arrFiles = $this->strings->returnFolderFilesList($strProjectFolderPath);
		$zip->open($strBackupFileURL, ZIPARCHIVE::CREATE);
		// Inserting SQL File
		$zip->addFile($strSQLFileNameURL, $strSQLFileName);
		$intTotalSizeMB = 0;
		// Inserting Project Files
		foreach ($arrFiles as $i => $strFile) {
			$strSourceFileFullPath = $strProjectFolderPath . '/' . $strFile;
			$intTotalSizeMB += @filesize($strSourceFileFullPath)/1000000;
			// If total files size greater than limit, stop adding files
			if ($intTotalSizeMB > $this->intBackupSizeLimitMB) break;			
			$zip->addFile($strSourceFileFullPath, $strFile);
		}
		$zip->close();
		@unlink($strSQLFileNameURL);
		$arrResult['strBackupFileURL'] = $strBackupFileURL;
		$arrResult['strBackupDateTime'] = date('d/m/Y H:i', time());
		$arrResult['strBackupNextDateTime'] = date('d/m/Y', strtotime("+" . $arrProject['intBackupFrequencyDays'] . " day"));
		// Update Last Execution Date
		$query = "UPDATE project SET dtBackupLastExecution = NOW() WHERE idProject = " . $arrProject['idProject'];
		$this->database->executeQuery($query);
		// Insert Event into Log
		$this->database->insertEvent(29, $arrProject['idUserCreator'], 'BACKUP PROJECT [' . $arrProject['strName'] . '] OWNER [' . $arrProject['strUserCreator'] . ']');
		// Delete files leaving just $this->intMaxBackups most recent ones
		$arrBackups = $this->strings->returnFolderFilesList($strBackupFolderPath);
		$arrBackups = array_reverse($arrBackups);
		foreach($arrBackups as $i => $strBackupFile) {
			if ($i < $this->intMaxBackups) continue;
			@unlink($strBackupFolderPath . '/' . $strBackupFile);
		}
		// Send Notification Mail
		$strBackupFileFullURL = $this->strings->strSiteURL . '/' . $strBackupFileURL;
		$arrSessions = array();
		$arrSessions[0]['strTitle'] = $_SESSION['stradmManageProjectBackupBackupFile'];
		$arrSessions[0]['strContent'] = '<img src="' . $this->strings->strSiteURL . '/img/filetypes/zip.png" style="height:24px" valign="absmiddle"> <a href="' . $strBackupFileFullURL . '">' . $strBackupFileFullURL . '</a>';
		$strBackupAvailableUntil = 
			$_SESSION['stradmManageProjectBackupBackupFileExpireNote'] . ' ' . 
			date('d/m/Y', strtotime("+" . ($this->intMaxBackups*$arrProject['intBackupFrequencyDays']) . " day"))
		;
		$strBody = $this->strings->mailFormatContent(2, $_SESSION['stradmManageProjectBackupBackupNotification'], $strBackupAvailableUntil, '', $arrSessions, '?idProject=' . $arrProject['idProject']);
		$strSubject = $this->strings->strUpperAccents($this->strings->strSiteName . ': ' . $_SESSION['stradmManageProjectBackupBackupNotification']);
		$this->strings->sendMail($strSubject, $strBody, $this->strings->strSiteEmail, $arrProject['strUserCreator'], $this->strings->strSiteEmail);
		return $arrResult;
	}

	public function backupRestore($idProject, $idUser, $strPassword, $strBackupFileURL) {
		// Checking Password
		$arrResult['idResult'] = -2;
		if ($this->blnUserExistsByIDPassword($idUser, $strPassword) !== true) {
			$arrResult['idResult'] = -1;
			return $arrResult;
		}
		// Continue...
		$zip = new ZipArchive;
		if ($zip->open($strBackupFileURL) !== TRUE) {
			return $arrResult;
		} else {
			$strProjectFolderPath = $this->strings->strProjectFolder . '/' . $idProject . '/';
			// Searching for SQL Data File
			for($i=0;$i<$zip->numFiles;$i++) { 
				$entry = $zip->getNameIndex($i);
				if(preg_match('#\.(sql)$#i', $entry)) {
					$strSQLDataFileName = $entry;
					// Copy SQL Data File to tmp Folder
					$zip->extractTo($this->strings->strSiteTmpFileFolder, array($strSQLDataFileName));
					$strSQLDataFilePathTmp = $this->strings->strSiteTmpFileFolder . '/' . $strSQLDataFileName;
					// Before that, delete all project data
					$arrQueries = $this->arrBackupQueries($idProject, 2);
					$arrQueries = array_reverse($arrQueries);
					$query = '';
					foreach ($arrQueries as $arrQuery) {
						$query .= $arrQuery[1] . ';' . chr(13);
					}
					$result = $this->database->executeMultiQuery($query);
					//if ($result === false) {return $arrResult;}
					// Process SQL Data File
					$query = trim(@file_get_contents($strSQLDataFilePathTmp));
					if (! $query) {
						return $arrResult;
					}
					$query = str_replace(chr(13), "\n\r", $query);
					$result = $this->database->executeMultiQuery($query);
					//if ($result === false) { return $arrResult;	}
					break;
				}
			}
			// Deleting SQL Data File from tmp Folder
			@unlink($strSQLDataFilePathTmp);
			// Extracting ZIP Files
			$arrFiles = $this->strings->returnFolderFilesList($strProjectFolderPath);
			// Delete Current Project Files
			foreach ($arrFiles as $i => $strFile) {
				@unlink($strProjectFolderPath . $strFile);
			}
			// Copy Zip Files to Folder
			$zip->extractTo($strProjectFolderPath);
			$zip->close();
			// Deleting SQL Data File from project folder
			@unlink($strProjectFolderPath . $strSQLDataFileName);
		}
		$arrResult['idResult'] = 1;
		return $arrResult;
	}
	
	public function blnUserExistsByIDPassword($idUser, $strPassword) {
		$query = "SELECT u.idUser FROM user u WHERE u.idUser = " . $idUser . " && u.strPassword = '" . md5($strPassword) . "'";
		$result = $this->database->executeQuery($query);
		$result = $this->database->prepareReturn($result);
		return count($result) > 0 ? true : false;
	}
}
?>