-- MySQL Workbench Forward Engineering

SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL,ALLOW_INVALID_DATES';

-- -----------------------------------------------------
-- Schema viconsaga
-- -----------------------------------------------------

-- -----------------------------------------------------
-- Table `country`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `country` ;

CREATE TABLE IF NOT EXISTS `country` (
  `idCountry` INT NOT NULL AUTO_INCREMENT,
  `strName` VARCHAR(50) NULL,
  `strCapital` VARCHAR(50) BINARY NULL,
  `strTelAreaCode` VARCHAR(5) NULL,
  `strCurrencySymbol` VARCHAR(20) NULL,
  `strLanguageCode` VARCHAR(8) NULL,
  PRIMARY KEY (`idCountry`))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `projectuserscope`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `projectuserscope` ;

CREATE TABLE IF NOT EXISTS `projectuserscope` (
  `idProjectUserScope` INT NOT NULL AUTO_INCREMENT,
  `strProjectUserScope` VARCHAR(50) NULL,
  PRIMARY KEY (`idProjectUserScope`))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csstheme`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `csstheme` ;

CREATE TABLE IF NOT EXISTS `csstheme` (
  `idCSSTheme` INT NOT NULL AUTO_INCREMENT,
  `strThemeName` VARCHAR(100) NULL,
  PRIMARY KEY (`idCSSTheme`))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `project`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `project` ;

CREATE TABLE IF NOT EXISTS `project` (
  `idProject` INT NOT NULL AUTO_INCREMENT,
  `idUserCreator` INT NULL,
  `blnActive` TINYINT(1) NOT NULL DEFAULT 1,
  `dtDateCreation` DATETIME NULL,
  `strAlias` VARCHAR(45) NULL,
  `strName` VARCHAR(255) NULL,
  `txtDescription` TEXT NULL,
  `strAddress` VARCHAR(244) NULL,
  `dblLatitude` FLOAT NULL,
  `dblLongitude` FLOAT NULL,
  `idCountry` INT NOT NULL DEFAULT 30,
  `strRGBColor` VARCHAR(10) NULL,
  `strGoogleAnalyticsID` VARCHAR(50) NULL,
  `strSkypeID` VARCHAR(50) NULL,
  `idCSSTheme` INT NOT NULL DEFAULT 1,
  `strLogoFile` VARCHAR(20) NULL,
  `strBackgroundFile` VARCHAR(20) NULL,
  `blnAllowAllView` TINYINT(1) NOT NULL DEFAULT 0,
  `blnAllowFormShare` TINYINT(1) NULL DEFAULT 1,
  `intAllowJoinAsLevel` INT NOT NULL DEFAULT 3,
  `idProjectUserViewScope` INT NOT NULL DEFAULT 1,
  `idProjectUserEditScope` INT NOT NULL DEFAULT 1,
  `intBackupFrequencyDays` INT UNSIGNED NOT NULL DEFAULT 30,
  `dtBackupLastExecution` DATETIME NULL,
  `blnMobileAllowEditCoordinates` TINYINT(1) NOT NULL DEFAULT 1,
  `intRecordClusterRadiusMts` INT NOT NULL DEFAULT 0,
  `blnMapClusterer` TINYINT(1) NOT NULL DEFAULT 1,
  PRIMARY KEY (`idProject`),
  INDEX `fk_attraction_country1_idx` (`idCountry` ASC),
  INDEX `fk_project_projectuserviewscope1_idx` (`idProjectUserViewScope` ASC),
  INDEX `fk_project_csstheme1_idx` (`idCSSTheme` ASC),
  INDEX `fk_project_projectuserviewscope2_idx` (`idProjectUserEditScope` ASC),
  CONSTRAINT `fk_attraction_country1`
    FOREIGN KEY (`idCountry`)
    REFERENCES `country` (`idCountry`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_project_projectuserviewscope1`
    FOREIGN KEY (`idProjectUserViewScope`)
    REFERENCES `projectuserscope` (`idProjectUserScope`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_project_csstheme1`
    FOREIGN KEY (`idCSSTheme`)
    REFERENCES `csstheme` (`idCSSTheme`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_project_projectuserviewscope2`
    FOREIGN KEY (`idProjectUserEditScope`)
    REFERENCES `projectuserscope` (`idProjectUserScope`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `userlevel`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `userlevel` ;

CREATE TABLE IF NOT EXISTS `userlevel` (
  `idUserLevel` INT NOT NULL AUTO_INCREMENT,
  `strLevel` VARCHAR(45) NULL,
  PRIMARY KEY (`idUserLevel`))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `user`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `user` ;

CREATE TABLE IF NOT EXISTS `user` (
  `idUser` INT NOT NULL AUTO_INCREMENT,
  `idProject` INT NOT NULL,
  `idUserLevel` INT NOT NULL DEFAULT 1,
  `blnDeleted` TINYINT(1) NOT NULL DEFAULT 0,
  `blnActive` TINYINT(1) NOT NULL DEFAULT 1,
  `dtRegister` DATETIME NULL,
  `strName` VARCHAR(100) NULL,
  `strEmail` VARCHAR(100) NULL,
  `strPassword` VARCHAR(45) NULL,
  `dblLatitude` DOUBLE NULL,
  `dblLongitude` DOUBLE NULL,
  `strProfilePhotoPath` VARCHAR(45) NULL,
  `strSkypeID` VARCHAR(50) NULL,
  PRIMARY KEY (`idUser`),
  INDEX `fk_user_project1_idx` (`idProject` ASC),
  INDEX `fk_user_userlevel1_idx` (`idUserLevel` ASC),
  CONSTRAINT `fk_user_project1`
    FOREIGN KEY (`idProject`)
    REFERENCES `project` (`idProject`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_user_userlevel1`
    FOREIGN KEY (`idUserLevel`)
    REFERENCES `userlevel` (`idUserLevel`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `support`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `support` ;

CREATE TABLE IF NOT EXISTS `support` (
  `idSupport` INT NOT NULL AUTO_INCREMENT,
  `idUser` INT NOT NULL,
  `dtDateTime` DATETIME NULL,
  `strSubject` VARCHAR(200) NULL,
  `txtMessage` TEXT NULL,
  `strFileName` VARCHAR(100) NULL,
  PRIMARY KEY (`idSupport`),
  INDEX `fk_support_exhibitor1_idx` (`idUser` ASC),
  CONSTRAINT `fk_support_exhibitor1`
    FOREIGN KEY (`idUser`)
    REFERENCES `user` (`idUser`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `supportresponse`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `supportresponse` ;

CREATE TABLE IF NOT EXISTS `supportresponse` (
  `idSupportResponse` INT NOT NULL AUTO_INCREMENT,
  `idSupport` INT NOT NULL,
  `dtDateTime` DATETIME NULL,
  `txtMessage` TEXT NULL,
  `blnFromSupport` TINYINT(1) NOT NULL DEFAULT 0,
  `blnRead` TINYINT(1) NOT NULL DEFAULT 0,
  PRIMARY KEY (`idSupportResponse`),
  INDEX `fk_supportresponse_support1_idx` (`idSupport` ASC),
  CONSTRAINT `fk_supportresponse_support1`
    FOREIGN KEY (`idSupport`)
    REFERENCES `support` (`idSupport`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `datum`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datum` ;

CREATE TABLE IF NOT EXISTS `datum` (
  `idDatum` INT NOT NULL AUTO_INCREMENT,
  `strName` VARCHAR(100) NULL,
  `dblA` DOUBLE NULL,
  `dblE2` DOUBLE NULL,
  PRIMARY KEY (`idDatum`))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `projectworkgroup`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `projectworkgroup` ;

CREATE TABLE IF NOT EXISTS `projectworkgroup` (
  `idProjectWorkgroup` INT NULL AUTO_INCREMENT,
  `idProject` INT NOT NULL,
  `strWorkgroup` VARCHAR(100) NULL,
  PRIMARY KEY (`idProjectWorkgroup`),
  INDEX `fk_projectusergroup_project1_idx` (`idProject` ASC),
  CONSTRAINT `fk_projectusergroup_project1`
    FOREIGN KEY (`idProject`)
    REFERENCES `project` (`idProject`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `eventtype`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `eventtype` ;

CREATE TABLE IF NOT EXISTS `eventtype` (
  `idEventType` INT NOT NULL AUTO_INCREMENT,
  `strEventType` VARCHAR(45) NULL,
  PRIMARY KEY (`idEventType`))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `event`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `event` ;

CREATE TABLE IF NOT EXISTS `event` (
  `idEvent` INT NOT NULL AUTO_INCREMENT,
  `idEventType` INT NOT NULL,
  `idUser` INT NULL,
  `dtDateTime` DATETIME NULL,
  `strParam1` VARCHAR(100) NULL,
  `strParam2` VARCHAR(100) NULL,
  `strParam3` VARCHAR(100) NULL,
  PRIMARY KEY (`idEvent`),
  INDEX `fk_usereventlog_usereventtype1_idx` (`idEventType` ASC),
  CONSTRAINT `fk_usereventlog_usereventtype1`
    FOREIGN KEY (`idEventType`)
    REFERENCES `eventtype` (`idEventType`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `marker`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `marker` ;

CREATE TABLE IF NOT EXISTS `marker` (
  `idMarker` INT NOT NULL AUTO_INCREMENT,
  `strMarkerFileName` VARCHAR(45) NULL,
  `idProject` INT NULL,
  PRIMARY KEY (`idMarker`),
  INDEX `fk_marker_project1_idx` (`idProject` ASC),
  CONSTRAINT `fk_marker_project1`
    FOREIGN KEY (`idProject`)
    REFERENCES `project` (`idProject`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `datasource`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datasource` ;

CREATE TABLE IF NOT EXISTS `datasource` (
  `idDataSource` INT NOT NULL AUTO_INCREMENT,
  `idProject` INT NOT NULL,
  `strName` VARCHAR(100) NOT NULL,
  `strSiteURL` VARCHAR(150) NULL,
  `strLogoFileName` VARCHAR(255) NULL,
  `strScriptPHPFileName` VARCHAR(255) NULL,
  `strGETParameterq` VARCHAR(45) NULL,
  `strGETParameterlimit` VARCHAR(45) NULL,
  `strResultTimeSeriesFields` VARCHAR(45) NULL,
  `intUpdateFrequencyMin` INT UNSIGNED NOT NULL DEFAULT 60,
  `blnActive` TINYINT(1) NOT NULL DEFAULT 1,
  `blnPublic` TINYINT(1) NOT NULL DEFAULT 1,
  PRIMARY KEY (`idDataSource`))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `form`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `form` ;

CREATE TABLE IF NOT EXISTS `form` (
  `idForm` INT NOT NULL AUTO_INCREMENT,
  `idProject` INT NOT NULL,
  `idDataSource` INT NOT NULL DEFAULT 1,
  `idMarker` INT NOT NULL,
  `dtCreation` DATETIME NULL,
  `dtLastUpdate` DATETIME NULL,
  `strName` VARCHAR(100) NULL,
  `blnActive` TINYINT(1) NOT NULL DEFAULT 1,
  PRIMARY KEY (`idForm`),
  INDEX `fk_form_project1_idx` (`idProject` ASC),
  INDEX `fk_form_marker1_idx` (`idMarker` ASC),
  INDEX `fk_form_infosource1_idx` (`idDataSource` ASC),
  CONSTRAINT `fk_form_project1`
    FOREIGN KEY (`idProject`)
    REFERENCES `project` (`idProject`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_form_marker1`
    FOREIGN KEY (`idMarker`)
    REFERENCES `marker` (`idMarker`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_form_infosource1`
    FOREIGN KEY (`idDataSource`)
    REFERENCES `datasource` (`idDataSource`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `formfieldtype`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `formfieldtype` ;

CREATE TABLE IF NOT EXISTS `formfieldtype` (
  `idFormFieldType` INT NOT NULL AUTO_INCREMENT,
  `strFormFieldType` VARCHAR(45) NULL,
  PRIMARY KEY (`idFormFieldType`))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `formfield`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `formfield` ;

CREATE TABLE IF NOT EXISTS `formfield` (
  `idFormField` INT NOT NULL AUTO_INCREMENT,
  `idForm` INT NOT NULL,
  `idFormFieldType` INT NOT NULL,
  `strName` VARCHAR(255) NULL,
  `strTip` VARCHAR(255) NULL,
  `intOrder` INT NULL,
  `blnActive` TINYINT(1) NULL,
  PRIMARY KEY (`idFormField`),
  INDEX `fk_formfield_form1_idx` (`idForm` ASC),
  INDEX `fk_formfield_formfieldtype1_idx` (`idFormFieldType` ASC),
  CONSTRAINT `fk_formfield_form1`
    FOREIGN KEY (`idForm`)
    REFERENCES `form` (`idForm`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_formfield_formfieldtype1`
    FOREIGN KEY (`idFormFieldType`)
    REFERENCES `formfieldtype` (`idFormFieldType`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `device`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `device` ;

CREATE TABLE IF NOT EXISTS `device` (
  `idDevice` INT NOT NULL AUTO_INCREMENT,
  `strName` VARCHAR(45) NULL,
  PRIMARY KEY (`idDevice`))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `shapetype`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `shapetype` ;

CREATE TABLE IF NOT EXISTS `shapetype` (
  `idShapeType` INT NOT NULL AUTO_INCREMENT,
  `strShapeType` VARCHAR(45) NULL,
  PRIMARY KEY (`idShapeType`))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `formrecord`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `formrecord` ;

CREATE TABLE IF NOT EXISTS `formrecord` (
  `idFormRecord` INT NOT NULL AUTO_INCREMENT,
  `idUser` INT NOT NULL,
  `idForm` INT NOT NULL,
  `idDevice` INT NOT NULL DEFAULT 1,
  `idShapeType` INT NOT NULL,
  `strCustomMarkerRGBColor` VARCHAR(255) NULL,
  `dtCreation` DATETIME NULL,
  `dtLastUpdate` DATETIME NULL,
  PRIMARY KEY (`idFormRecord`),
  INDEX `fk_formrecord_user1_idx` (`idUser` ASC),
  INDEX `fk_formrecord_form1_idx` (`idForm` ASC),
  INDEX `fk_formrecord_device1_idx` (`idDevice` ASC),
  INDEX `fk_formrecord_shapetype1_idx` (`idShapeType` ASC),
  CONSTRAINT `fk_formrecord_user1`
    FOREIGN KEY (`idUser`)
    REFERENCES `user` (`idUser`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_formrecord_form1`
    FOREIGN KEY (`idForm`)
    REFERENCES `form` (`idForm`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_formrecord_device1`
    FOREIGN KEY (`idDevice`)
    REFERENCES `device` (`idDevice`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_formrecord_shapetype1`
    FOREIGN KEY (`idShapeType`)
    REFERENCES `shapetype` (`idShapeType`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `userapisession`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `userapisession` ;

CREATE TABLE IF NOT EXISTS `userapisession` (
  `idUserAPISession` INT NOT NULL AUTO_INCREMENT,
  `idUser` INT NOT NULL,
  `dtDate` DATETIME NULL,
  `strKey` VARCHAR(45) NULL,
  PRIMARY KEY (`idUserAPISession`),
  INDEX `fk_APISession_user1_idx` (`idUser` ASC),
  CONSTRAINT `fk_APISession_user1`
    FOREIGN KEY (`idUser`)
    REFERENCES `user` (`idUser`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `userposition`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `userposition` ;

CREATE TABLE IF NOT EXISTS `userposition` (
  `idUserPosition` INT NOT NULL AUTO_INCREMENT,
  `idUser` INT NOT NULL,
  `dtDate` DATETIME NULL,
  `dblLatitude` DOUBLE NULL,
  `dblLongitude` DOUBLE NULL,
  PRIMARY KEY (`idUserPosition`),
  INDEX `fk_userposition_user1_idx` (`idUser` ASC),
  CONSTRAINT `fk_userposition_user1`
    FOREIGN KEY (`idUser`)
    REFERENCES `user` (`idUser`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `formrecordvertex`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `formrecordvertex` ;

CREATE TABLE IF NOT EXISTS `formrecordvertex` (
  `idFormRecordVertex` INT NOT NULL AUTO_INCREMENT,
  `idFormRecord` INT NOT NULL,
  `dblLatitude` DOUBLE NULL,
  `dblLongitude` DOUBLE NULL,
  `intPosition` INT NULL,
  PRIMARY KEY (`idFormRecordVertex`),
  INDEX `fk_formrecordvertex_formrecord1_idx` (`idFormRecord` ASC),
  CONSTRAINT `fk_formrecordvertex_formrecord1`
    FOREIGN KEY (`idFormRecord`)
    REFERENCES `formrecord` (`idFormRecord`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `formrecordfield`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `formrecordfield` ;

CREATE TABLE IF NOT EXISTS `formrecordfield` (
  `idFormRecordField` INT NOT NULL AUTO_INCREMENT,
  `idFormField` INT NOT NULL,
  `idFormRecord` INT NOT NULL,
  PRIMARY KEY (`idFormRecordField`),
  INDEX `fk_formrecordfield_formfield1_idx` (`idFormField` ASC),
  INDEX `fk_formrecordfield_formrecord1_idx` (`idFormRecord` ASC),
  CONSTRAINT `fk_formrecordfield_formfield1`
    FOREIGN KEY (`idFormField`)
    REFERENCES `formfield` (`idFormField`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_formrecordfield_formrecord1`
    FOREIGN KEY (`idFormRecord`)
    REFERENCES `formrecord` (`idFormRecord`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `formrecordfieldtext`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `formrecordfieldtext` ;

CREATE TABLE IF NOT EXISTS `formrecordfieldtext` (
  `idText` INT NOT NULL AUTO_INCREMENT,
  `idFormRecordField` INT NOT NULL,
  `strValue` TEXT NULL,
  PRIMARY KEY (`idText`),
  INDEX `fk_formrecordfieldtext_formrecordfield1_idx` (`idFormRecordField` ASC),
  CONSTRAINT `fk_formrecordfieldtext_formrecordfield1`
    FOREIGN KEY (`idFormRecordField`)
    REFERENCES `formrecordfield` (`idFormRecordField`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `formrecordfieldnumeric`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `formrecordfieldnumeric` ;

CREATE TABLE IF NOT EXISTS `formrecordfieldnumeric` (
  `idNumeric` INT NOT NULL AUTO_INCREMENT,
  `idFormRecordField` INT NOT NULL,
  `dblValue` DOUBLE NULL,
  PRIMARY KEY (`idNumeric`),
  INDEX `fk_formrecordfieldtext_formrecordfield1_idx` (`idFormRecordField` ASC),
  CONSTRAINT `fk_formrecordfieldtext_formrecordfield10`
    FOREIGN KEY (`idFormRecordField`)
    REFERENCES `formrecordfield` (`idFormRecordField`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `formfieldalternative`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `formfieldalternative` ;

CREATE TABLE IF NOT EXISTS `formfieldalternative` (
  `idFormFieldAlternative` INT NOT NULL AUTO_INCREMENT,
  `idFormField` INT NOT NULL,
  `strAlternative` VARCHAR(255) NULL,
  `blnPublic` TINYINT(1) NOT NULL DEFAULT 1,
  `intOrder` INT NOT NULL DEFAULT 1,
  PRIMARY KEY (`idFormFieldAlternative`),
  INDEX `fk_formfieldalternative_formfield1_idx` (`idFormField` ASC),
  CONSTRAINT `fk_formfieldalternative_formfield1`
    FOREIGN KEY (`idFormField`)
    REFERENCES `formfield` (`idFormField`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `formrecordfieldalternative`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `formrecordfieldalternative` ;

CREATE TABLE IF NOT EXISTS `formrecordfieldalternative` (
  `idFormRecordFieldAlternative` INT NOT NULL AUTO_INCREMENT,
  `idFormRecordField` INT NOT NULL,
  `idFormFieldAlternative` INT NOT NULL,
  PRIMARY KEY (`idFormRecordFieldAlternative`),
  INDEX `fk_formrecordfieldtext_formrecordfield1_idx` (`idFormRecordField` ASC),
  INDEX `fk_formrecordfieldmultiplechoice_formfieldalternative1_idx` (`idFormFieldAlternative` ASC),
  CONSTRAINT `fk_formrecordfieldtext_formrecordfield100`
    FOREIGN KEY (`idFormRecordField`)
    REFERENCES `formrecordfield` (`idFormRecordField`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_formrecordfieldmultiplechoice_formfieldalternative1`
    FOREIGN KEY (`idFormFieldAlternative`)
    REFERENCES `formfieldalternative` (`idFormFieldAlternative`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `formrecordfile`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `formrecordfile` ;

CREATE TABLE IF NOT EXISTS `formrecordfile` (
  `idFormRecordFile` INT NOT NULL AUTO_INCREMENT,
  `idFormRecord` INT NULL,
  `strFileName` VARCHAR(255) NULL,
  `strFileOriginalName` VARCHAR(255) NULL,
  `strDescription` VARCHAR(255) NULL,
  `intPosition` INT NULL,
  `intFileSizeBytes` INT NULL,
  PRIMARY KEY (`idFormRecordFile`),
  INDEX `fk_formrecordfile_formrecord1_idx` (`idFormRecord` ASC),
  CONSTRAINT `fk_formrecordfile_formrecord1`
    FOREIGN KEY (`idFormRecord`)
    REFERENCES `formrecord` (`idFormRecord`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `formrecordfielddate`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `formrecordfielddate` ;

CREATE TABLE IF NOT EXISTS `formrecordfielddate` (
  `idFormRecordFieldDate` INT NOT NULL AUTO_INCREMENT,
  `idFormRecordField` INT NOT NULL,
  `dtValue` DATE NULL,
  PRIMARY KEY (`idFormRecordFieldDate`),
  INDEX `fk_formrecordfielddatetime_formrecordfield1_idx` (`idFormRecordField` ASC),
  CONSTRAINT `fk_formrecordfielddatetime_formrecordfield1`
    FOREIGN KEY (`idFormRecordField`)
    REFERENCES `formrecordfield` (`idFormRecordField`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `projectsearch`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `projectsearch` ;

CREATE TABLE IF NOT EXISTS `projectsearch` (
  `idProjectSearch` INT NOT NULL AUTO_INCREMENT,
  `idProject` INT NOT NULL,
  `dtDateSearch` DATETIME NULL,
  `strSearch` VARCHAR(50) NULL,
  PRIMARY KEY (`idProjectSearch`),
  INDEX `fk_projectsearch_project1_idx` (`idProject` ASC),
  CONSTRAINT `fk_projectsearch_project1`
    FOREIGN KEY (`idProject`)
    REFERENCES `project` (`idProject`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `formrecordfieldtime`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `formrecordfieldtime` ;

CREATE TABLE IF NOT EXISTS `formrecordfieldtime` (
  `idFormRecordFieldTime` INT NOT NULL AUTO_INCREMENT,
  `idFormRecordField` INT NOT NULL,
  `tmValue` TIME NULL,
  PRIMARY KEY (`idFormRecordFieldTime`),
  INDEX `fk_formrecordfielddatetime_formrecordfield1_idx` (`idFormRecordField` ASC),
  CONSTRAINT `fk_formrecordfielddatetime_formrecordfield10`
    FOREIGN KEY (`idFormRecordField`)
    REFERENCES `formrecordfield` (`idFormRecordField`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `formrecordfieldtimeserie`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `formrecordfieldtimeserie` ;

CREATE TABLE IF NOT EXISTS `formrecordfieldtimeserie` (
  `idFormRecordFieldTimeSerie` INT NOT NULL AUTO_INCREMENT,
  `idFormRecordField` INT NOT NULL,
  `dtDateTime` DATETIME NULL,
  `strValue` VARCHAR(100) NULL,
  PRIMARY KEY (`idFormRecordFieldTimeSerie`),
  INDEX `fk_formrecordfieldtimeserie_formrecordfield1_idx` (`idFormRecordField` ASC),
  CONSTRAINT `fk_formrecordfieldtimeserie_formrecordfield1`
    FOREIGN KEY (`idFormRecordField`)
    REFERENCES `formrecordfield` (`idFormRecordField`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `userprojectworkgroup`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `userprojectworkgroup` ;

CREATE TABLE IF NOT EXISTS `userprojectworkgroup` (
  `idUser` INT NOT NULL,
  `idProjectWorkgroup` INT NOT NULL,
  INDEX `fk_userprojectworkgroup_user1_idx` (`idUser` ASC),
  INDEX `fk_userprojectworkgroup_projectworkgroup1_idx` (`idProjectWorkgroup` ASC),
  CONSTRAINT `fk_userprojectworkgroup_user1`
    FOREIGN KEY (`idUser`)
    REFERENCES `user` (`idUser`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_userprojectworkgroup_projectworkgroup1`
    FOREIGN KEY (`idProjectWorkgroup`)
    REFERENCES `projectworkgroup` (`idProjectWorkgroup`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `userfilter`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `userfilter` ;

CREATE TABLE IF NOT EXISTS `userfilter` (
  `idUserFilter` INT NOT NULL AUTO_INCREMENT,
  `idUser` INT NOT NULL,
  `idMarker` INT NULL,
  `strName` VARCHAR(100) NULL,
  PRIMARY KEY (`idUserFilter`))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `userfilterclause`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `userfilterclause` ;

CREATE TABLE IF NOT EXISTS `userfilterclause` (
  `idUserFilterClause` INT NOT NULL AUTO_INCREMENT,
  `idUserFilter` INT NOT NULL,
  `idFormField` INT NOT NULL,
  `intOperator` INT NOT NULL DEFAULT 1,
  `strValue` VARCHAR(100) NULL,
  PRIMARY KEY (`idUserFilterClause`),
  INDEX `fk_userfilterclause_userfilter1_idx` (`idUserFilter` ASC),
  INDEX `fk_userfilterclause_formfield1_idx` (`idFormField` ASC),
  CONSTRAINT `fk_userfilterclause_userfilter1`
    FOREIGN KEY (`idUserFilter`)
    REFERENCES `userfilter` (`idUserFilter`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_userfilterclause_formfield1`
    FOREIGN KEY (`idFormField`)
    REFERENCES `formfield` (`idFormField`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `toponymy`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `toponymy` ;

CREATE TABLE IF NOT EXISTS `toponymy` (
  `idToponymy` INT NOT NULL AUTO_INCREMENT,
  `idUser` INT NOT NULL,
  `dblLatitude` DOUBLE NULL,
  `dblLongitude` DOUBLE NULL,
  `strToponymy` VARCHAR(100) NULL,
  `strCSS` VARCHAR(255) NULL,
  PRIMARY KEY (`idToponymy`),
  INDEX `fk_maplabel_user1_idx` (`idUser` ASC),
  CONSTRAINT `fk_maplabel_user1`
    FOREIGN KEY (`idUser`)
    REFERENCES `user` (`idUser`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `useralert`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `useralert` ;

CREATE TABLE IF NOT EXISTS `useralert` (
  `idUserAlert` INT NOT NULL AUTO_INCREMENT,
  `idUser` INT NOT NULL,
  `idForm` INT NOT NULL,
  `dtCreation` DATETIME NULL,
  `strName` VARCHAR(100) NULL,
  `blnOnRecordCreate` TINYINT(1) NOT NULL DEFAULT 0,
  `blnOnRecordUpdate` TINYINT(1) NOT NULL DEFAULT 0,
  `blnOnRecordDelete` TINYINT(1) NOT NULL DEFAULT 0,
  `strActionEmailTo` VARCHAR(45) NULL,
  `intNotifyAfterDaysFromEvent` INT UNSIGNED NOT NULL DEFAULT 0,
  `blnActive` TINYINT(1) NOT NULL DEFAULT 1,
  PRIMARY KEY (`idUserAlert`),
  INDEX `fk_useralert_user1_idx` (`idUser` ASC),
  INDEX `fk_useralert_form1_idx` (`idForm` ASC),
  CONSTRAINT `fk_useralert_user1`
    FOREIGN KEY (`idUser`)
    REFERENCES `user` (`idUser`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_useralert_form1`
    FOREIGN KEY (`idForm`)
    REFERENCES `form` (`idForm`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `useralertclause`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `useralertclause` ;

CREATE TABLE IF NOT EXISTS `useralertclause` (
  `idUserAlertClause` INT NOT NULL AUTO_INCREMENT,
  `idUserAlert` INT NOT NULL,
  `idFormField` INT NOT NULL,
  `strOperador` VARCHAR(3) NULL,
  `strValue` VARCHAR(100) NULL,
  INDEX `fk_useralertclause_useralert1_idx` (`idUserAlert` ASC),
  INDEX `fk_useralertclause_formfield1_idx` (`idFormField` ASC),
  PRIMARY KEY (`idUserAlertClause`),
  CONSTRAINT `fk_useralertclause_useralert1`
    FOREIGN KEY (`idUserAlert`)
    REFERENCES `useralert` (`idUserAlert`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_useralertclause_formfield1`
    FOREIGN KEY (`idFormField`)
    REFERENCES `formfield` (`idFormField`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `useralertevent`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `useralertevent` ;

CREATE TABLE IF NOT EXISTS `useralertevent` (
  `idUserAlertEvent` INT NOT NULL AUTO_INCREMENT,
  `idUserAlert` INT NOT NULL,
  `idEventType` INT NOT NULL,
  `dtDateTime` DATETIME NULL,
  `idUser` INT NULL,
  `idFormRecord` INT NULL,
  `dblLatitude` DOUBLE NULL,
  `dblLongitude` DOUBLE NULL,
  `txtDetails` TEXT NULL,
  `blnRead` TINYINT(1) NOT NULL DEFAULT 0,
  `blnNotified` TINYINT(1) NOT NULL DEFAULT 0,
  `blnSolved` TINYINT(1) NOT NULL DEFAULT 0,
  INDEX `fk_useralertevents_useralert1_idx` (`idUserAlert` ASC),
  PRIMARY KEY (`idUserAlertEvent`),
  INDEX `fk_useralertevent_eventtype1_idx` (`idEventType` ASC),
  CONSTRAINT `fk_useralertevents_useralert1`
    FOREIGN KEY (`idUserAlert`)
    REFERENCES `useralert` (`idUserAlert`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_useralertevent_eventtype1`
    FOREIGN KEY (`idEventType`)
    REFERENCES `eventtype` (`idEventType`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `formrecordlog`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `formrecordlog` ;

CREATE TABLE IF NOT EXISTS `formrecordlog` (
  `idFormRecordLog` INT NOT NULL AUTO_INCREMENT,
  `idFormRecord` INT NOT NULL,
  `idUser` INT NOT NULL,
  `dtDateTime` DATETIME NULL,
  `txtLog` TEXT NULL,
  PRIMARY KEY (`idFormRecordLog`),
  INDEX `fk_formrecordlog_formrecord1_idx` (`idFormRecord` ASC),
  INDEX `fk_formrecordlog_user1_idx` (`idUser` ASC),
  CONSTRAINT `fk_formrecordlog_formrecord1`
    FOREIGN KEY (`idFormRecord`)
    REFERENCES `formrecord` (`idFormRecord`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_formrecordlog_user1`
    FOREIGN KEY (`idUser`)
    REFERENCES `user` (`idUser`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `userimageoverlay`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `userimageoverlay` ;

CREATE TABLE IF NOT EXISTS `userimageoverlay` (
  `idUserImageOverlay` INT NOT NULL AUTO_INCREMENT,
  `idUser` INT NOT NULL,
  `dblLatSW` DOUBLE NULL,
  `dblLongSW` DOUBLE NULL,
  `dblLatNE` DOUBLE NULL,
  `dblLongNE` DOUBLE NULL,
  `strName` VARCHAR(100) NULL,
  `strFileName` VARCHAR(255) NULL,
  PRIMARY KEY (`idUserImageOverlay`),
  INDEX `fk_userimageoverlay_user1_idx` (`idUser` ASC),
  CONSTRAINT `fk_userimageoverlay_user1`
    FOREIGN KEY (`idUser`)
    REFERENCES `user` (`idUser`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `datasourceusersearchresult`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datasourceusersearchresult` ;

CREATE TABLE IF NOT EXISTS `datasourceusersearchresult` (
  `idDataSourceUserSearchResult` INT NOT NULL AUTO_INCREMENT,
  `idUser` INT NOT NULL,
  `idDataSource` INT NOT NULL,
  `idFormRecord` INT NULL,
  `strID` VARCHAR(50) NULL,
  `dtCreated` DATETIME NULL,
  `dblLatitude` DOUBLE NULL,
  `dblLongitude` DOUBLE NULL,
  `strAttachedFiles` TEXT NULL,
  `txtXML` TEXT NULL,
  PRIMARY KEY (`idDataSourceUserSearchResult`),
  INDEX `fk_datasourceusersearchresult_user1_idx` (`idUser` ASC),
  INDEX `fk_datasourceusersearchresult_datasource1_idx` (`idDataSource` ASC),
  CONSTRAINT `fk_datasourceusersearchresult_user1`
    FOREIGN KEY (`idUser`)
    REFERENCES `user` (`idUser`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_datasourceusersearchresult_datasource1`
    FOREIGN KEY (`idDataSource`)
    REFERENCES `datasource` (`idDataSource`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `datasourceparameter`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datasourceparameter` ;

CREATE TABLE IF NOT EXISTS `datasourceparameter` (
  `idDataSourceParameter` INT NOT NULL AUTO_INCREMENT,
  `idDataSource` INT NOT NULL,
  `strName` VARCHAR(50) NULL,
  `txtDescription` TEXT NULL,
  `strDefaultValue` VARCHAR(100) NULL,
  `blnMandatory` TINYINT(1) NOT NULL DEFAULT 0,
  PRIMARY KEY (`idDataSourceParameter`),
  INDEX `fk_datasourceparameter_datasource1_idx` (`idDataSource` ASC),
  CONSTRAINT `fk_datasourceparameter_datasource1`
    FOREIGN KEY (`idDataSource`)
    REFERENCES `datasource` (`idDataSource`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `datasourceparameteruser`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datasourceparameteruser` ;

CREATE TABLE IF NOT EXISTS `datasourceparameteruser` (
  `idDataSourceParameter` INT NOT NULL,
  `idUser` INT NOT NULL,
  `strValue` VARCHAR(500) NULL,
  INDEX `fk_datasourceparameteruser_datasourceparameter1_idx` (`idDataSourceParameter` ASC),
  INDEX `fk_datasourceparameteruser_user1_idx` (`idUser` ASC),
  PRIMARY KEY (`idDataSourceParameter`, `idUser`),
  CONSTRAINT `fk_datasourceparameteruser_datasourceparameter1`
    FOREIGN KEY (`idDataSourceParameter`)
    REFERENCES `datasourceparameter` (`idDataSourceParameter`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_datasourceparameteruser_user1`
    FOREIGN KEY (`idUser`)
    REFERENCES `user` (`idUser`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `datasourceusersearch`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datasourceusersearch` ;

CREATE TABLE IF NOT EXISTS `datasourceusersearch` (
  `idDataSource` INT NOT NULL,
  `idUser` INT NOT NULL,
  `strKeyword` VARCHAR(50) NULL,
  `dtSearch` DATETIME NOT NULL DEFAULT NOW(),
  INDEX `fk_datasourcesearchuser_user1_idx` (`idUser` ASC),
  INDEX `fk_datasourcesearchuser_datasource1_idx` (`idDataSource` ASC),
  PRIMARY KEY (`idDataSource`, `idUser`),
  CONSTRAINT `fk_datasourcesearchuser_user1`
    FOREIGN KEY (`idUser`)
    REFERENCES `user` (`idUser`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_datasourcesearchuser_datasource1`
    FOREIGN KEY (`idDataSource`)
    REFERENCES `datasource` (`idDataSource`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;

-- -----------------------------------------------------
-- Data for table `country`
-- -----------------------------------------------------
START TRANSACTION;
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (1, 'Afghanistan', 'Kabul', '93', 'AFN', 'af');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (2, 'Albania', 'Tirana', '355', 'ALL', 'al');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (3, 'Algeria', 'Algiers', '213', 'DZD', 'dz');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (4, 'American Samoa', 'Pago Pago', '684', 'USD', 'as');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (5, 'Andorra', 'Andorra', '376', 'EUR', 'ad');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (6, 'Angola', 'Luanda', '244', 'AOA', 'ao');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (7, 'Anguilla', 'The Valley', '1264', 'XCD', 'ai');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (8, 'Antarctica', 'None', '672', 'XCD', 'aq');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (9, 'Antigua and Barbuda', 'St. Johns', '1268', 'XCD', 'ag');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (10, 'Argentina', 'Buenos Aires', '54', 'ARS', 'ar');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (11, 'Armenia', 'Yerevan', '374', 'AMD', 'am');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (12, 'Aruba', 'Oranjestad', '297', 'AWG', 'aw');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (13, 'Australia', 'Canberra', '61', 'AUD', 'au');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (14, 'Austria', 'Vienna', '43', 'EUR', 'at');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (15, 'Azerbaijan', 'Baku', '994', 'AZN', 'az');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (16, 'Bahamas', 'Nassau', '1242', 'BSD', 'bs');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (17, 'Bahrain', 'Al-Manamah', '973', 'BHD', 'bh');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (18, 'Bangladesh', 'Dhaka', '880', 'BDT', 'bd');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (19, 'Barbados', 'Bridgetown', '1246', 'BBD', 'bb');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (20, 'Belarus', 'Minsk', '375', 'BYR', 'by');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (21, 'Belgium', 'Brussels', '32', 'EUR', 'be');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (22, 'Belize', 'Belmopan', '501', 'BZD', 'bz');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (23, 'Benin', 'Porto-Novo', '229', 'XOF', 'bj');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (24, 'Bermuda', 'Hamilton', '1441', 'BMD', 'bm');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (25, 'Bhutan', 'Thimphu', '975', 'BTN', 'bt');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (26, 'Bolivia', 'La Paz', '591', 'BOB', 'bo');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (27, 'Bosnia-Herzegovina', 'Sarajevo', '387', 'BAM', 'ba');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (28, 'Botswana', 'Gaborone', '267', 'BWP', 'bw');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (29, 'Bouvet Island', 'None', '0', 'NOK', 'bv');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (30, 'Brazil', 'Brasilia', '55', 'BRL', 'br');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (31, 'British Indian Ocean Territory', 'None', '0', 'USD', 'io');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (32, 'Brunei Darussalam', 'Bandar Seri Begawan', '673', 'BND', 'bn');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (33, 'Bulgaria', 'Sofia', '359', 'BGN', 'bg');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (34, 'Burkina Faso', 'Ouagadougou', '226', 'XOF', 'bf');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (35, 'Burundi', 'Bujumbura', '257', 'BIF', 'bi');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (36, 'Cambodia', 'Phnom Penh', '855', 'KHR', 'kh');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (37, 'Cameroon', 'Yaounde', '237', 'XAF', 'cm');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (38, 'Canada', 'Ottawa', '1', 'CAD', 'ca');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (39, 'Cape Verde', 'Praia', '238', 'CVE', 'cv');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (40, 'Cayman Islands', 'Georgetown', '0', 'KYD', 'ky');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (41, 'Central African Republic', 'Bangui', '236', 'XAF', 'cf');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (42, 'Chad', 'NDjamena', '235', 'XAF', 'td');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (43, 'Chile', 'Santiago', '56', 'CLP', 'cl');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (44, 'China', 'Beijing', '86', 'CNY', 'cn');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (45, 'Christmas Island', 'The Settlement', '61', 'AUD', 'cx');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (46, 'Cocos Keeling Islands', 'West Island', '61', 'AUD', 'cc');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (47, 'Colombia', 'Bogota', '57', 'COP', 'co');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (48, 'Comoros', 'Moroni', '269', 'KMF', 'km');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (49, 'Congo', 'Brazzaville', '242', 'XAF', 'cg');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (50, 'Congo', 'Dem. Republic Kinshasa', '243', 'CDF', 'cd');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (51, 'Cook Islands', 'Avarua', '682', 'NZD', 'ck');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (52, 'Costa Rica', 'San Jose', '506', 'CRC', 'cr');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (53, 'Croatia', 'Zagreb', '385', 'HRK', 'hr');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (54, 'Cuba', 'Havana', '53', 'CUP', 'cu');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (55, 'Cyprus', 'Nicosia', '357', 'EUR', 'cy');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (56, 'Czech Rep.', 'Prague', '420', 'CZK', 'cz');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (57, 'Denmark', 'Copenhagen', '45', 'DKK', 'dk');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (58, 'Djibouti', 'Djibouti', '253', 'DJF', 'dj');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (59, 'Dominica', 'Roseau', '1767', 'XCD', 'dm');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (60, 'Dominican Republic', 'Santo Domingo', '809', 'DOP', 'do');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (61, 'Ecuador', 'Quito', '593', 'ECS', 'ec');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (62, 'Egypt', 'Cairo', '20', 'EGP', 'eg');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (63, 'El Salvador', 'San Salvador', '503', 'SVC', 'sv');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (64, 'Equatorial Guinea', 'Malabo', '240', 'XAF', 'gq');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (65, 'Eritrea', 'Asmara', '291', 'ERN', 'er');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (66, 'Estonia', 'Tallinn', '372', 'EUR', 'ee');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (67, 'Ethiopia', 'Addis Ababa', '251', 'ETB', 'et');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (68, 'European Union', 'Brussels', '0', 'EUR', 'eu.int');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (69, 'Falkland Islands Malvinas', 'Stanley', '500', 'FKP', 'fk');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (70, 'Faroe Islands', 'Torshavn', '298', 'DKK', 'fo');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (71, 'Fiji', 'Suva', '679', 'FJD', 'fj');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (72, 'Finland', 'Helsinki', '358', 'EUR', 'fi');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (73, 'France', 'Paris', '33', 'EUR', 'fr');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (74, 'French Guiana', 'Cayenne', '594', 'EUR', 'gf');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (75, 'French Southern Territories', 'None', '0', 'EUR', 'tf');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (76, 'Gabon', 'Libreville', '241', 'XAF', 'ga');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (77, 'Gambia', 'Banjul', '220', 'GMD', 'gm');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (78, 'Georgia', 'Tbilisi', '995', 'GEL', 'ge');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (79, 'Germany', 'Berlin', '49', 'EUR', 'de');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (80, 'Ghana', 'Accra', '233', 'GHS', 'gh');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (81, 'Gibraltar', 'Gibraltar', '350', 'GIP', 'gi');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (82, 'Great Britain', 'London', '44', 'GBP', 'gb');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (83, 'Greece', 'Athens', '30', 'EUR', 'gr');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (84, 'Greenland', 'Godthab', '299', 'DKK', 'gl');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (85, 'Grenada', 'St. Georges', '1473', 'XCD', 'gd');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (86, 'Guadeloupe French', 'Basse-Terre', '590', 'EUR', 'gp');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (87, 'Guam USA', 'Agana', '1671', 'USD', 'gu');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (88, 'Guatemala', 'Guatemala City', '502', 'QTQ', 'gt');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (89, 'Guernsey', 'St. Peter Port', '0', 'GGP', 'gg');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (90, 'Guinea', 'Conakry', '224', 'GNF', 'gn');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (91, 'Guinea Bissau', 'Bissau', '245', 'GWP', 'gw');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (92, 'Guyana', 'Georgetown', '592', 'GYD', 'gy');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (93, 'Haiti', 'Port-au-Prince', '509', 'HTG', 'ht');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (94, 'Heard Island and McDonald Islands', 'None', '0', 'AUD', 'hm');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (95, 'Honduras', 'Tegucigalpa', '504', 'HNL', 'hn');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (96, 'Hong Kong', 'Victoria', '852', 'HKD', 'hk');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (97, 'Hungary', 'Budapest', '36', 'HUF', 'hu');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (98, 'Iceland', 'Reykjavik', '354', 'ISK', 'is');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (99, 'India', 'New Delhi', '91', 'INR', 'in');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (100, 'Indonesia', 'Jakarta', '62', 'IDR', 'id');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (101, 'Iran', 'Tehran', '98', 'IRR', 'ir');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (102, 'Iraq', 'Baghdad', '964', 'IQD', 'iq');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (103, 'Ireland', 'Dublin', '353', 'EUR', 'ie');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (104, 'Isle of Man', 'Douglas', '0', 'GBP', 'im');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (105, 'Israel', 'Jerusalem', '972', 'ILS', 'il');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (106, 'Italy', 'Rome', '39', 'EUR', 'it');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (107, 'Ivory Coast', 'Abidjan', '225', 'XOF', 'ci');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (108, 'Jamaica', 'Kingston', '1876', 'JMD', 'jm');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (109, 'Japan', 'Tokyo', '81', 'JPY', 'jp');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (110, 'Jersey', 'Saint Helier', '0', 'GBP', 'je');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (111, 'Jordan', 'Amman', '962', 'JOD', 'jo');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (112, 'Kazakhstan', 'Astana', '7', 'KZT', 'kz');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (113, 'Kenya', 'Nairobi', '254', 'KES', 'ke');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (114, 'Kiribati', 'Tarawa', '686', 'AUD', 'ki');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (115, 'Korea-North', 'Pyongyang', '850', 'KPW', 'kp');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (116, 'Korea-South', 'Seoul', '82', 'KRW', 'kr');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (117, 'Kuwait', 'Kuwait City', '965', 'KWD', 'kw');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (118, 'Kyrgyzstan', 'Bishkek', '996', 'KGS', 'kg');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (119, 'Laos', 'Vientiane', '856', 'LAK', 'la');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (120, 'Latvia', 'Riga', '371', 'LVL', 'lv');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (121, 'Lebanon', 'Beirut', '961', 'LBP', 'lb');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (122, 'Lesotho', 'Maseru', '266', 'LSL', 'ls');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (123, 'Liberia', 'Monrovia', '231', 'LRD', 'lr');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (124, 'Libya', 'Tripoli', '218', 'LYD', 'ly');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (125, 'Liechtenstein', 'Vaduz', '423', 'CHF', 'li');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (126, 'Lithuania', 'Vilnius', '370', 'LTL', 'lt');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (127, 'Luxembourg', 'Luxembourg', '352', 'EUR', 'lu');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (128, 'Macau', 'Macau', '853', 'MOP', 'mo');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (129, 'Macedonia', 'Skopje', '389', 'MKD', 'mk');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (130, 'Madagascar', 'Antananarivo', '261', 'MGF', 'mg');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (131, 'Malawi', 'Lilongwe', '265', 'MWK', 'mw');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (132, 'Malaysia', 'Kuala Lumpur', '60', 'MYR', 'my');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (133, 'Maldives', 'Male', '960', 'MVR', 'mv');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (134, 'Mali', 'Bamako', '223', 'XOF', 'ml');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (135, 'Malta', 'Valletta', '356', 'EUR', 'mt');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (136, 'Marshall Islands', 'Majuro', '692', 'USD', 'mh');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (137, 'Martinique French', 'Fort-de-France', '596', 'EUR', 'mq');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (138, 'Mauritania', 'Nouakchott', '222', 'MRO', 'mr');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (139, 'Mauritius', 'Port Louis', '230', 'MUR', 'mu');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (140, 'Mayotte', 'Dzaoudzi', '269', 'EUR', 'yt');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (141, 'Mexico', 'Mexico City', '52', 'MXN', 'mx');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (142, 'Micronesia', 'Palikir', '691', 'USD', 'fm');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (143, 'Moldova', 'Kishinev', '373', 'MDL', 'md');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (144, 'Monaco', 'Monaco', '377', 'EUR', 'mc');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (145, 'Mongolia', 'Ulan Bator', '976', 'MNT', 'mn');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (146, 'Montenegro', 'Podgorica', '382', 'EUR', 'me');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (147, 'Montserrat', 'Plymouth', '1664', 'XCD', 'ms');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (148, 'Morocco', 'Rabat', '212', 'MAD', 'ma');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (149, 'Mozambique', 'Maputo', '258', 'MZN', 'mz');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (150, 'Myanmar', 'Naypyidaw', '95', 'MMK', 'mm');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (151, 'Namibia', 'Windhoek', '264', 'NAD', 'na');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (152, 'Nauru', 'Yaren', '674', 'AUD', 'nr');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (153, 'Nepal', 'Kathmandu', '977', 'NPR', 'np');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (154, 'Netherlands', 'Amsterdam', '31', 'EUR', 'nl');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (155, 'Netherlands Antilles', 'Willemstad', '599', 'ANG', 'an');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (156, 'New Caledonia French', 'Noumea', '687', 'XPF', 'nc');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (157, 'New Zealand', 'Wellington', '64', 'NZD', 'nz');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (158, 'Nicaragua', 'Managua', '505', 'NIO', 'ni');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (159, 'Niger', 'Niamey', '227', 'XOF', 'ne');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (160, 'Nigeria', 'Lagos', '234', 'NGN', 'ng');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (161, 'Niue', 'Alofi', '683', 'NZD', 'nu');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (162, 'Norfolk Island', 'Kingston', '672', 'AUD', 'nf');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (163, 'Northern Mariana Islands', 'Saipan', '670', 'USD', 'mp');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (164, 'Norway', 'Oslo', '47', 'NOK', 'no');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (165, 'Oman', 'Muscat', '968', 'OMR', 'om');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (166, 'Pakistan', 'Islamabad', '92', 'PKR', 'pk');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (167, 'Palau', 'Koror', '680', 'USD', 'pw');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (168, 'Panama', 'Panama City', '507', 'PAB', 'pa');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (169, 'Papua New Guinea', 'Port Moresby', '675', 'PGK', 'pg');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (170, 'Paraguay', 'Asuncion', '595', 'PYG', 'py');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (171, 'Peru', 'Lima', '51', 'PEN', 'pe');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (172, 'Philippines', 'Manila', '63', 'PHP', 'ph');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (173, 'Pitcairn Island', 'Adamstown', '0', 'NZD', 'pn');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (174, 'Poland', 'Warsaw', '48', 'PLN', 'pl');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (175, 'Polynesia French', 'Papeete', '689', 'XPF', 'pf');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (176, 'Portugal', 'Lisbon', '351', 'EUR', 'pt');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (177, 'Puerto Rico', 'San Juan', '1787', 'USD', 'pr');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (178, 'Qatar', 'Doha', '974', 'QAR', 'qa');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (179, 'Reunion French', 'Saint-Denis', '262', 'EUR', 're');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (180, 'Romania', 'Bucharest', '40', 'RON', 'ro');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (181, 'Russia', 'Moscow', '7', 'RUB', 'ru');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (182, 'Rwanda', 'Kigali', '250', 'RWF', 'rw');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (183, 'Saint Helena', 'Jamestown', '290', 'SHP', 'sh');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (184, 'Saint Kitts & Nevis Anguilla', 'Basseterre', '1869', 'XCD', 'kn');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (185, 'Saint Lucia', 'Castries', '1758', 'XCD', 'lc');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (186, 'Saint Pierre and Miquelon', 'St. Pierre', '508', 'EUR', 'pm');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (187, 'Saint Vincent & Grenadines', 'Kingstown', '1784', 'XCD', 'vc');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (188, 'Samoa', 'Apia', '684', 'WST', 'ws');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (189, 'San Marino', 'San Marino', '378', 'EUR', 'sm');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (190, 'Sao Tome and Principe', 'Sao Tome', '239', 'STD', 'st');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (191, 'Saudi Arabia', 'Riyadh', '966', 'SAR', 'sa');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (192, 'Senegal', 'Dakar', '221', 'XOF', 'sn');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (193, 'Serbia', 'Belgrade', '381', 'RSD', 'rs');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (194, 'Seychelles', 'Victoria', '248', 'SCR', 'sc');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (195, 'Sierra Leone', 'Freetown', '232', 'SLL', 'sl');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (196, 'Singapore', 'Singapore', '65', 'SGD', 'sg');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (197, 'Slovakia', 'Bratislava', '421', 'EUR', 'sk');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (198, 'Slovenia', 'Ljubljana', '386', 'EUR', 'si');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (199, 'Solomon Islands', 'Honiara', '677', 'SBD', 'sb');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (200, 'Somalia', 'Mogadishu', '252', 'SOS', 'so');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (201, 'South Africa', 'Pretoria', '27', 'ZAR', 'za');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (202, 'South Georgia & South Sandwich Islands', 'None', '0', 'GBP', 'gs');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (203, 'South Sudan', 'Ramciel', '0', 'SSP', 'ss');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (204, 'Spain', 'Madrid', '34', 'EUR', 'es');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (205, 'Sri Lanka', 'Colombo', '94', 'LKR', 'lk');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (206, 'Sudan', 'Khartoum', '249', 'SDG', 'sd');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (207, 'Suriname', 'Paramaribo', '597', 'SRD', 'sr');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (208, 'Svalbard and Jan Mayen Islands', 'Longyearbyen', '0', 'NOK', 'sj');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (209, 'Swaziland', 'Mbabane', '268', 'SZL', 'sz');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (210, 'Sweden', 'Stockholm', '46', 'SEK', 'se');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (211, 'Switzerland', 'Bern', '41', 'CHF', 'ch');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (212, 'Syria', 'Damascus', '963', 'SYP', 'sy');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (213, 'Taiwan', 'Taipei', '886', 'TWD', 'tw');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (214, 'Tajikistan', 'Dushanbe', '992', 'TJS', 'tj');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (215, 'Tanzania', 'Dodoma', '255', 'TZS', 'tz');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (216, 'Thailand', 'Bangkok', '66', 'THB', 'th');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (217, 'Togo', 'Lome', '228', 'XOF', 'tg');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (218, 'Tokelau', 'None', '690', 'NZD', 'tk');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (219, 'Tonga', 'Nukualofa', '676', 'TOP', 'to');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (220, 'Trinidad and Tobago', 'Port of Spain', '1868', 'TTD', 'tt');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (221, 'Tunisia', 'Tunis', '216', 'TND', 'tn');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (222, 'Turkey', 'Ankara', '90', 'TRY', 'tr');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (223, 'Turkmenistan', 'Ashgabat', '993', 'TMT', 'tm');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (224, 'Turks and Caicos Islands', 'Grand Turk', '1649', 'USD', 'tc');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (225, 'Tuvalu', 'Funafuti', '688', 'AUD', 'tv');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (226, 'U.K.', 'London', '44', 'GBP', 'uk');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (227, 'Uganda', 'Kampala', '256', 'UGX', 'ug');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (228, 'Ukraine', 'Kiev', '380', 'UAH', 'ua');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (229, 'United Arab Emirates', 'Abu Dhabi', '971', 'AED', 'ae');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (230, 'Uruguay', 'Montevideo', '598', 'UYU', 'uy');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (231, 'USA', 'Washington', '1', 'USD', 'us');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (232, 'USA Minor Outlying Islands', 'None', '0', 'USD', 'um');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (233, 'Uzbekistan', 'Tashkent', '998', 'UZS', 'uz');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (234, 'Vanuatu', 'Port Vila', '678', 'VUV', 'vu');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (235, 'Vatican', 'Vatican City', '39', 'EUR', 'va');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (236, 'Venezuela', 'Caracas', '58', 'VEF', 've');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (237, 'Vietnam', 'Hanoi', '84', 'VND', 'vn');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (238, 'Virgin Islands British', 'Road Town', '1284', 'USD', 'vg');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (239, 'Virgin Islands USA', 'Charlotte Amalie', '1340', 'USD', 'vi');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (240, 'Wallis and Futuna Islands', 'Mata-Utu', '681', 'XPF', 'wf');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (241, 'Western Sahara', 'El Aaiun', '0', 'MAD', 'eh');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (242, 'Yemen', 'Sana', '967', 'YER', 'ye');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (243, 'Zambia', 'Lusaka', '260', 'ZMW', 'zm');
INSERT INTO `country` (`idCountry`, `strName`, `strCapital`, `strTelAreaCode`, `strCurrencySymbol`, `strLanguageCode`) VALUES (244, 'Zimbabwe', 'Harare', '263', 'ZWD', 'zw');

COMMIT;


-- -----------------------------------------------------
-- Data for table `projectuserscope`
-- -----------------------------------------------------
START TRANSACTION;
INSERT INTO `projectuserscope` (`idProjectUserScope`, `strProjectUserScope`) VALUES (1, 'Just Me');
INSERT INTO `projectuserscope` (`idProjectUserScope`, `strProjectUserScope`) VALUES (2, 'My Workgroup');
INSERT INTO `projectuserscope` (`idProjectUserScope`, `strProjectUserScope`) VALUES (3, 'All Users');

COMMIT;


-- -----------------------------------------------------
-- Data for table `csstheme`
-- -----------------------------------------------------
START TRANSACTION;
INSERT INTO `csstheme` (`idCSSTheme`, `strThemeName`) VALUES (1, 'united');
INSERT INTO `csstheme` (`idCSSTheme`, `strThemeName`) VALUES (2, 'classic');
INSERT INTO `csstheme` (`idCSSTheme`, `strThemeName`) VALUES (3, 'cyborg');
INSERT INTO `csstheme` (`idCSSTheme`, `strThemeName`) VALUES (4, 'journal');
INSERT INTO `csstheme` (`idCSSTheme`, `strThemeName`) VALUES (5, 'redy');
INSERT INTO `csstheme` (`idCSSTheme`, `strThemeName`) VALUES (6, 'simplex');
INSERT INTO `csstheme` (`idCSSTheme`, `strThemeName`) VALUES (7, 'slate');
INSERT INTO `csstheme` (`idCSSTheme`, `strThemeName`) VALUES (8, 'spacelab');
INSERT INTO `csstheme` (`idCSSTheme`, `strThemeName`) VALUES (9, 'cerulean');

COMMIT;


-- -----------------------------------------------------
-- Data for table `userlevel`
-- -----------------------------------------------------
START TRANSACTION;
INSERT INTO `userlevel` (`idUserLevel`, `strLevel`) VALUES (1, 'Visitor');
INSERT INTO `userlevel` (`idUserLevel`, `strLevel`) VALUES (2, 'Edit');
INSERT INTO `userlevel` (`idUserLevel`, `strLevel`) VALUES (3, 'Create, Edit, Delete');
INSERT INTO `userlevel` (`idUserLevel`, `strLevel`) VALUES (4, 'Project Administrator');

COMMIT;


-- -----------------------------------------------------
-- Data for table `datum`
-- -----------------------------------------------------
START TRANSACTION;
INSERT INTO `datum` (`idDatum`, `strName`, `dblA`, `dblE2`) VALUES (1, 'Airy', 6377563, 0.00667054);
INSERT INTO `datum` (`idDatum`, `strName`, `dblA`, `dblE2`) VALUES (2, 'Australian National', 6378160, 0.006694542);
INSERT INTO `datum` (`idDatum`, `strName`, `dblA`, `dblE2`) VALUES (3, 'Bessel 1841', 6377397, 0.006674372);
INSERT INTO `datum` (`idDatum`, `strName`, `dblA`, `dblE2`) VALUES (4, 'Bessel 1841 Nambia', 6377484, 0.006674372);
INSERT INTO `datum` (`idDatum`, `strName`, `dblA`, `dblE2`) VALUES (5, 'Clarke 1866', 6378206, 0.006768658);
INSERT INTO `datum` (`idDatum`, `strName`, `dblA`, `dblE2`) VALUES (6, 'Clarke 1880', 6378249, 0.006803511);
INSERT INTO `datum` (`idDatum`, `strName`, `dblA`, `dblE2`) VALUES (7, 'Everest', 6377276, 0.006637847);
INSERT INTO `datum` (`idDatum`, `strName`, `dblA`, `dblE2`) VALUES (8, 'Fischer 1960 Mercury', 6378166, 0.006693422);
INSERT INTO `datum` (`idDatum`, `strName`, `dblA`, `dblE2`) VALUES (9, 'Fischer 1968', 6378150, 0.006693422);
INSERT INTO `datum` (`idDatum`, `strName`, `dblA`, `dblE2`) VALUES (10, 'GRS 1967', 6378160, 0.006694605);
INSERT INTO `datum` (`idDatum`, `strName`, `dblA`, `dblE2`) VALUES (11, 'GRS 1980', 6378137, 0.00669438);
INSERT INTO `datum` (`idDatum`, `strName`, `dblA`, `dblE2`) VALUES (12, 'Helmert 1906', 6378200, 0.006693422);
INSERT INTO `datum` (`idDatum`, `strName`, `dblA`, `dblE2`) VALUES (13, 'Hough', 6378270, 0.00672267);
INSERT INTO `datum` (`idDatum`, `strName`, `dblA`, `dblE2`) VALUES (14, 'International', 6378388, 0.00672267);
INSERT INTO `datum` (`idDatum`, `strName`, `dblA`, `dblE2`) VALUES (15, 'Krassovsky', 6378245, 0.006693422);
INSERT INTO `datum` (`idDatum`, `strName`, `dblA`, `dblE2`) VALUES (16, 'Modified Airy', 6377340, 0.00667054);
INSERT INTO `datum` (`idDatum`, `strName`, `dblA`, `dblE2`) VALUES (17, 'Modified Everest', 6377304, 0.006637847);
INSERT INTO `datum` (`idDatum`, `strName`, `dblA`, `dblE2`) VALUES (18, 'Modified Fischer 1960', 6378155, 0.006693422);
INSERT INTO `datum` (`idDatum`, `strName`, `dblA`, `dblE2`) VALUES (19, 'South American 1969', 6378160, 0.006694542);
INSERT INTO `datum` (`idDatum`, `strName`, `dblA`, `dblE2`) VALUES (20, 'WGS 60', 6378165, 0.006693422);
INSERT INTO `datum` (`idDatum`, `strName`, `dblA`, `dblE2`) VALUES (21, 'WGS 66', 6378145, 0.006694542);
INSERT INTO `datum` (`idDatum`, `strName`, `dblA`, `dblE2`) VALUES (22, 'WGS 72', 6378135, 0.006694318);
INSERT INTO `datum` (`idDatum`, `strName`, `dblA`, `dblE2`) VALUES (23, 'WGS 84', 6378137, 0.00669437999014132);
INSERT INTO `datum` (`idDatum`, `strName`, `dblA`, `dblE2`) VALUES (24, 'SIRGAS 2000', 6378137, 0.00669437999014132);
INSERT INTO `datum` (`idDatum`, `strName`, `dblA`, `dblE2`) VALUES (25, 'Corrego Alegre', 6378388, 0.00672267002169147);

COMMIT;


-- -----------------------------------------------------
-- Data for table `projectworkgroup`
-- -----------------------------------------------------
START TRANSACTION;
INSERT INTO `projectworkgroup` (`idProjectWorkgroup`, `idProject`, `strWorkgroup`) VALUES (0, 0, 'General');

COMMIT;


-- -----------------------------------------------------
-- Data for table `eventtype`
-- -----------------------------------------------------
START TRANSACTION;
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (1, 'UserLogin');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (2, 'UserLogout');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (3, 'FormInsert');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (4, 'FormDelete');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (5, 'FormUpdateMarkerChange');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (6, 'FormUpdateRename');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (7, 'FormUpdateFieldInsert');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (8, 'FormUpdateFieldRename');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (9, 'FormUpdateFieldDelete');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (10, 'UserInsert');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (11, 'UserDelete');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (12, 'UserUpdateEmail');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (13, 'RecordInsert');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (14, 'RecordUpdate');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (15, 'RecordDelete');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (16, 'RecordFileInsert');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (17, 'RecordFileDescriptionUpdade');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (18, 'RecordFileDelete');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (19, 'Search');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (20, 'UserJoinSubmit');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (21, 'UserActivated');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (22, 'UserBlocked');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (23, 'UserGroupInsert');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (24, 'UserGroupUpdate');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (25, 'UserGroupDelete');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (26, 'UserGroupJoin');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (27, 'UserGroupRelease');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (28, 'RecordSelect');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (29, 'ProjectBackup');
INSERT INTO `eventtype` (`idEventType`, `strEventType`) VALUES (30, 'DatasourceGather');

COMMIT;


-- -----------------------------------------------------
-- Data for table `marker`
-- -----------------------------------------------------
START TRANSACTION;
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (1, '1.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (2, '2.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (3, '3.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (4, '4.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (5, '5.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (6, '6.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (7, '7.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (8, '8.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (9, '9.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (10, '10.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (11, '11.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (12, '12.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (13, '13.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (14, '14.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (15, '15.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (16, '16.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (17, '17.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (18, '18.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (19, '19.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (20, '20.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (21, '21.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (22, '22.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (23, '23.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (24, '24.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (25, '25.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (26, '26.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (27, '27.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (28, '28.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (29, '29.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (30, '30.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (31, '31.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (32, '32.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (33, '33.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (34, '34.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (35, '35.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (36, '36.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (37, '37.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (38, '38.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (39, '39.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (40, '40.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (41, '41.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (42, '42.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (43, '43.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (44, '44.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (45, '45.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (46, '46.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (47, '47.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (48, '48.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (49, '49.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (50, '50.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (51, '51.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (52, '52.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (53, '53.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (54, '54.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (55, '55.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (56, '56.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (57, '58.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (58, '58.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (59, '59.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (60, '60.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (61, '61.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (62, '62.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (63, '63.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (64, '64.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (65, '65.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (66, '66.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (67, '67.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (68, '68.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (69, '69.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (70, '70.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (71, '71.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (72, '72.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (73, '73.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (74, '74.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (75, '75.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (76, '76.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (77, '77.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (78, '78.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (79, '79.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (80, '80.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (81, '81.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (82, '82.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (83, '83.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (84, '84.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (85, '85.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (86, '86.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (87, '87.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (88, '88.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (89, '89.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (90, '90.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (91, '91.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (92, '92.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (93, '92.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (94, '94.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (95, '95.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (96, '96.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (97, '97.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (98, '98.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (99, '99.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (100, '100.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (101, '101.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (102, '102.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (103, '103.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (104, '104.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (105, '105.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (106, '106.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (107, '107.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (108, '108.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (109, '109.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (110, '110.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (111, '111.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (112, '112.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (113, '113.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (114, '114.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (115, '115.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (116, '116.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (117, '117.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (118, '118.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (119, '119.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (120, '120.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (121, '121.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (122, '122.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (123, '123.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (124, '124.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (125, '125.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (126, '126.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (127, '127.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (128, '128.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (129, '129.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (130, '130.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (131, '131.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (132, '132.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (133, '133.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (134, '134.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (135, '135.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (136, '136.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (137, '137.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (138, '138.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (139, '139.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (140, '140.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (141, '141.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (142, '142.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (143, '143.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (144, '144.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (145, '145.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (146, '146.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (147, '147.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (148, '148.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (149, '149.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (150, '150.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (151, '151.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (152, '152.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (153, '153.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (154, '154.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (155, '155.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (156, '156.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (157, '157.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (158, '158.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (159, '159.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (160, '160.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (161, '161.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (162, '162.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (163, '163.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (164, '164.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (165, '165.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (166, '166.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (167, '167.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (168, '168.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (169, '169.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (170, '170.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (171, '171.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (172, '172.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (173, '173.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (174, '174.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (175, '175.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (176, '176.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (177, '177.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (178, '178.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (179, '179.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (180, '180.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (181, '181.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (182, '182.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (183, '183.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (184, '184.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (185, '185.png', NULL);
INSERT INTO `marker` (`idMarker`, `strMarkerFileName`, `idProject`) VALUES (186, '186.png', NULL);

COMMIT;


-- -----------------------------------------------------
-- Data for table `datasource`
-- -----------------------------------------------------
START TRANSACTION;
INSERT INTO `datasource` (`idDataSource`, `idProject`, `strName`, `strSiteURL`, `strLogoFileName`, `strScriptPHPFileName`, `strGETParameterq`, `strGETParameterlimit`, `strResultTimeSeriesFields`, `intUpdateFrequencyMin`, `blnActive`, `blnPublic`) VALUES (1, 0, 'Vicon SAGA', NULL, 'vicon.png', NULL, NULL, NULL, NULL, 60, 1, 1);
INSERT INTO `datasource` (`idDataSource`, `idProject`, `strName`, `strSiteURL`, `strLogoFileName`, `strScriptPHPFileName`, `strGETParameterq`, `strGETParameterlimit`, `strResultTimeSeriesFields`, `intUpdateFrequencyMin`, `blnActive`, `blnPublic`) VALUES (2, 0, 'Facebook', NULL, 'facebook.png', 'facebook.php', NULL, NULL, NULL, 60, 1, 1);
INSERT INTO `datasource` (`idDataSource`, `idProject`, `strName`, `strSiteURL`, `strLogoFileName`, `strScriptPHPFileName`, `strGETParameterq`, `strGETParameterlimit`, `strResultTimeSeriesFields`, `intUpdateFrequencyMin`, `blnActive`, `blnPublic`) VALUES (3, 0, 'Twitter', NULL, 'twitter.png', 'twitter.php', NULL, NULL, NULL, 60, 1, 1);
INSERT INTO `datasource` (`idDataSource`, `idProject`, `strName`, `strSiteURL`, `strLogoFileName`, `strScriptPHPFileName`, `strGETParameterq`, `strGETParameterlimit`, `strResultTimeSeriesFields`, `intUpdateFrequencyMin`, `blnActive`, `blnPublic`) VALUES (4, 0, 'Flickr', NULL, 'flickr.png', 'flickr.php', NULL, NULL, NULL, 60, 1, 1);
INSERT INTO `datasource` (`idDataSource`, `idProject`, `strName`, `strSiteURL`, `strLogoFileName`, `strScriptPHPFileName`, `strGETParameterq`, `strGETParameterlimit`, `strResultTimeSeriesFields`, `intUpdateFrequencyMin`, `blnActive`, `blnPublic`) VALUES (5, 0, 'Instagram', NULL, 'instagram.png', 'instagram.php', NULL, NULL, NULL, 60, 1, 1);
INSERT INTO `datasource` (`idDataSource`, `idProject`, `strName`, `strSiteURL`, `strLogoFileName`, `strScriptPHPFileName`, `strGETParameterq`, `strGETParameterlimit`, `strResultTimeSeriesFields`, `intUpdateFrequencyMin`, `blnActive`, `blnPublic`) VALUES (6, 0, 'YouTube', NULL, 'youtube.png', 'youtube.php', NULL, NULL, NULL, 60, 1, 1);
INSERT INTO `datasource` (`idDataSource`, `idProject`, `strName`, `strSiteURL`, `strLogoFileName`, `strScriptPHPFileName`, `strGETParameterq`, `strGETParameterlimit`, `strResultTimeSeriesFields`, `intUpdateFrequencyMin`, `blnActive`, `blnPublic`) VALUES (7, 0, 'USGS - Simos', NULL, 'usgs.png', 'usgs.php', NULL, NULL, NULL, 60, 1, 1);
INSERT INTO `datasource` (`idDataSource`, `idProject`, `strName`, `strSiteURL`, `strLogoFileName`, `strScriptPHPFileName`, `strGETParameterq`, `strGETParameterlimit`, `strResultTimeSeriesFields`, `intUpdateFrequencyMin`, `blnActive`, `blnPublic`) VALUES (8, 0, 'Geodesign Hub', NULL, 'geodesignhub.png', 'geodesignhub.php', NULL, NULL, NULL, 60, 1, 1);
INSERT INTO `datasource` (`idDataSource`, `idProject`, `strName`, `strSiteURL`, `strLogoFileName`, `strScriptPHPFileName`, `strGETParameterq`, `strGETParameterlimit`, `strResultTimeSeriesFields`, `intUpdateFrequencyMin`, `blnActive`, `blnPublic`) VALUES (9, 0, 'CEMADEN - Pluviômetros', NULL, 'cemaden.png', 'cemaden.php', NULL, NULL, NULL, 60, 1, 1);
INSERT INTO `datasource` (`idDataSource`, `idProject`, `strName`, `strSiteURL`, `strLogoFileName`, `strScriptPHPFileName`, `strGETParameterq`, `strGETParameterlimit`, `strResultTimeSeriesFields`, `intUpdateFrequencyMin`, `blnActive`, `blnPublic`) VALUES (10, 0, 'Google Plus', NULL, 'googleplus.png', 'googleplus.php', NULL, NULL, NULL, 60, 1, 1);
INSERT INTO `datasource` (`idDataSource`, `idProject`, `strName`, `strSiteURL`, `strLogoFileName`, `strScriptPHPFileName`, `strGETParameterq`, `strGETParameterlimit`, `strResultTimeSeriesFields`, `intUpdateFrequencyMin`, `blnActive`, `blnPublic`) VALUES (11, 0, 'Tumblr', NULL, 'tumblr.png', 'tumblr.php', NULL, NULL, NULL, 60, 1, 1);

COMMIT;


-- -----------------------------------------------------
-- Data for table `formfieldtype`
-- -----------------------------------------------------
START TRANSACTION;
INSERT INTO `formfieldtype` (`idFormFieldType`, `strFormFieldType`) VALUES (1, 'Text');
INSERT INTO `formfieldtype` (`idFormFieldType`, `strFormFieldType`) VALUES (2, 'Numeric');
INSERT INTO `formfieldtype` (`idFormFieldType`, `strFormFieldType`) VALUES (3, 'Unichoice');
INSERT INTO `formfieldtype` (`idFormFieldType`, `strFormFieldType`) VALUES (4, 'Multichoice');
INSERT INTO `formfieldtype` (`idFormFieldType`, `strFormFieldType`) VALUES (5, 'Date');
INSERT INTO `formfieldtype` (`idFormFieldType`, `strFormFieldType`) VALUES (6, 'Time');
INSERT INTO `formfieldtype` (`idFormFieldType`, `strFormFieldType`) VALUES (7, 'TimeSerie');

COMMIT;


-- -----------------------------------------------------
-- Data for table `device`
-- -----------------------------------------------------
START TRANSACTION;
INSERT INTO `device` (`idDevice`, `strName`) VALUES (1, 'Web');
INSERT INTO `device` (`idDevice`, `strName`) VALUES (2, 'Mobile');
INSERT INTO `device` (`idDevice`, `strName`) VALUES (3, 'API');
INSERT INTO `device` (`idDevice`, `strName`) VALUES (4, 'Social Network');

COMMIT;


-- -----------------------------------------------------
-- Data for table `shapetype`
-- -----------------------------------------------------
START TRANSACTION;
INSERT INTO `shapetype` (`idShapeType`, `strShapeType`) VALUES (1, 'Point');
INSERT INTO `shapetype` (`idShapeType`, `strShapeType`) VALUES (2, 'Line');
INSERT INTO `shapetype` (`idShapeType`, `strShapeType`) VALUES (3, 'Area');

COMMIT;